<?php

/** @noinspection SpellCheckingInspection */
declare(strict_types=1);

/*
 * Copyright (c) Ne-Lexa
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 *
 * @see https://github.com/Ne-Lexa/google-play-scraper
 */

namespace Nelexa\GPlay\Util;

/**
 * Class LocaleHelper.
 */
class LocaleHelper
{
    public const DEFAULT_GOOGLE_PLAY_LOCALE = 'en_US';

    public const SUPPORTED_LOCALES = [
        'af' => 'af', // Afrikaans
        'am' => 'am', // Amharic
        'ar' => 'ar', // Arabic
        'az_az' => 'az_AZ', // Azerbaijani
        'be' => 'be', // Belarusian
        'bg' => 'bg', // Bulgarian
        'bn_bd' => 'bn_BD', // Bengali
        'ca' => 'ca', // Catalan
        'cs_cz' => 'cs_CZ', // Czech
        'da_dk' => 'da_DK', // Danish
        'de_de' => 'de_DE', // German
        'el_gr' => 'el_GR', // Greek
        'en_au' => 'en_AU', // English (Australia)
        'en_ca' => 'en_CA', // English (Canada)
        'en_gb' => 'en_GB', // English (United Kingdom)
        'en_in' => 'en_IN', // English (India)
        'en_sg' => 'en_SG', // English (Singapore)
        'en_us' => 'en_US', // English (United States)
        'en_za' => 'en_ZA', // English (South Africa)
        'es_419' => 'es_419', // Spanish (Latin America)
        'es_es' => 'es_ES', // Spanish (Spain)
        'es_us' => 'es_US', // Spanish (United States)
        'et' => 'et', // Estonian
        'eu_es' => 'eu_ES', // Basque
        'fa' => 'fa', // Persian
        'fi_fi' => 'fi_FI', // Finnish
        'fil' => 'fil', // Filipino
        'fr_ca' => 'fr_CA', // French (Canada)
        'fr_fr' => 'fr_FR', // French
        'gl_es' => 'gl_ES', // Galician
        'hi_in' => 'hi_IN', // Hindi
        'hr' => 'hr', // Croatian
        'hu_hu' => 'hu_HU', // Hungarian
        'hy_am' => 'hy_AM', // Armenian
        'id' => 'id', // Indonesian
        'is_is' => 'is_IS', // Icelandic
        'it_it' => 'it_IT', // Italian
        'iw_il' => 'iw_IL', // Hebrew
        'ja_jp' => 'ja_JP', // Japanese
        'ka_ge' => 'ka_GE', // Georgian
        'kk' => 'kk', // Kazakh
        'km_kh' => 'km_KH', // Khmer
        'kn_in' => 'kn_IN', // Kannada
        'ko_kr' => 'ko_KR', // Korean (South Korea)
        'ky_kg' => 'ky_KG', // Kyrgyz
        'lo_la' => 'lo_LA', // Lao
        'lt' => 'lt', // Lithuanian
        'lv' => 'lv', // Latvian
        'mk_mk' => 'mk_MK', // Macedonian
        'ml_in' => 'ml_IN', // Malayalam
        'mn_mn' => 'mn_MN', // Mongolian
        'mr_in' => 'mr_IN', // Marathi
        'ms' => 'ms', // Malay
        'my_mm' => 'my_MM', // Burmese
        'ne_np' => 'ne_NP', // Nepali
        'nl_nl' => 'nl_NL', // Dutch
        'no_no' => 'no_NO', // Norwegian
        'pl_pl' => 'pl_PL', // Polish
        'pt_br' => 'pt_BR', // Portuguese (Brazil)
        'pt_pt' => 'pt_PT', // Portuguese (Portugal)
        'ro' => 'ro', // Romanian
        'ru_ru' => 'ru_RU', // Russian
        'si_lk' => 'si_LK', // Sinhala
        'sk' => 'sk', // Slovak
        'sl' => 'sl', // Slovenian
        'sr' => 'sr', // Serbian
        'sv_se' => 'sv_SE', // Swedish
        'sw' => 'sw', // Swahili
        'ta_in' => 'ta_IN', // Tamil
        'te_in' => 'te_IN', // Telugu
        'th' => 'th', // Thai
        'tr_tr' => 'tr_TR', // Turkish
        'uk' => 'uk', // Ukrainian
        'vi' => 'vi', // Vietnamese
        'zh_cn' => 'zh_CN', // Chinese (Simplified)
        'zh_hk' => 'zh_HK', // Chinese (Hong Kong)
        'zh_tw' => 'zh_TW', // Chinese (Traditional)
        'zu' => 'zu', // Zulu
    ];

    private const ALIASES_LOCALE = [
        'az' => 'az_AZ',
        'bn' => 'bn_BD',
        'bo' => 'zh_TW',
        'bo_cn' => 'zh_TW',
        'bo_in' => 'zh_TW',
        'br' => 'fr_FR',
        'ckb' => 'ar',
        'cs' => 'cs_CZ',
        'da' => 'da_DK',
        'de' => 'de_DE',
        'el' => 'el_GR',
        'en' => 'en_US',
        'en_001' => 'en_AU',
        'en_150' => 'en_AU',
        'en_ae' => 'en_AU',
        'en_ag' => 'en_AU',
        'en_ai' => 'en_AU',
        'en_as' => 'en_AU',
        'en_at' => 'en_AU',
        'en_bb' => 'en_AU',
        'en_be' => 'en_AU',
        'en_bi' => 'en_AU',
        'en_bm' => 'en_AU',
        'en_bs' => 'en_AU',
        'en_bw' => 'en_AU',
        'en_bz' => 'en_AU',
        'en_cc' => 'en_AU',
        'en_ch' => 'en_AU',
        'en_ck' => 'en_AU',
        'en_cm' => 'en_AU',
        'en_cx' => 'en_AU',
        'en_cy' => 'en_AU',
        'en_de' => 'en_AU',
        'en_dg' => 'en_AU',
        'en_dk' => 'en_AU',
        'en_dm' => 'en_AU',
        'en_er' => 'en_AU',
        'en_ie' => 'en_AU',
        'en_fi' => 'en_AU',
        'en_fj' => 'en_AU',
        'en_fk' => 'en_AU',
        'en_fm' => 'en_AU',
        'en_gd' => 'en_AU',
        'en_gg' => 'en_AU',
        'en_gh' => 'en_AU',
        'en_gi' => 'en_AU',
        'en_gm' => 'en_AU',
        'en_gu' => 'en_AU',
        'en_gy' => 'en_AU',
        'en_hk' => 'en_AU',
        'en_il' => 'en_AU',
        'en_im' => 'en_AU',
        'en_io' => 'en_AU',
        'en_je' => 'en_AU',
        'en_jm' => 'en_AU',
        'en_ke' => 'en_AU',
        'en_ki' => 'en_AU',
        'en_kn' => 'en_AU',
        'en_ky' => 'en_AU',
        'en_lc' => 'en_AU',
        'en_lr' => 'en_AU',
        'en_ls' => 'en_AU',
        'en_mg' => 'en_AU',
        'en_mh' => 'en_AU',
        'en_mo' => 'en_AU',
        'en_mp' => 'en_AU',
        'en_ms' => 'en_AU',
        'en_mt' => 'en_AU',
        'en_mu' => 'en_AU',
        'en_mw' => 'en_AU',
        'en_my' => 'en_AU',
        'en_na' => 'en_AU',
        'en_nf' => 'en_AU',
        'en_ng' => 'en_AU',
        'en_nl' => 'en_AU',
        'en_nr' => 'en_AU',
        'en_nu' => 'en_AU',
        'en_nz' => 'en_AU',
        'en_pg' => 'en_AU',
        'en_ph' => 'en_AU',
        'en_pk' => 'en_AU',
        'en_pn' => 'en_AU',
        'en_pr' => 'en_AU',
        'en_pw' => 'en_AU',
        'en_rw' => 'en_AU',
        'en_sb' => 'en_AU',
        'en_sc' => 'en_AU',
        'en_sd' => 'en_AU',
        'en_se' => 'en_AU',
        'en_sh' => 'en_AU',
        'en_si' => 'en_AU',
        'en_sl' => 'en_AU',
        'en_ss' => 'en_AU',
        'en_sx' => 'en_AU',
        'en_sz' => 'en_AU',
        'en_tc' => 'en_AU',
        'en_tk' => 'en_AU',
        'en_to' => 'en_AU',
        'en_tt' => 'en_AU',
        'en_tv' => 'en_AU',
        'en_tz' => 'en_AU',
        'en_ug' => 'en_AU',
        'en_um' => 'en_AU',
        'en_us_posix' => 'en_US',
        'en_vc' => 'en_AU',
        'en_vg' => 'en_AU',
        'en_vi' => 'en_AU',
        'en_vu' => 'en_AU',
        'en_ws' => 'en_AU',
        'en_zm' => 'en_AU',
        'en_zw' => 'en_AU',
        'es' => 'es_ES',
        'es_br' => 'es_419',
        'es_bz' => 'es_419',
        'es_cu' => 'es_419',
        'eu' => 'eu_ES',
        'fi' => 'fi_FI',
        'fil' => 'fil',
        'fo' => 'da_DK',
        'fr' => 'fr_FR',
        'fr_bl' => 'fr_CA',
        'fr_gf' => 'fr_CA',
        'fr_gp' => 'fr_CA',
        'fr_ht' => 'fr_CA',
        'fr_mf' => 'fr_CA',
        'fr_mq' => 'fr_CA',
        'fr_pm' => 'fr_CA',
        'fy' => 'nl_NL',
        'gl' => 'gl_ES',
        'he' => 'iw_IL',
        'hi' => 'hi_IN',
        'hu' => 'hu_HU',
        'hy' => 'hy_AM',
        'in' => 'id',
        'is' => 'is_IS',
        'it' => 'it_IT',
        'iw' => 'iw_IL',
        'ja' => 'ja_JP',
        'jv' => 'id',
        'ka' => 'ka_GE',
        'km' => 'km_KH',
        'kn' => 'kn_IN',
        'ko' => 'ko_KR',
        'ku' => 'tr_TR',
        'ky' => 'ky_KG',
        'lo' => 'lo_LA',
        'mg' => 'fr_FR',
        'mk' => 'mk_MK',
        'ml' => 'ml_IN',
        'mn' => 'mn_MN',
        'mo' => 'ro',
        'mr' => 'mr_IN',
        'mt' => 'en_GB',
        'mt_mt' => 'en_GB',
        'my' => 'my_MM',
        'nb' => 'no_NO',
        'ne' => 'ne_NP',
        'nl' => 'nl_NL',
        'nn' => 'no_NO',
        'no' => 'no_NO',
        'or' => 'en_GB',
        'or_in' => 'en_GB',
        'pl' => 'pl_PL',
        'ps' => 'en_GB',
        'ps_af' => 'en_GB',
        'pt' => 'pt_PT',
        'pt_ao' => 'pt_PT',
        'pt_ch' => 'pt_PT',
        'pt_cv' => 'pt_PT',
        'pt_gq' => 'pt_PT',
        'pt_gw' => 'pt_PT',
        'pt_lu' => 'pt_PT',
        'pt_mo' => 'pt_PT',
        'pt_mz' => 'pt_PT',
        'pt_st' => 'pt_PT',
        'pt_tl' => 'pt_PT',
        'qu' => 'es_419',
        'qu_bo' => 'es_419',
        'qu_ec' => 'es_419',
        'qu_pe' => 'es_419',
        'rm' => 'de_DE',
        'ro' => 'ro',
        'ru' => 'ru_RU',
        'rw' => 'fr_FR',
        'sh' => 'sr',
        'sh_ba' => 'sr',
        'sh_cs' => 'sr',
        'sh_yu' => 'sr',
        'si' => 'si_LK',
        'sv' => 'sv_SE',
        'ta' => 'ta_IN',
        'te' => 'te_IN',
        'tg' => 'ru_RU',
        'ti' => 'en_GB',
        'ti_er' => 'en_GB',
        'ti_et' => 'en_GB',
        'tk' => 'ru_RU',
        'tl' => 'fil',
        'tr' => 'tr_TR',
        'tt' => 'ru_RU',
        'ug' => 'zh_CN',
        'ug_cn' => 'zh_CN',
        'wo' => 'fr_FR',
        'zh' => 'zh_CN',
        'zh_hans_cn' => 'zh_CN',
        'zh_hant' => 'zh_TW',
        'zh_hant_hk' => 'zh_HK',
        'zh_hant_mo' => 'zh_HK',
        'zh_hant_tw' => 'zh_TW',
        'zh_mo' => 'zh_HK',
    ];

    private const GOOGLE_PLAY_TRANSLATE_LANGUAGES = [
        'af' => [
            'am' => 'Amharies',
            'ar' => 'Arabies',
            'az_AZ' => 'Azerbeidjans (Azerbeidjan)',
            'be' => 'Belarussies',
            'bg' => 'Bulgaars',
            'bn_BD' => 'Bengaals (Bangladesj)',
            'ca' => 'Katalaans',
            'cs_CZ' => 'Tsjeggies (Tsjeggië)',
            'da_DK' => 'Deens (Denemarke)',
            'de_DE' => 'Duits (Duitsland)',
            'el_GR' => 'Grieks (Griekeland)',
            'en_AU' => 'Engels (Australië)',
            'en_CA' => 'Engels (Kanada)',
            'en_GB' => 'Engels (Verenigde Koninkryk)',
            'en_IN' => 'Engels (Indië)',
            'en_SG' => 'Engels (Singapoer)',
            'en_US' => 'Engels (Verenigde State van Amerika)',
            'en_ZA' => 'Engels (Suid-Afrika)',
            'es_419' => 'Spaans (Latyns-Amerika)',
            'es_ES' => 'Spaans (Spanje)',
            'es_US' => 'Spaans (Verenigde State van Amerika)',
            'et' => 'Estnies',
            'eu_ES' => 'Baskies (Spanje)',
            'fa' => 'Persies',
            'fi_FI' => 'Fins (Finland)',
            'fil' => 'Filippyns',
            'fr_CA' => 'Frans (Kanada)',
            'fr_FR' => 'Frans (Frankryk)',
            'gl_ES' => 'Galisies (Spanje)',
            'hi_IN' => 'Hindi (Indië)',
            'hr' => 'Kroaties',
            'hu_HU' => 'Hongaars (Hongarye)',
            'hy' => 'Armeens (Armenië)',
            'id' => 'Indonesies',
            'is_IS' => 'Yslands (Ysland)',
            'it_IT' => 'Italiaans (Italië)',
            'iw_IL' => 'Hebreeus (Israel)',
            'ja_JP' => 'Japannees (Japan)',
            'ka_GE' => 'Georgies (Georgië)',
            'kk' => 'Kazaks',
            'km_KH' => 'Khmer (Kambodja)',
            'kn_IN' => 'Kannada (Indië)',
            'ko' => 'Koreaans (Suid-Korea)',
            'ky_KG' => 'Kirgisies (Kirgistan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Litaus',
            'lv' => 'Letties',
            'mk_MK' => 'Masedonies (Noord-Macedonië)',
            'ml_IN' => 'Malabaars (Indië)',
            'mn_MN' => 'Mongools (Mongolië)',
            'mr_IN' => 'Marathi (Indië)',
            'ms' => 'Maleis',
            'my_MM' => 'Birmaans (Mianmar [Birma])',
            'ne_NP' => 'Nepalees (Nepal)',
            'nl_NL' => 'Nederlands (Nederland)',
            'no_NO' => 'Noors (Noorweë)',
            'pl_PL' => 'Pools (Pole)',
            'pt_BR' => 'Portugees (Brasilië)',
            'pt_PT' => 'Portugees (Portugal)',
            'ro' => 'Roemeens',
            'ru_RU' => 'Russies (Rusland)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slowaaks',
            'sl' => 'Sloweens',
            'sr' => 'Serwies',
            'sv_SE' => 'Sweeds (Swede)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (Indië)',
            'te_IN' => 'Teloegoe (Indië)',
            'th' => 'Thai',
            'tr_TR' => 'Turks (Turkye)',
            'uk' => 'Oekraïens',
            'vi' => 'Viëtnamees',
            'zh_CN' => 'Chinees (Vereenvoudig)',
            'zh_HK' => 'Chinees (Hongkong)',
            'zh_TW' => 'Chinees (Tradisioneel)',
            'zu' => 'Zoeloe',
        ],
        'am' => [
            'af' => 'አፍሪካንኛ',
            'ar' => 'ዓረብኛ',
            'az_AZ' => 'አዘርባጃንኛ (አዘርባጃን)',
            'be' => 'ቤላራሻኛ',
            'bg' => 'ቡልጋሪኛ',
            'bn_BD' => 'ቤንጋሊኛ (ባንግላዲሽ)',
            'ca' => 'ካታላንኛ',
            'cs_CZ' => 'ቼክኛ (ቼቺያ)',
            'da_DK' => 'ዴኒሽ (ዴንማርክ)',
            'de_DE' => 'ጀርመን (ጀርመን)',
            'el_GR' => 'ግሪክኛ (ግሪክ)',
            'en_AU' => 'እንግሊዝኛ (አውስትራልያ)',
            'en_CA' => 'እንግሊዝኛ (ካናዳ)',
            'en_GB' => 'እንግሊዝኛ (ዩናይትድ ኪንግደም)',
            'en_IN' => 'እንግሊዝኛ (ህንድ)',
            'en_SG' => 'እንግሊዝኛ (ሲንጋፖር)',
            'en_US' => 'እንግሊዝኛ (ዩናይትድ ስቴትስ)',
            'en_ZA' => 'እንግሊዝኛ (ደቡብ አፍሪካ)',
            'es_419' => 'ስፓንሽኛ (ላቲን አሜሪካ)',
            'es_ES' => 'ስፓንሽኛ (ስፔን)',
            'es_US' => 'ስፓንሽኛ (ዩናይትድ ስቴትስ)',
            'et' => 'ኢስቶኒያንኛ',
            'eu_ES' => 'ባስክኛ (ስፔን)',
            'fa' => 'ፐርሺያኛ',
            'fi_FI' => 'ፊኒሽ (ፊንላንድ)',
            'fil' => 'ፊሊፒንኛ',
            'fr_CA' => 'ፈረንሳይኛ (ካናዳ)',
            'fr_FR' => 'ፈረንሳይኛ (ፈረንሳይ)',
            'gl_ES' => 'ጋሊሺያ (ስፔን)',
            'hi_IN' => 'ሒንዱኛ (ህንድ)',
            'hr' => 'ክሮሽያንኛ',
            'hu_HU' => 'ሀንጋሪኛ (ሀንጋሪ)',
            'hy' => 'አርመናዊ (አርሜኒያ)',
            'id' => 'ኢንዶኔዥኛ',
            'is_IS' => 'አይስላንድኛ (አይስላንድ)',
            'it_IT' => 'ጣሊያንኛ (ጣሊያን)',
            'iw_IL' => 'ዕብራይስጥ﻿ (እስራኤል)',
            'ja_JP' => 'ጃፓንኛ (ጃፓን)',
            'ka_GE' => 'ጆርጂያን (ጆርጂያ)',
            'kk' => 'ካዛክኛ',
            'km_KH' => 'ክህመርኛ (ካምቦዲያ)',
            'kn_IN' => 'ካናዳኛ (ህንድ)',
            'ko' => 'ኮሪያኛ (ደቡብ ኮሪያ)',
            'ky_KG' => 'ኪርጊዝኛ (ኪርጊስታን)',
            'lo_LA' => 'ላኦኛ (ላኦስ)',
            'lt' => 'ሉቴንያንኛ',
            'lv' => 'ላትቪያን',
            'mk_MK' => 'ማሴዶንኛ (ሰሜን መቄዶንያ)',
            'ml_IN' => 'ማላያላምኛ (ህንድ)',
            'mn_MN' => 'ሞንጎሊያኛ (ሞንጎሊያ)',
            'mr_IN' => 'ማራቲኛ (ህንድ)',
            'ms' => 'ማላይኛ',
            'my_MM' => 'ቡርማኛ (ማይናማር[በርማ])',
            'ne_NP' => 'ኔፓሊኛ (ኔፓል)',
            'nl_NL' => 'ደች (ኔዘርላንድ)',
            'no_NO' => 'ኖርዌጂያን (ኖርዌይ)',
            'pl_PL' => 'ፖሊሽኛ (ፖላንድ)',
            'pt_BR' => 'ፖርቹጋልኛ (ብራዚል)',
            'pt_PT' => 'ፖርቹጋልኛ (ፖርቱጋል)',
            'ro' => 'ሮማኒያን',
            'ru_RU' => 'ራሽያኛ (ሩስያ)',
            'si_LK' => 'ሲንሃልኛ (ሲሪላንካ)',
            'sk' => 'ስሎቫክኛ',
            'sl' => 'ስሎቪኛ',
            'sr' => 'ሰርብያኛ',
            'sv_SE' => 'ስዊድንኛ (ስዊድን)',
            'sw' => 'ስዋሂሊኛ',
            'ta_IN' => 'ታሚልኛ (ህንድ)',
            'te_IN' => 'ተሉጉኛ (ህንድ)',
            'th' => 'ታይኛ',
            'tr_TR' => 'ቱርክኛ (ቱርክ)',
            'uk' => 'ዩክሬንኛ',
            'vi' => 'ቪየትናምኛ',
            'zh_CN' => 'ቻይንኛ (ቀለል ያለ)',
            'zh_HK' => 'ቻይንኛ (ሆንግ ኮንግ)',
            'zh_TW' => 'ቻይንኛ (ባህላዊ)',
            'zu' => 'ዙሉኛ',
        ],
        'ar' => [
            'af' => 'الأفريقانية',
            'am' => 'الأمهرية',
            'az_AZ' => 'الأذربيجانية (أذربيجان)',
            'be' => 'البيلاروسية',
            'bg' => 'البلغارية',
            'bn_BD' => 'البنغالية (بنغلاديش)',
            'ca' => 'الكتالانية',
            'cs_CZ' => 'التشيكية (التشيك)',
            'da_DK' => 'الدانمركية (الدانمرك)',
            'de_DE' => 'الألمانية (ألمانيا)',
            'el_GR' => 'اليونانية (اليونان)',
            'en_AU' => 'الإنجليزية (أستراليا)',
            'en_CA' => 'الإنجليزية (كندا)',
            'en_GB' => 'الإنجليزية (المملكة المتحدة)',
            'en_IN' => 'الإنجليزية (الهند)',
            'en_SG' => 'الإنجليزية (سنغافورة)',
            'en_US' => 'الإنجليزية (الولايات المتحدة)',
            'en_ZA' => 'الإنجليزية (جنوب أفريقيا)',
            'es_419' => 'الإسبانية (أمريكا اللاتينية)',
            'es_ES' => 'الإسبانية (إسبانيا)',
            'es_US' => 'الإسبانية (الولايات المتحدة)',
            'et' => 'الإستونية',
            'eu_ES' => 'الباسكية (إسبانيا)',
            'fa' => 'الفارسية',
            'fi_FI' => 'الفنلندية (فنلندا)',
            'fil' => 'الفلبينية',
            'fr_CA' => 'الفرنسية (كندا)',
            'fr_FR' => 'الفرنسية (فرنسا)',
            'gl_ES' => 'الجاليكية (إسبانيا)',
            'hi_IN' => 'الهندية (الهند)',
            'hr' => 'الكرواتية',
            'hu_HU' => 'الهنغارية (هنغاريا)',
            'hy' => 'الأرمنية (أرمينيا)',
            'id' => 'الإندونيسية',
            'is_IS' => 'الأيسلندية (آيسلندا)',
            'it_IT' => 'الإيطالية (إيطاليا)',
            'iw_IL' => 'العبرية (إسرائيل)',
            'ja_JP' => 'اليابانية (اليابان)',
            'ka_GE' => 'الجورجية (جورجيا)',
            'kk' => 'الكازاخستانية',
            'km_KH' => 'الخميرية (كمبوديا)',
            'kn_IN' => 'الكانادا (الهند)',
            'ko' => 'الكورية (كوريا الجنوبية)',
            'ky_KG' => 'القيرغيزية (قيرغيزستان)',
            'lo_LA' => 'اللاوية (لاوس)',
            'lt' => 'الليتوانية',
            'lv' => 'اللاتفية',
            'mk_MK' => 'المقدونية (مقدونيا الشمالية)',
            'ml_IN' => 'المالايالامية (الهند)',
            'mn_MN' => 'المنغولية (منغوليا)',
            'mr_IN' => 'الماراثية (الهند)',
            'ms' => 'الماليزية',
            'my_MM' => 'البورمية (ميانمار [بورما])',
            'ne_NP' => 'النيبالية (نيبال)',
            'nl_NL' => 'الهولندية (هولندا)',
            'no_NO' => 'النرويجية (النرويج)',
            'pl_PL' => 'البولندية (بولندا)',
            'pt_BR' => 'البرتغالية (البرازيل)',
            'pt_PT' => 'البرتغالية (البرتغال)',
            'ro' => 'الرومانية',
            'ru_RU' => 'الروسية (روسيا)',
            'si_LK' => 'السنهالية (سريلانكا)',
            'sk' => 'السلوفاكية',
            'sl' => 'السلوفانية',
            'sr' => 'الصربية',
            'sv_SE' => 'السويدية (السويد)',
            'sw' => 'السواحلية',
            'ta_IN' => 'التاميلية (الهند)',
            'te_IN' => 'التيلوغوية (الهند)',
            'th' => 'التايلاندية',
            'tr_TR' => 'التركية (تركيا)',
            'uk' => 'الأوكرانية',
            'vi' => 'الفيتنامية',
            'zh_CN' => 'الصينية (المبسطة)',
            'zh_HK' => 'الصينية (هونغ كونغ)',
            'zh_TW' => 'الصينية (التقليدية)',
            'zu' => 'الزولو',
        ],
        'az_AZ' => [
            'af' => 'afrikaans',
            'am' => 'amhar',
            'ar' => 'ərəb',
            'be' => 'belarus',
            'bg' => 'bolqar',
            'bn_BD' => 'benqal (Banqladeş)',
            'ca' => 'katalan',
            'cs_CZ' => 'çex (Çexiya)',
            'da_DK' => 'danimarka (Danimarka)',
            'de_DE' => 'alman (Almaniya)',
            'el_GR' => 'yunan (Yunanıstan)',
            'en_AU' => 'ingilis (Avstraliya)',
            'en_CA' => 'ingilis (Kanada)',
            'en_GB' => 'ingilis (Birləşmiş Krallıq)',
            'en_IN' => 'ingilis (Hindistan)',
            'en_SG' => 'ingilis (Sinqapur)',
            'en_US' => 'ingilis (Amerika Birləşmiş Ştatları)',
            'en_ZA' => 'ingilis (Cənub Afrika)',
            'es_419' => 'ispan (Latın Amerikası)',
            'es_ES' => 'ispan (İspaniya)',
            'es_US' => 'ispan (Amerika Birləşmiş Ştatları)',
            'et' => 'eston',
            'eu_ES' => 'bask (İspaniya)',
            'fa' => 'fars',
            'fi_FI' => 'fin (Finlandiya)',
            'fil' => 'filippin',
            'fr_CA' => 'fransız (Kanada)',
            'fr_FR' => 'fransız (Fransa)',
            'gl_ES' => 'qalisiya (İspaniya)',
            'hi_IN' => 'hind (Hindistan)',
            'hr' => 'xorvat',
            'hu_HU' => 'macar (Macarıstan)',
            'hy' => 'erməni (Ermənistan)',
            'id' => 'indoneziya',
            'is_IS' => 'island (İslandiya)',
            'it_IT' => 'italyan (İtaliya)',
            'iw_IL' => 'ivrit (İsrail)',
            'ja_JP' => 'yapon (Yaponiya)',
            'ka_GE' => 'gürcü (Gürcüstan)',
            'kk' => 'qazax',
            'km_KH' => 'kxmer (Kamboca)',
            'kn_IN' => 'kannada (Hindistan)',
            'ko' => 'koreya (Cənubi Koreya)',
            'ky_KG' => 'qırğız (Qırğızıstan)',
            'lo_LA' => 'laos (Laos)',
            'lt' => 'litva',
            'lv' => 'latış',
            'mk_MK' => 'makedon (Şimali Makedoniya)',
            'ml_IN' => 'malayalam (Hindistan)',
            'mn_MN' => 'monqol (Monqolustan)',
            'mr_IN' => 'marathi (Hindistan)',
            'ms' => 'malay',
            'my_MM' => 'birman (Myanma)',
            'ne_NP' => 'nepal (Nepal)',
            'nl_NL' => 'holland (Niderland)',
            'no_NO' => 'norveç (Norveç)',
            'pl_PL' => 'polyak (Polşa)',
            'pt_BR' => 'portuqal (Braziliya)',
            'pt_PT' => 'portuqal (Portuqaliya)',
            'ro' => 'rumın',
            'ru_RU' => 'rus (Rusiya)',
            'si_LK' => 'sinhala (Şri-Lanka)',
            'sk' => 'slovak',
            'sl' => 'sloven',
            'sr' => 'serb',
            'sv_SE' => 'isveç (İsveç)',
            'sw' => 'suahili',
            'ta_IN' => 'tamil (Hindistan)',
            'te_IN' => 'teluqu (Hindistan)',
            'th' => 'tay',
            'tr_TR' => 'türk (Türkiyə)',
            'uk' => 'ukrayna',
            'vi' => 'vyetnam',
            'zh_CN' => 'çin (sadələşmiş)',
            'zh_HK' => 'çin (Honq Konq)',
            'zh_TW' => 'çin (ənənəvi)',
            'zu' => 'zulu',
        ],
        'be' => [
            'af' => 'афрыкаанс',
            'am' => 'амхарская',
            'ar' => 'арабская',
            'az_AZ' => 'азербайджанская (Азербайджан)',
            'bg' => 'балгарская',
            'bn_BD' => 'бенгальская (Бангладэш)',
            'ca' => 'каталанская',
            'cs_CZ' => 'чэшская (Чэхія)',
            'da_DK' => 'дацкая (Данія)',
            'de_DE' => 'нямецкая (Германія)',
            'el_GR' => 'грэчаская (Грэцыя)',
            'en_AU' => 'англійская (Аўстралія)',
            'en_CA' => 'англійская (Канада)',
            'en_GB' => 'англійская (Вялікабрытанія)',
            'en_IN' => 'англійская (Індыя)',
            'en_SG' => 'англійская (Сінгапур)',
            'en_US' => 'англійская (Злучаныя Штаты)',
            'en_ZA' => 'англійская (Паўднёва-Афрыканская Рэспубліка)',
            'es_419' => 'іспанская (Лацінская Амерыка)',
            'es_ES' => 'іспанская (Іспанія)',
            'es_US' => 'іспанская (Злучаныя Штаты)',
            'et' => 'эстонская',
            'eu_ES' => 'баскская (Іспанія)',
            'fa' => 'фарсі',
            'fi_FI' => 'фінская (Фінляндыя)',
            'fil' => 'філіпінская',
            'fr_CA' => 'французская (Канада)',
            'fr_FR' => 'французская (Францыя)',
            'gl_ES' => 'галісійская (Іспанія)',
            'hi_IN' => 'хіндзі (Індыя)',
            'hr' => 'харвацкая',
            'hu_HU' => 'венгерская (Венгрыя)',
            'hy' => 'армянская (Арменія)',
            'id' => 'інданезійская',
            'is_IS' => 'ісландская (Ісландыя)',
            'it_IT' => 'італьянская (Італія)',
            'iw_IL' => 'іўрыт (Ізраіль)',
            'ja_JP' => 'японская (Японія)',
            'ka_GE' => 'грузінская (Грузія)',
            'kk' => 'казахская',
            'km_KH' => 'кхмерская (Камбоджа)',
            'kn_IN' => 'канада (Індыя)',
            'ko' => 'карэйская (Паўднёвая Карэя)',
            'ky_KG' => 'кіргізская (Кыргызстан)',
            'lo_LA' => 'лаоская (Лаос)',
            'lt' => 'літоўская',
            'lv' => 'латышская',
            'mk_MK' => 'македонская (Паўночная Македонія)',
            'ml_IN' => 'малаялам (Індыя)',
            'mn_MN' => 'мангольская (Манголія)',
            'mr_IN' => 'маратхі (Індыя)',
            'ms' => 'малайская',
            'my_MM' => 'бірманская (М’янма [Бірма])',
            'ne_NP' => 'непальская (Непал)',
            'nl_NL' => 'нідэрландская (Нідэрланды)',
            'no_NO' => 'нарвежская (Нарвегія)',
            'pl_PL' => 'польская (Польшча)',
            'pt_BR' => 'партугальская (Бразілія)',
            'pt_PT' => 'партугальская (Партугалія)',
            'ro' => 'румынская',
            'ru_RU' => 'руская (Расія)',
            'si_LK' => 'сінгальская (Шры-Ланка)',
            'sk' => 'славацкая',
            'sl' => 'славенская',
            'sr' => 'сербская',
            'sv_SE' => 'шведская (Швецыя)',
            'sw' => 'суахілі',
            'ta_IN' => 'тамільская (Індыя)',
            'te_IN' => 'тэлугу (Індыя)',
            'th' => 'тайская',
            'tr_TR' => 'турэцкая (Турцыя)',
            'uk' => 'украінская',
            'vi' => 'в’етнамская',
            'zh_CN' => 'кітайская (спрошчанае кітайскае)',
            'zh_HK' => 'кітайская (Ганконг)',
            'zh_TW' => 'кітайская (традыцыйнае кітайскае)',
            'zu' => 'зулу',
        ],
        'bg' => [
            'af' => 'африканс',
            'am' => 'амхарски',
            'ar' => 'арабски',
            'az_AZ' => 'азербайджански (Азербайджан)',
            'be' => 'беларуски',
            'bn_BD' => 'бенгалски (Бангладеш)',
            'ca' => 'каталонски',
            'cs_CZ' => 'чешки (Чехия)',
            'da_DK' => 'датски (Дания)',
            'de_DE' => 'немски (Германия)',
            'el_GR' => 'гръцки (Гърция)',
            'en_AU' => 'английски (Австралия)',
            'en_CA' => 'английски (Канада)',
            'en_GB' => 'английски (Обединеното кралство)',
            'en_IN' => 'английски (Индия)',
            'en_SG' => 'английски (Сингапур)',
            'en_US' => 'английски (Съединени щати)',
            'en_ZA' => 'английски (Южна Африка)',
            'es_419' => 'испански (Латинска Америка)',
            'es_ES' => 'испански (Испания)',
            'es_US' => 'испански (Съединени щати)',
            'et' => 'естонски',
            'eu_ES' => 'баски (Испания)',
            'fa' => 'персийски',
            'fi_FI' => 'фински (Финландия)',
            'fil' => 'филипински',
            'fr_CA' => 'френски (Канада)',
            'fr_FR' => 'френски (Франция)',
            'gl_ES' => 'галисийски (Испания)',
            'hi_IN' => 'хинди (Индия)',
            'hr' => 'хърватски',
            'hu_HU' => 'унгарски (Унгария)',
            'hy' => 'арменски (Армения)',
            'id' => 'индонезийски',
            'is_IS' => 'исландски (Исландия)',
            'it_IT' => 'италиански (Италия)',
            'iw_IL' => 'иврит (Израел)',
            'ja_JP' => 'японски (Япония)',
            'ka_GE' => 'грузински (Грузия)',
            'kk' => 'казахски',
            'km_KH' => 'кхмерски (Камбоджа)',
            'kn_IN' => 'каннада (Индия)',
            'ko' => 'корейски (Южна Корея)',
            'ky_KG' => 'киргизки (Киргизстан)',
            'lo_LA' => 'лаоски (Лаос)',
            'lt' => 'литовски',
            'lv' => 'латвийски',
            'mk_MK' => 'македонски (Северна Македония)',
            'ml_IN' => 'малаялам (Индия)',
            'mn_MN' => 'монголски (Монголия)',
            'mr_IN' => 'марати (Индия)',
            'ms' => 'малайски',
            'my_MM' => 'бирмански (Мианмар [Бирма])',
            'ne_NP' => 'непалски (Непал)',
            'nl_NL' => 'нидерландски (Нидерландия)',
            'no_NO' => 'норвежки (Норвегия)',
            'pl_PL' => 'полски (Полша)',
            'pt_BR' => 'португалски (Бразилия)',
            'pt_PT' => 'португалски (Португалия)',
            'ro' => 'румънски',
            'ru_RU' => 'руски (Русия)',
            'si_LK' => 'синхалски (Шри Ланка)',
            'sk' => 'словашки',
            'sl' => 'словенски',
            'sr' => 'сръбски',
            'sv_SE' => 'шведски (Швеция)',
            'sw' => 'суахили',
            'ta_IN' => 'тамилски (Индия)',
            'te_IN' => 'телугу (Индия)',
            'th' => 'тайски',
            'tr_TR' => 'турски (Турция)',
            'uk' => 'украински',
            'vi' => 'виетнамски',
            'zh_CN' => 'китайски (опростена)',
            'zh_HK' => 'китайски (Хонконг)',
            'zh_TW' => 'китайски (традиционна)',
            'zu' => 'зулуски',
        ],
        'bn_BD' => [
            'af' => 'আফ্রিকান',
            'am' => 'আমহারিক',
            'ar' => 'আরবী',
            'az_AZ' => 'আজারবাইজানী (আজারবাইজান)',
            'be' => 'বেলারুশিয়',
            'bg' => 'বুলগেরিয়',
            'ca' => 'কাতালান',
            'cs_CZ' => 'চেক (চেচিয়া)',
            'da_DK' => 'ডেনিশ (ডেনমার্ক)',
            'de_DE' => 'জার্মান (জার্মানি)',
            'el_GR' => 'গ্রিক (গ্রীস)',
            'en_AU' => 'ইংরেজি (অস্ট্রেলিয়া)',
            'en_CA' => 'ইংরেজি (কানাডা)',
            'en_GB' => 'ইংরেজি (যুক্তরাজ্য)',
            'en_IN' => 'ইংরেজি (ভারত)',
            'en_SG' => 'ইংরেজি (সিঙ্গাপুর)',
            'en_US' => 'ইংরেজি (মার্কিন যুক্তরাষ্ট্র)',
            'en_ZA' => 'ইংরেজি (দক্ষিণ আফ্রিকা)',
            'es_419' => 'স্প্যানিশ (ল্যাটিন আমেরিকা)',
            'es_ES' => 'স্প্যানিশ (স্পেন)',
            'es_US' => 'স্প্যানিশ (মার্কিন যুক্তরাষ্ট্র)',
            'et' => 'এস্তোনীয়',
            'eu_ES' => 'বাস্ক (স্পেন)',
            'fa' => 'ফার্সি',
            'fi_FI' => 'ফিনিশ (ফিনল্যান্ড)',
            'fil' => 'ফিলিপিনো',
            'fr_CA' => 'ফরাসি (কানাডা)',
            'fr_FR' => 'ফরাসি (ফ্রান্স)',
            'gl_ES' => 'গ্যালিশিয় (স্পেন)',
            'hi_IN' => 'হিন্দি (ভারত)',
            'hr' => 'ক্রোয়েশীয়',
            'hu_HU' => 'হাঙ্গেরীয় (হাঙ্গেরি)',
            'hy' => 'আর্মেনিয় (আর্মেনিয়া)',
            'id' => 'ইন্দোনেশীয়',
            'is_IS' => 'আইসল্যান্ডীয় (আইসল্যান্ড)',
            'it_IT' => 'ইতালিয় (ইতালি)',
            'iw_IL' => 'হিব্রু (ইজরায়েল)',
            'ja_JP' => 'জাপানি (জাপান)',
            'ka_GE' => 'জর্জিয়ান (জর্জিয়া)',
            'kk' => 'কাজাখ',
            'km_KH' => 'খমের (কম্বোডিয়া)',
            'kn_IN' => 'কন্নড় (ভারত)',
            'ko' => 'কোরিয়ান (দক্ষিণ কোরিয়া)',
            'ky_KG' => 'কির্গিজ (কিরগিজিস্তান)',
            'lo_LA' => 'লাও (লাওস)',
            'lt' => 'লিথুয়েনীয়',
            'lv' => 'লাত্‌ভীয়',
            'mk_MK' => 'ম্যাসিডোনীয় (উত্তর ম্যাসেডোনিয়া)',
            'ml_IN' => 'মালায়ালাম (ভারত)',
            'mn_MN' => 'মঙ্গোলিয় (মঙ্গোলিয়া)',
            'mr_IN' => 'মারাঠি (ভারত)',
            'ms' => 'মালয়',
            'my_MM' => 'বর্মি (মায়ানমার [বার্মা])',
            'ne_NP' => 'নেপালী (নেপাল)',
            'nl_NL' => 'ওলন্দাজ (নেদারল্যান্ডস)',
            'no_NO' => 'নরওয়েজীয় (নরওয়ে)',
            'pl_PL' => 'পোলিশ (পোল্যান্ড)',
            'pt_BR' => 'পর্তুগীজ (ব্রাজিল)',
            'pt_PT' => 'পর্তুগীজ (পর্তুগাল)',
            'ro' => 'রোমানীয়',
            'ru_RU' => 'রুশ (রাশিয়া)',
            'si_LK' => 'সিংহলী (শ্রীলঙ্কা)',
            'sk' => 'স্লোভাক',
            'sl' => 'স্লোভেনীয়',
            'sr' => 'সার্বীয়',
            'sv_SE' => 'সুইডিশ (সুইডেন)',
            'sw' => 'সোয়াহিলি',
            'ta_IN' => 'তামিল (ভারত)',
            'te_IN' => 'তেলুগু (ভারত)',
            'th' => 'থাই',
            'tr_TR' => 'তুর্কী (তুরস্ক)',
            'uk' => 'ইউক্রেনীয়',
            'vi' => 'ভিয়েতনামী',
            'zh_CN' => 'চীনা (সরলীকৃত)',
            'zh_HK' => 'চীনা (হংকং)',
            'zh_TW' => 'চীনা (ঐতিহ্যবাহী)',
            'zu' => 'জুলু',
        ],
        'ca' => [
            'af' => 'afrikaans',
            'am' => 'amhàric',
            'ar' => 'àrab',
            'az_AZ' => 'azerbaidjanès (Azerbaidjan)',
            'be' => 'belarús',
            'bg' => 'búlgar',
            'bn_BD' => 'bengalí (Bangladesh)',
            'cs_CZ' => 'txec (Txèquia)',
            'da_DK' => 'danès (Dinamarca)',
            'de_DE' => 'alemany (Alemanya)',
            'el_GR' => 'grec (Grècia)',
            'en_AU' => 'anglès (Austràlia)',
            'en_CA' => 'anglès (Canadà)',
            'en_GB' => 'anglès (Regne Unit)',
            'en_IN' => 'anglès (Índia)',
            'en_SG' => 'anglès (Singapur)',
            'en_US' => 'anglès (Estats Units)',
            'en_ZA' => 'anglès (República de Sud-àfrica)',
            'es_419' => 'espanyol (Amèrica Llatina)',
            'es_ES' => 'espanyol (Espanya)',
            'es_US' => 'espanyol (Estats Units)',
            'et' => 'estonià',
            'eu_ES' => 'basc (Espanya)',
            'fa' => 'persa',
            'fi_FI' => 'finès (Finlàndia)',
            'fil' => 'filipí',
            'fr_CA' => 'francès (Canadà)',
            'fr_FR' => 'francès (França)',
            'gl_ES' => 'gallec (Espanya)',
            'hi_IN' => 'hindi (Índia)',
            'hr' => 'croat',
            'hu_HU' => 'hongarès (Hongria)',
            'hy' => 'armeni (Armènia)',
            'id' => 'indonesi',
            'is_IS' => 'islandès (Islàndia)',
            'it_IT' => 'italià (Itàlia)',
            'iw_IL' => 'hebreu (Israel)',
            'ja_JP' => 'japonès (Japó)',
            'ka_GE' => 'georgià (Geòrgia)',
            'kk' => 'kazakh',
            'km_KH' => 'khmer (Cambodja)',
            'kn_IN' => 'kannada (Índia)',
            'ko' => 'coreà (Corea del Sud)',
            'ky_KG' => 'kirguís (Kirguizistan)',
            'lo_LA' => 'laosià (Laos)',
            'lt' => 'lituà',
            'lv' => 'letó',
            'mk_MK' => 'macedoni (Macedònia del Nord)',
            'ml_IN' => 'malaiàlam (Índia)',
            'mn_MN' => 'mongol (Mongòlia)',
            'mr_IN' => 'marathi (Índia)',
            'ms' => 'malai',
            'my_MM' => 'birmà (Myanmar [Birmània])',
            'ne_NP' => 'nepalès (Nepal)',
            'nl_NL' => 'neerlandès (Països Baixos)',
            'no_NO' => 'noruec (Noruega)',
            'pl_PL' => 'polonès (Polònia)',
            'pt_BR' => 'portuguès (Brasil)',
            'pt_PT' => 'portuguès (Portugal)',
            'ro' => 'romanès',
            'ru_RU' => 'rus (Rússia)',
            'si_LK' => 'singalès (Sri Lanka)',
            'sk' => 'eslovac',
            'sl' => 'eslovè',
            'sr' => 'serbi',
            'sv_SE' => 'suec (Suècia)',
            'sw' => 'suahili',
            'ta_IN' => 'tàmil (Índia)',
            'te_IN' => 'telugu (Índia)',
            'th' => 'tai',
            'tr_TR' => 'turc (Turquia)',
            'uk' => 'ucraïnès',
            'vi' => 'vietnamita',
            'zh_CN' => 'xinès (simplificat)',
            'zh_HK' => 'xinès (Hong Kong)',
            'zh_TW' => 'xinès (tradicional)',
            'zu' => 'zulu',
        ],
        'cs_CZ' => [
            'af' => 'Afrikánština',
            'am' => 'Amharština',
            'ar' => 'Arabština',
            'az_AZ' => 'Ázerbájdžánština (Ázerbájdžán)',
            'be' => 'Běloruština',
            'bg' => 'Bulharština',
            'bn_BD' => 'Bengálština (Bangladéš)',
            'ca' => 'Katalánština',
            'da_DK' => 'Dánština (Dánsko)',
            'de_DE' => 'Němčina (Německo)',
            'el_GR' => 'Řečtina (Řecko)',
            'en_AU' => 'Angličtina (Austrálie)',
            'en_CA' => 'Angličtina (Kanada)',
            'en_GB' => 'Angličtina (Spojené království)',
            'en_IN' => 'Angličtina (Indie)',
            'en_SG' => 'Angličtina (Singapur)',
            'en_US' => 'Angličtina (Spojené státy)',
            'en_ZA' => 'Angličtina (Jihoafrická republika)',
            'es_419' => 'Španělština (Latinská Amerika)',
            'es_ES' => 'Španělština (Španělsko)',
            'es_US' => 'Španělština (Spojené státy)',
            'et' => 'Estonština',
            'eu_ES' => 'Baskičtina (Španělsko)',
            'fa' => 'Perština',
            'fi_FI' => 'Finština (Finsko)',
            'fil' => 'Filipínština',
            'fr_CA' => 'Francouzština (Kanada)',
            'fr_FR' => 'Francouzština (Francie)',
            'gl_ES' => 'Galicijština (Španělsko)',
            'hi_IN' => 'Hindština (Indie)',
            'hr' => 'Chorvatština',
            'hu_HU' => 'Maďarština (Maďarsko)',
            'hy' => 'Arménština (Arménie)',
            'id' => 'Indonéština',
            'is_IS' => 'Islandština (Island)',
            'it_IT' => 'Italština (Itálie)',
            'iw_IL' => 'Hebrejština (Izrael)',
            'ja_JP' => 'Japonština (Japonsko)',
            'ka_GE' => 'Gruzínština (Gruzie)',
            'kk' => 'Kazaština',
            'km_KH' => 'Khmérština (Kambodža)',
            'kn_IN' => 'Kannadština (Indie)',
            'ko' => 'Korejština (Jižní Korea)',
            'ky_KG' => 'Kyrgyzština (Kyrgyzstán)',
            'lo_LA' => 'Laoština (Laos)',
            'lt' => 'Litevština',
            'lv' => 'Lotyština',
            'mk_MK' => 'Makedonština (Severní Makedonie)',
            'ml_IN' => 'Malajálamština (Indie)',
            'mn_MN' => 'Mongolština (Mongolsko)',
            'mr_IN' => 'Maráthština (Indie)',
            'ms' => 'Malajština',
            'my_MM' => 'Barmština (Myanmar [Barma])',
            'ne_NP' => 'Nepálština (Nepál)',
            'nl_NL' => 'Nizozemština (Nizozemsko)',
            'no_NO' => 'Norština (Norsko)',
            'pl_PL' => 'Polština (Polsko)',
            'pt_BR' => 'Portugalština (Brazílie)',
            'pt_PT' => 'Portugalština (Portugalsko)',
            'ro' => 'Rumunština',
            'ru_RU' => 'Ruština (Rusko)',
            'si_LK' => 'Sinhálština (Srí Lanka)',
            'sk' => 'Slovenština',
            'sl' => 'Slovinština',
            'sr' => 'Srbština',
            'sv_SE' => 'Švédština (Švédsko)',
            'sw' => 'Svahilština',
            'ta_IN' => 'Tamilština (Indie)',
            'te_IN' => 'Telugština (Indie)',
            'th' => 'Thajština',
            'tr_TR' => 'Turečtina (Turecko)',
            'uk' => 'Ukrajinština',
            'vi' => 'Vietnamština',
            'zh_CN' => 'Čínština (zjednodušené)',
            'zh_HK' => 'Čínština (Hongkong)',
            'zh_TW' => 'Čínština (tradiční)',
            'zu' => 'Zuluština',
        ],
        'da_DK' => [
            'af' => 'Afrikaans',
            'am' => 'Amharisk',
            'ar' => 'Arabisk',
            'az_AZ' => 'Aserbajdsjansk (Aserbajdsjan)',
            'be' => 'Hviderussisk',
            'bg' => 'Bulgarsk',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Catalansk',
            'cs_CZ' => 'Tjekkisk (Tjekkiet)',
            'de_DE' => 'Tysk (Tyskland)',
            'el_GR' => 'Græsk (Grækenland)',
            'en_AU' => 'Engelsk (Australien)',
            'en_CA' => 'Engelsk (Canada)',
            'en_GB' => 'Engelsk (Storbritannien)',
            'en_IN' => 'Engelsk (Indien)',
            'en_SG' => 'Engelsk (Singapore)',
            'en_US' => 'Engelsk (USA)',
            'en_ZA' => 'Engelsk (Sydafrika)',
            'es_419' => 'Spansk (Latinamerika)',
            'es_ES' => 'Spansk (Spanien)',
            'es_US' => 'Spansk (USA)',
            'et' => 'Estisk',
            'eu_ES' => 'Baskisk (Spanien)',
            'fa' => 'Persisk',
            'fi_FI' => 'Finsk (Finland)',
            'fil' => 'Filippinsk',
            'fr_CA' => 'Fransk (Canada)',
            'fr_FR' => 'Fransk (Frankrig)',
            'gl_ES' => 'Galicisk (Spanien)',
            'hi_IN' => 'Hindi (Indien)',
            'hr' => 'Kroatisk',
            'hu_HU' => 'Ungarsk (Ungarn)',
            'hy' => 'Armensk (Armenien)',
            'id' => 'Indonesisk',
            'is_IS' => 'Islandsk (Island)',
            'it_IT' => 'Italiensk (Italien)',
            'iw_IL' => 'Hebraisk (Israel)',
            'ja_JP' => 'Japansk (Japan)',
            'ka_GE' => 'Georgisk (Georgien)',
            'kk' => 'Kasakhisk',
            'km_KH' => 'Khmer (Cambodja)',
            'kn_IN' => 'Kannada (Indien)',
            'ko' => 'Koreansk (Sydkorea)',
            'ky_KG' => 'Kirgisisk (Kirgisistan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Litauisk',
            'lv' => 'Lettisk',
            'mk_MK' => 'Makedonsk (Nordmakedonien)',
            'ml_IN' => 'Malayalam (Indien)',
            'mn_MN' => 'Mongolsk (Mongoliet)',
            'mr_IN' => 'Marathisk (Indien)',
            'ms' => 'Malajisk',
            'my_MM' => 'Burmesisk (Myanmar [Burma])',
            'ne_NP' => 'Nepalesisk (Nepal)',
            'nl_NL' => 'Hollandsk (Holland)',
            'no_NO' => 'Norsk (Norge)',
            'pl_PL' => 'Polsk (Polen)',
            'pt_BR' => 'Portugisisk (Brasilien)',
            'pt_PT' => 'Portugisisk (Portugal)',
            'ro' => 'Rumænsk',
            'ru_RU' => 'Russisk (Rusland)',
            'si_LK' => 'Singalesisk (Sri Lanka)',
            'sk' => 'Slovakisk',
            'sl' => 'Slovensk',
            'sr' => 'Serbisk',
            'sv_SE' => 'Svensk (Sverige)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (Indien)',
            'te_IN' => 'Telugu (Indien)',
            'th' => 'Thai',
            'tr_TR' => 'Tyrkisk (Tyrkiet)',
            'uk' => 'Ukrainsk',
            'vi' => 'Vietnamesisk',
            'zh_CN' => 'Kinesisk (forenklet)',
            'zh_HK' => 'Kinesisk (Hongkong)',
            'zh_TW' => 'Kinesisk (traditionelt)',
            'zu' => 'Zulu',
        ],
        'de_DE' => [
            'af' => 'Afrikaans',
            'am' => 'Amharisch',
            'ar' => 'Arabisch',
            'az_AZ' => 'Aserbaidschanisch (Aserbaidschan)',
            'be' => 'Weißrussisch',
            'bg' => 'Bulgarisch',
            'bn_BD' => 'Bengalisch (Bangladesch)',
            'ca' => 'Katalanisch',
            'cs_CZ' => 'Tschechisch (Tschechien)',
            'da_DK' => 'Dänisch (Dänemark)',
            'el_GR' => 'Griechisch (Griechenland)',
            'en_AU' => 'Englisch (Australien)',
            'en_CA' => 'Englisch (Kanada)',
            'en_GB' => 'Englisch (Vereinigtes Königreich)',
            'en_IN' => 'Englisch (Indien)',
            'en_SG' => 'Englisch (Singapur)',
            'en_US' => 'Englisch (Vereinigte Staaten)',
            'en_ZA' => 'Englisch (Südafrika)',
            'es_419' => 'Spanisch (Lateinamerika)',
            'es_ES' => 'Spanisch (Spanien)',
            'es_US' => 'Spanisch (Vereinigte Staaten)',
            'et' => 'Estnisch',
            'eu_ES' => 'Baskisch (Spanien)',
            'fa' => 'Persisch',
            'fi_FI' => 'Finnisch (Finnland)',
            'fil' => 'Filipino',
            'fr_CA' => 'Französisch (Kanada)',
            'fr_FR' => 'Französisch (Frankreich)',
            'gl_ES' => 'Galicisch (Spanien)',
            'hi_IN' => 'Hindi (Indien)',
            'hr' => 'Kroatisch',
            'hu_HU' => 'Ungarisch (Ungarn)',
            'hy' => 'Armenisch (Armenien)',
            'id' => 'Indonesisch',
            'is_IS' => 'Isländisch (Island)',
            'it_IT' => 'Italienisch (Italien)',
            'iw_IL' => 'Hebräisch (Israel)',
            'ja_JP' => 'Japanisch (Japan)',
            'ka_GE' => 'Georgisch (Georgien)',
            'kk' => 'Kasachisch',
            'km_KH' => 'Khmer (Kambodscha)',
            'kn_IN' => 'Kannada (Indien)',
            'ko' => 'Koreanisch (Südkorea)',
            'ky_KG' => 'Kirgisisch (Kirgisistan)',
            'lo_LA' => 'Laotisch (Laos)',
            'lt' => 'Litauisch',
            'lv' => 'Lettisch',
            'mk_MK' => 'Mazedonisch (Nordmazedonien)',
            'ml_IN' => 'Malayalam (Indien)',
            'mn_MN' => 'Mongolisch (Mongolei)',
            'mr_IN' => 'Marathi (Indien)',
            'ms' => 'Malaiisch',
            'my_MM' => 'Birmanisch (Myanmar)',
            'ne_NP' => 'Nepalesisch (Nepal)',
            'nl_NL' => 'Niederländisch (Niederlande)',
            'no_NO' => 'Norwegisch (Norwegen)',
            'pl_PL' => 'Polnisch (Polen)',
            'pt_BR' => 'Portugiesisch (Brasilien)',
            'pt_PT' => 'Portugiesisch (Portugal)',
            'ro' => 'Rumänisch',
            'ru_RU' => 'Russisch (Russland)',
            'si_LK' => 'Singhalesisch (Sri Lanka)',
            'sk' => 'Slowakisch',
            'sl' => 'Slowenisch',
            'sr' => 'Serbisch',
            'sv_SE' => 'Schwedisch (Schweden)',
            'sw' => 'Suaheli',
            'ta_IN' => 'Tamil (Indien)',
            'te_IN' => 'Telugu (Indien)',
            'th' => 'Thailändisch',
            'tr_TR' => 'Türkisch (Türkei)',
            'uk' => 'Ukrainisch',
            'vi' => 'Vietnamesisch',
            'zh_CN' => 'Chinesisch (Vereinfacht)',
            'zh_HK' => 'Chinesisch (Hongkong)',
            'zh_TW' => 'Chinesisch (Traditionell)',
            'zu' => 'Zulu',
        ],
        'el_GR' => [
            'af' => 'Αφρικάανς',
            'am' => 'Αμχαρικά',
            'ar' => 'Αραβικά',
            'az_AZ' => 'Αζερμπαϊτζανικά (Αζερμπαϊτζάν)',
            'be' => 'Λευκορωσικά',
            'bg' => 'Βουλγαρικά',
            'bn_BD' => 'Βεγγαλικά (Μπανγκλαντές)',
            'ca' => 'Καταλανικά',
            'cs_CZ' => 'Τσεχικά (Τσεχία)',
            'da_DK' => 'Δανικά (Δανία)',
            'de_DE' => 'Γερμανικά (Γερμανία)',
            'en_AU' => 'Αγγλικά (Αυστραλία)',
            'en_CA' => 'Αγγλικά (Καναδάς)',
            'en_GB' => 'Αγγλικά (Ηνωμένο Βασίλειο)',
            'en_IN' => 'Αγγλικά (Ινδία)',
            'en_SG' => 'Αγγλικά (Σιγκαπούρη)',
            'en_US' => 'Αγγλικά (Ηνωμένες Πολιτείες)',
            'en_ZA' => 'Αγγλικά (Νότια Αφρική)',
            'es_419' => 'Ισπανικά (Λατινική Αμερική)',
            'es_ES' => 'Ισπανικά (Ισπανία)',
            'es_US' => 'Ισπανικά (Ηνωμένες Πολιτείες)',
            'et' => 'Εσθονικά',
            'eu_ES' => 'Βασκικά (Ισπανία)',
            'fa' => 'Περσικά',
            'fi_FI' => 'Φινλανδικά (Φινλανδία)',
            'fil' => 'Φιλιππινικά',
            'fr_CA' => 'Γαλλικά (Καναδάς)',
            'fr_FR' => 'Γαλλικά (Γαλλία)',
            'gl_ES' => 'Γαλικιανά (Ισπανία)',
            'hi_IN' => 'Χίντι (Ινδία)',
            'hr' => 'Κροατικά',
            'hu_HU' => 'Ουγγρικά (Ουγγαρία)',
            'hy' => 'Αρμενικά (Αρμενία)',
            'id' => 'Ινδονησιακά',
            'is_IS' => 'Ισλανδικά (Ισλανδία)',
            'it_IT' => 'Ιταλικά (Ιταλία)',
            'iw_IL' => 'Εβραϊκά (Ισραήλ)',
            'ja_JP' => 'Ιαπωνικά (Ιαπωνία)',
            'ka_GE' => 'Γεωργιανά (Γεωργία)',
            'kk' => 'Καζακικά',
            'km_KH' => 'Χμερ (Καμπότζη)',
            'kn_IN' => 'Κανάντα (Ινδία)',
            'ko' => 'Κορεατικά (Νότια Κορέα)',
            'ky_KG' => 'Κιργιζικά (Κιργιστάν)',
            'lo_LA' => 'Λαοτινά (Λάος)',
            'lt' => 'Λιθουανικά',
            'lv' => 'Λετονικά',
            'mk_MK' => 'Μακεδονικά (Βόρεια Μακεδονία)',
            'ml_IN' => 'Μαλαγιαλαμικά (Ινδία)',
            'mn_MN' => 'Μογγολικά (Μογγολία)',
            'mr_IN' => 'Μαραθικά (Ινδία)',
            'ms' => 'Μαλαισιανά',
            'my_MM' => 'Βιρμανικά (Μιανμάρ [Βιρμανία])',
            'ne_NP' => 'Νεπαλικά (Νεπάλ)',
            'nl_NL' => 'Ολλανδικά (Ολλανδία)',
            'no_NO' => 'Νορβηγικά (Νορβηγία)',
            'pl_PL' => 'Πολωνικά (Πολωνία)',
            'pt_BR' => 'Πορτογαλικά (Βραζιλία)',
            'pt_PT' => 'Πορτογαλικά (Πορτογαλία)',
            'ro' => 'Ρουμανικά',
            'ru_RU' => 'Ρωσικά (Ρωσία)',
            'si_LK' => 'Σινχαλεζικά (Σρι Λάνκα)',
            'sk' => 'Σλοβακικά',
            'sl' => 'Σλοβενικά',
            'sr' => 'Σερβικά',
            'sv_SE' => 'Σουηδικά (Σουηδία)',
            'sw' => 'Σουαχίλι',
            'ta_IN' => 'Ταμιλικά (Ινδία)',
            'te_IN' => 'Τελούγκου (Ινδία)',
            'th' => 'Ταϊλανδικά',
            'tr_TR' => 'Τουρκικά (Τουρκία)',
            'uk' => 'Ουκρανικά',
            'vi' => 'Βιετναμικά',
            'zh_CN' => 'Κινεζικά (Απλοποιημένο)',
            'zh_HK' => 'Κινεζικά (Χονγκ Κονγκ)',
            'zh_TW' => 'Κινεζικά (Παραδοσιακό)',
            'zu' => 'Ζουλού',
        ],
        'en_AU' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arabic',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusian',
            'bg' => 'Bulgarian',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Danish (Denmark)',
            'de_DE' => 'German (Germany)',
            'el_GR' => 'Greek (Greece)',
            'es_419' => 'Spanish (Latin America)',
            'es_ES' => 'Spanish (Spain)',
            'es_US' => 'Spanish (United States)',
            'et' => 'Estonian',
            'eu_ES' => 'Basque (Spain)',
            'fa' => 'Persian',
            'fi_FI' => 'Finnish (Finland)',
            'fil' => 'Filipino',
            'fr_CA' => 'French (Canada)',
            'fr_FR' => 'French (France)',
            'gl_ES' => 'Galician (Spain)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatian',
            'hu_HU' => 'Hungarian (Hungary)',
            'hy' => 'Armenian (Armenia)',
            'id' => 'Indonesian',
            'is_IS' => 'Icelandic (Iceland)',
            'it_IT' => 'Italian (Italy)',
            'iw_IL' => 'Hebrew (Israel)',
            'ja_JP' => 'Japanese (Japan)',
            'ka_GE' => 'Georgian (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korean (South Korea)',
            'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lithuanian',
            'lv' => 'Latvian',
            'mk_MK' => 'Macedonian (North Macedonia)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolian (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malay',
            'my_MM' => 'Burmese (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Dutch (Netherlands)',
            'no_NO' => 'Norwegian (Norway)',
            'pl_PL' => 'Polish (Poland)',
            'pt_BR' => 'Portuguese (Brazil)',
            'pt_PT' => 'Portuguese (Portugal)',
            'ro' => 'Romanian',
            'ru_RU' => 'Russian (Russia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenian',
            'sr' => 'Serbian',
            'sv_SE' => 'Swedish (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turkish (Turkey)',
            'uk' => 'Ukrainian',
            'vi' => 'Vietnamese',
            'zh_CN' => 'Chinese (Simplified)',
            'zh_HK' => 'Chinese (Hong Kong)',
            'zh_TW' => 'Chinese (Traditional)',
            'zu' => 'Zulu',
        ],
        'en_CA' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arabic',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusian',
            'bg' => 'Bulgarian',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Danish (Denmark)',
            'de_DE' => 'German (Germany)',
            'el_GR' => 'Greek (Greece)',
            'es_419' => 'Spanish (Latin America)',
            'es_ES' => 'Spanish (Spain)',
            'es_US' => 'Spanish (United States)',
            'et' => 'Estonian',
            'eu_ES' => 'Basque (Spain)',
            'fa' => 'Persian',
            'fi_FI' => 'Finnish (Finland)',
            'fil' => 'Filipino',
            'fr_CA' => 'French (Canada)',
            'fr_FR' => 'French (France)',
            'gl_ES' => 'Galician (Spain)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatian',
            'hu_HU' => 'Hungarian (Hungary)',
            'hy' => 'Armenian (Armenia)',
            'id' => 'Indonesian',
            'is_IS' => 'Icelandic (Iceland)',
            'it_IT' => 'Italian (Italy)',
            'iw_IL' => 'Hebrew (Israel)',
            'ja_JP' => 'Japanese (Japan)',
            'ka_GE' => 'Georgian (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korean (South Korea)',
            'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lithuanian',
            'lv' => 'Latvian',
            'mk_MK' => 'Macedonian (North Macedonia)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolian (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malay',
            'my_MM' => 'Burmese (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Dutch (Netherlands)',
            'no_NO' => 'Norwegian (Norway)',
            'pl_PL' => 'Polish (Poland)',
            'pt_BR' => 'Portuguese (Brazil)',
            'pt_PT' => 'Portuguese (Portugal)',
            'ro' => 'Romanian',
            'ru_RU' => 'Russian (Russia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenian',
            'sr' => 'Serbian',
            'sv_SE' => 'Swedish (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turkish (Turkey)',
            'uk' => 'Ukrainian',
            'vi' => 'Vietnamese',
            'zh_CN' => 'Chinese (Simplified)',
            'zh_HK' => 'Chinese (Hong Kong)',
            'zh_TW' => 'Chinese (Traditional)',
            'zu' => 'Zulu',
        ],
        'en_GB' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arabic',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusian',
            'bg' => 'Bulgarian',
            'bn_BD' => 'Bangla (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Danish (Denmark)',
            'de_DE' => 'German (Germany)',
            'el_GR' => 'Greek (Greece)',
            'es_419' => 'Spanish (Latin America)',
            'es_ES' => 'Spanish (Spain)',
            'es_US' => 'Spanish (United States)',
            'et' => 'Estonian',
            'eu_ES' => 'Basque (Spain)',
            'fa' => 'Persian',
            'fi_FI' => 'Finnish (Finland)',
            'fil' => 'Filipino',
            'fr_CA' => 'French (Canada)',
            'fr_FR' => 'French (France)',
            'gl_ES' => 'Galician (Spain)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatian',
            'hu_HU' => 'Hungarian (Hungary)',
            'hy' => 'Armenian (Armenia)',
            'id' => 'Indonesian',
            'is_IS' => 'Icelandic (Iceland)',
            'it_IT' => 'Italian (Italy)',
            'iw_IL' => 'Hebrew (Israel)',
            'ja_JP' => 'Japanese (Japan)',
            'ka_GE' => 'Georgian (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korean (South Korea)',
            'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lithuanian',
            'lv' => 'Latvian',
            'mk_MK' => 'Macedonian (North Macedonia)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolian (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malay',
            'my_MM' => 'Burmese (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Dutch (Netherlands)',
            'no_NO' => 'Norwegian (Norway)',
            'pl_PL' => 'Polish (Poland)',
            'pt_BR' => 'Portuguese (Brazil)',
            'pt_PT' => 'Portuguese (Portugal)',
            'ro' => 'Romanian',
            'ru_RU' => 'Russian (Russia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenian',
            'sr' => 'Serbian',
            'sv_SE' => 'Swedish (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turkish (Turkey)',
            'uk' => 'Ukrainian',
            'vi' => 'Vietnamese',
            'zh_CN' => 'Chinese (Simplified)',
            'zh_HK' => 'Chinese (Hong Kong)',
            'zh_TW' => 'Chinese (Traditional)',
            'zu' => 'Zulu',
        ],
        'en_IN' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arabic',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusian',
            'bg' => 'Bulgarian',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Danish (Denmark)',
            'de_DE' => 'German (Germany)',
            'el_GR' => 'Greek (Greece)',
            'es_419' => 'Spanish (Latin America)',
            'es_ES' => 'Spanish (Spain)',
            'es_US' => 'Spanish (United States)',
            'et' => 'Estonian',
            'eu_ES' => 'Basque (Spain)',
            'fa' => 'Persian',
            'fi_FI' => 'Finnish (Finland)',
            'fil' => 'Filipino',
            'fr_CA' => 'French (Canada)',
            'fr_FR' => 'French (France)',
            'gl_ES' => 'Galician (Spain)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatian',
            'hu_HU' => 'Hungarian (Hungary)',
            'hy' => 'Armenian (Armenia)',
            'id' => 'Indonesian',
            'is_IS' => 'Icelandic (Iceland)',
            'it_IT' => 'Italian (Italy)',
            'iw_IL' => 'Hebrew (Israel)',
            'ja_JP' => 'Japanese (Japan)',
            'ka_GE' => 'Georgian (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korean (South Korea)',
            'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lithuanian',
            'lv' => 'Latvian',
            'mk_MK' => 'Macedonian (North Macedonia)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolian (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malay',
            'my_MM' => 'Burmese (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Dutch (Netherlands)',
            'no_NO' => 'Norwegian (Norway)',
            'pl_PL' => 'Polish (Poland)',
            'pt_BR' => 'Portuguese (Brazil)',
            'pt_PT' => 'Portuguese (Portugal)',
            'ro' => 'Romanian',
            'ru_RU' => 'Russian (Russia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenian',
            'sr' => 'Serbian',
            'sv_SE' => 'Swedish (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turkish (Turkey)',
            'uk' => 'Ukrainian',
            'vi' => 'Vietnamese',
            'zh_CN' => 'Chinese (Simplified)',
            'zh_HK' => 'Chinese (Hong Kong)',
            'zh_TW' => 'Chinese (Traditional)',
            'zu' => 'Zulu',
        ],
        'en_SG' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arabic',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusian',
            'bg' => 'Bulgarian',
            'bn_BD' => 'Bangla (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Danish (Denmark)',
            'de_DE' => 'German (Germany)',
            'el_GR' => 'Greek (Greece)',
            'es_419' => 'Spanish (Latin America)',
            'es_ES' => 'Spanish (Spain)',
            'es_US' => 'Spanish (United States)',
            'et' => 'Estonian',
            'eu_ES' => 'Basque (Spain)',
            'fa' => 'Persian',
            'fi_FI' => 'Finnish (Finland)',
            'fil' => 'Filipino',
            'fr_CA' => 'French (Canada)',
            'fr_FR' => 'French (France)',
            'gl_ES' => 'Galician (Spain)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatian',
            'hu_HU' => 'Hungarian (Hungary)',
            'hy' => 'Armenian (Armenia)',
            'id' => 'Indonesian',
            'is_IS' => 'Icelandic (Iceland)',
            'it_IT' => 'Italian (Italy)',
            'iw_IL' => 'Hebrew (Israel)',
            'ja_JP' => 'Japanese (Japan)',
            'ka_GE' => 'Georgian (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korean (South Korea)',
            'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lithuanian',
            'lv' => 'Latvian',
            'mk_MK' => 'Macedonian (North Macedonia)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolian (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malay',
            'my_MM' => 'Burmese (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Dutch (Netherlands)',
            'no_NO' => 'Norwegian (Norway)',
            'pl_PL' => 'Polish (Poland)',
            'pt_BR' => 'Portuguese (Brazil)',
            'pt_PT' => 'Portuguese (Portugal)',
            'ro' => 'Romanian',
            'ru_RU' => 'Russian (Russia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenian',
            'sr' => 'Serbian',
            'sv_SE' => 'Swedish (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turkish (Turkey)',
            'uk' => 'Ukrainian',
            'vi' => 'Vietnamese',
            'zh_CN' => 'Chinese (Simplified)',
            'zh_HK' => 'Chinese (Hong Kong)',
            'zh_TW' => 'Chinese (Traditional)',
            'zu' => 'Zulu',
        ],
        'en_US' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arabic',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusian',
            'bg' => 'Bulgarian',
            'bn_BD' => 'Bangla (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Danish (Denmark)',
            'de_DE' => 'German (Germany)',
            'el_GR' => 'Greek (Greece)',
            'es_419' => 'Spanish (Latin America)',
            'es_ES' => 'Spanish (Spain)',
            'es_US' => 'Spanish (United States)',
            'et' => 'Estonian',
            'eu_ES' => 'Basque (Spain)',
            'fa' => 'Persian',
            'fi_FI' => 'Finnish (Finland)',
            'fil' => 'Filipino',
            'fr_CA' => 'French (Canada)',
            'fr_FR' => 'French (France)',
            'gl_ES' => 'Galician (Spain)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatian',
            'hu_HU' => 'Hungarian (Hungary)',
            'hy' => 'Armenian (Armenia)',
            'id' => 'Indonesian',
            'is_IS' => 'Icelandic (Iceland)',
            'it_IT' => 'Italian (Italy)',
            'iw_IL' => 'Hebrew (Israel)',
            'ja_JP' => 'Japanese (Japan)',
            'ka_GE' => 'Georgian (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korean (South Korea)',
            'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lithuanian',
            'lv' => 'Latvian',
            'mk_MK' => 'Macedonian (North Macedonia)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolian (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malay',
            'my_MM' => 'Burmese (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Dutch (Netherlands)',
            'no_NO' => 'Norwegian (Norway)',
            'pl_PL' => 'Polish (Poland)',
            'pt_BR' => 'Portuguese (Brazil)',
            'pt_PT' => 'Portuguese (Portugal)',
            'ro' => 'Romanian',
            'ru_RU' => 'Russian (Russia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenian',
            'sr' => 'Serbian',
            'sv_SE' => 'Swedish (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turkish (Turkey)',
            'uk' => 'Ukrainian',
            'vi' => 'Vietnamese',
            'zh_CN' => 'Chinese (Simplified)',
            'zh_HK' => 'Chinese (Hong Kong)',
            'zh_TW' => 'Chinese (Traditional)',
            'zu' => 'Zulu',
        ],
        'en_ZA' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arabic',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusian',
            'bg' => 'Bulgarian',
            'bn_BD' => 'Bangla (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Danish (Denmark)',
            'de_DE' => 'German (Germany)',
            'el_GR' => 'Greek (Greece)',
            'es_419' => 'Spanish (Latin America)',
            'es_ES' => 'Spanish (Spain)',
            'es_US' => 'Spanish (United States)',
            'et' => 'Estonian',
            'eu_ES' => 'Basque (Spain)',
            'fa' => 'Persian',
            'fi_FI' => 'Finnish (Finland)',
            'fil' => 'Filipino',
            'fr_CA' => 'French (Canada)',
            'fr_FR' => 'French (France)',
            'gl_ES' => 'Galician (Spain)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatian',
            'hu_HU' => 'Hungarian (Hungary)',
            'hy' => 'Armenian (Armenia)',
            'id' => 'Indonesian',
            'is_IS' => 'Icelandic (Iceland)',
            'it_IT' => 'Italian (Italy)',
            'iw_IL' => 'Hebrew (Israel)',
            'ja_JP' => 'Japanese (Japan)',
            'ka_GE' => 'Georgian (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korean (South Korea)',
            'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lithuanian',
            'lv' => 'Latvian',
            'mk_MK' => 'Macedonian (North Macedonia)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolian (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malay',
            'my_MM' => 'Burmese (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Dutch (Netherlands)',
            'no_NO' => 'Norwegian (Norway)',
            'pl_PL' => 'Polish (Poland)',
            'pt_BR' => 'Portuguese (Brazil)',
            'pt_PT' => 'Portuguese (Portugal)',
            'ro' => 'Romanian',
            'ru_RU' => 'Russian (Russia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenian',
            'sr' => 'Serbian',
            'sv_SE' => 'Swedish (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turkish (Turkey)',
            'uk' => 'Ukrainian',
            'vi' => 'Vietnamese',
            'zh_CN' => 'Chinese (Simplified)',
            'zh_HK' => 'Chinese (Hong Kong)',
            'zh_TW' => 'Chinese (Traditional)',
            'zu' => 'Zulu',
        ],
        'es_419' => [
            'af' => 'Afrikáans',
            'am' => 'Amárico',
            'ar' => 'Árabe',
            'az_AZ' => 'Azerbaiyano (Azerbaiyán)',
            'be' => 'Bielorruso',
            'bg' => 'Búlgaro',
            'bn_BD' => 'Bengalí (Bangladés)',
            'ca' => 'Catalán',
            'cs_CZ' => 'Checo (Chequia)',
            'da_DK' => 'Danés (Dinamarca)',
            'de_DE' => 'Alemán (Alemania)',
            'el_GR' => 'Griego (Grecia)',
            'en_AU' => 'Inglés (Australia)',
            'en_CA' => 'Inglés (Canadá)',
            'en_GB' => 'Inglés (Reino Unido)',
            'en_IN' => 'Inglés (India)',
            'en_SG' => 'Inglés (Singapur)',
            'en_US' => 'Inglés (Estados Unidos)',
            'en_ZA' => 'Inglés (Sudáfrica)',
            'et' => 'Estonio',
            'eu_ES' => 'Vasco (España)',
            'fa' => 'Persa',
            'fi_FI' => 'Finés (Finlandia)',
            'fil' => 'Filipino',
            'fr_CA' => 'Francés (Canadá)',
            'fr_FR' => 'Francés (Francia)',
            'gl_ES' => 'Gallego (España)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croata',
            'hu_HU' => 'Húngaro (Hungría)',
            'hy' => 'Armenio (Armenia)',
            'id' => 'Indonesio',
            'is_IS' => 'Islandés (Islandia)',
            'it_IT' => 'Italiano (Italia)',
            'iw_IL' => 'Hebreo (Israel)',
            'ja_JP' => 'Japonés (Japón)',
            'ka_GE' => 'Georgiano (Georgia)',
            'kk' => 'Kazajo',
            'km_KH' => 'Jemer (Camboya)',
            'kn_IN' => 'Canarés (India)',
            'ko' => 'Coreano (Corea del Sur)',
            'ky_KG' => 'Kirguís (Kirguistán)',
            'lo_LA' => 'Laosiano (Laos)',
            'lt' => 'Lituano',
            'lv' => 'Letón',
            'mk_MK' => 'Macedonio (Macedonia del Norte)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongol (Mongolia)',
            'mr_IN' => 'Maratí (India)',
            'ms' => 'Malayo',
            'my_MM' => 'Birmano (Myanmar [Birmania])',
            'ne_NP' => 'Nepalí (Nepal)',
            'nl_NL' => 'Neerlandés (Países Bajos)',
            'no_NO' => 'Noruego (Noruega)',
            'pl_PL' => 'Polaco (Polonia)',
            'pt_BR' => 'Portugués (Brasil)',
            'pt_PT' => 'Portugués (Portugal)',
            'ro' => 'Rumano',
            'ru_RU' => 'Ruso (Rusia)',
            'si_LK' => 'Cingalés (Sri Lanka)',
            'sk' => 'Eslovaco',
            'sl' => 'Esloveno',
            'sr' => 'Serbio',
            'sv_SE' => 'Sueco (Suecia)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Tailandés',
            'tr_TR' => 'Turco (Turquía)',
            'uk' => 'Ucraniano',
            'vi' => 'Vietnamita',
            'zh_CN' => 'Chino (simplificado)',
            'zh_HK' => 'Chino (Hong Kong)',
            'zh_TW' => 'Chino (tradicional)',
            'zu' => 'Zulú',
        ],
        'es_ES' => [
            'af' => 'Afrikáans',
            'am' => 'Amárico',
            'ar' => 'Árabe',
            'az_AZ' => 'Azerbaiyano (Azerbaiyán)',
            'be' => 'Bielorruso',
            'bg' => 'Búlgaro',
            'bn_BD' => 'Bengalí (Bangladés)',
            'ca' => 'Catalán',
            'cs_CZ' => 'Checo (Chequia)',
            'da_DK' => 'Danés (Dinamarca)',
            'de_DE' => 'Alemán (Alemania)',
            'el_GR' => 'Griego (Grecia)',
            'en_AU' => 'Inglés (Australia)',
            'en_CA' => 'Inglés (Canadá)',
            'en_GB' => 'Inglés (Reino Unido)',
            'en_IN' => 'Inglés (India)',
            'en_SG' => 'Inglés (Singapur)',
            'en_US' => 'Inglés (Estados Unidos)',
            'en_ZA' => 'Inglés (Sudáfrica)',
            'et' => 'Estonio',
            'eu_ES' => 'Euskera (España)',
            'fa' => 'Persa',
            'fi_FI' => 'Finés (Finlandia)',
            'fil' => 'Filipino',
            'fr_CA' => 'Francés (Canadá)',
            'fr_FR' => 'Francés (Francia)',
            'gl_ES' => 'Gallego (España)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croata',
            'hu_HU' => 'Húngaro (Hungría)',
            'hy' => 'Armenio (Armenia)',
            'id' => 'Indonesio',
            'is_IS' => 'Islandés (Islandia)',
            'it_IT' => 'Italiano (Italia)',
            'iw_IL' => 'Hebreo (Israel)',
            'ja_JP' => 'Japonés (Japón)',
            'ka_GE' => 'Georgiano (Georgia)',
            'kk' => 'Kazajo',
            'km_KH' => 'Jemer (Camboya)',
            'kn_IN' => 'Canarés (India)',
            'ko' => 'Coreano (Corea del Sur)',
            'ky_KG' => 'Kirguís (Kirguistán)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lituano',
            'lv' => 'Letón',
            'mk_MK' => 'Macedonio (Macedonia del Norte)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongol (Mongolia)',
            'mr_IN' => 'Maratí (India)',
            'ms' => 'Malayo',
            'my_MM' => 'Birmano (Myanmar [Birmania])',
            'ne_NP' => 'Nepalí (Nepal)',
            'nl_NL' => 'Neerlandés (Países Bajos)',
            'no_NO' => 'Noruego (Noruega)',
            'pl_PL' => 'Polaco (Polonia)',
            'pt_BR' => 'Portugués (Brasil)',
            'pt_PT' => 'Portugués (Portugal)',
            'ro' => 'Rumano',
            'ru_RU' => 'Ruso (Rusia)',
            'si_LK' => 'Cingalés (Sri Lanka)',
            'sk' => 'Eslovaco',
            'sl' => 'Esloveno',
            'sr' => 'Serbio',
            'sv_SE' => 'Sueco (Suecia)',
            'sw' => 'Suajili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Tailandés',
            'tr_TR' => 'Turco (Turquía)',
            'uk' => 'Ucraniano',
            'vi' => 'Vietnamita',
            'zh_CN' => 'Chino (simplificado)',
            'zh_HK' => 'Chino (Hong Kong)',
            'zh_TW' => 'Chino (tradicional)',
            'zu' => 'Zulú',
        ],
        'es_US' => [
            'af' => 'Afrikáans',
            'am' => 'Amárico',
            'ar' => 'Árabe',
            'az_AZ' => 'Azerbaiyano (Azerbaiyán)',
            'be' => 'Bielorruso',
            'bg' => 'Búlgaro',
            'bn_BD' => 'Bengalí (Bangladés)',
            'ca' => 'Catalán',
            'cs_CZ' => 'Checo (Chequia)',
            'da_DK' => 'Danés (Dinamarca)',
            'de_DE' => 'Alemán (Alemania)',
            'el_GR' => 'Griego (Grecia)',
            'en_AU' => 'Inglés (Australia)',
            'en_CA' => 'Inglés (Canadá)',
            'en_GB' => 'Inglés (Reino Unido)',
            'en_IN' => 'Inglés (India)',
            'en_SG' => 'Inglés (Singapur)',
            'en_US' => 'Inglés (Estados Unidos)',
            'en_ZA' => 'Inglés (Sudáfrica)',
            'et' => 'Estonio',
            'eu_ES' => 'Euskera (España)',
            'fa' => 'Persa',
            'fi_FI' => 'Finés (Finlandia)',
            'fil' => 'Filipino',
            'fr_CA' => 'Francés (Canadá)',
            'fr_FR' => 'Francés (Francia)',
            'gl_ES' => 'Gallego (España)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croata',
            'hu_HU' => 'Húngaro (Hungría)',
            'hy' => 'Armenio (Armenia)',
            'id' => 'Indonesio',
            'is_IS' => 'Islandés (Islandia)',
            'it_IT' => 'Italiano (Italia)',
            'iw_IL' => 'Hebreo (Israel)',
            'ja_JP' => 'Japonés (Japón)',
            'ka_GE' => 'Georgiano (Georgia)',
            'kk' => 'Kazajo',
            'km_KH' => 'Jemer (Camboya)',
            'kn_IN' => 'Canarés (India)',
            'ko' => 'Coreano (Corea del Sur)',
            'ky_KG' => 'Kirguís (Kirguistán)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lituano',
            'lv' => 'Letón',
            'mk_MK' => 'Macedonio (Macedonia del Norte)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongol (Mongolia)',
            'mr_IN' => 'Maratí (India)',
            'ms' => 'Malayo',
            'my_MM' => 'Birmano (Myanmar [Birmania])',
            'ne_NP' => 'Nepalí (Nepal)',
            'nl_NL' => 'Neerlandés (Países Bajos)',
            'no_NO' => 'Noruego (Noruega)',
            'pl_PL' => 'Polaco (Polonia)',
            'pt_BR' => 'Portugués (Brasil)',
            'pt_PT' => 'Portugués (Portugal)',
            'ro' => 'Rumano',
            'ru_RU' => 'Ruso (Rusia)',
            'si_LK' => 'Cingalés (Sri Lanka)',
            'sk' => 'Eslovaco',
            'sl' => 'Esloveno',
            'sr' => 'Serbio',
            'sv_SE' => 'Sueco (Suecia)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Tailandés',
            'tr_TR' => 'Turco (Turquía)',
            'uk' => 'Ucraniano',
            'vi' => 'Vietnamita',
            'zh_CN' => 'Chino (simplificado)',
            'zh_HK' => 'Chino (Hong Kong)',
            'zh_TW' => 'Chino (tradicional)',
            'zu' => 'Zulú',
        ],
        'et' => [
            'af' => 'afrikaani',
            'am' => 'amhara',
            'ar' => 'araabia',
            'az_AZ' => 'aserbaidžaani (Aserbaidžaan)',
            'be' => 'valgevene',
            'bg' => 'bulgaaria',
            'bn_BD' => 'bengali (Bangladesh)',
            'ca' => 'katalaani',
            'cs_CZ' => 'tšehhi (Tšehhi)',
            'da_DK' => 'taani (Taani)',
            'de_DE' => 'saksa (Saksamaa)',
            'el_GR' => 'kreeka (Kreeka)',
            'en_AU' => 'inglise (Austraalia)',
            'en_CA' => 'inglise (Kanada)',
            'en_GB' => 'inglise (Suurbritannia)',
            'en_IN' => 'inglise (India)',
            'en_SG' => 'inglise (Singapur)',
            'en_US' => 'inglise (Ameerika Ühendriigid)',
            'en_ZA' => 'inglise (Lõuna-Aafrika Vabariik)',
            'es_419' => 'hispaania (Ladina-Ameerika)',
            'es_ES' => 'hispaania (Hispaania)',
            'es_US' => 'hispaania (Ameerika Ühendriigid)',
            'eu_ES' => 'baski (Hispaania)',
            'fa' => 'pärsia',
            'fi_FI' => 'soome (Soome)',
            'fil' => 'filipiini',
            'fr_CA' => 'prantsuse (Kanada)',
            'fr_FR' => 'prantsuse (Prantsusmaa)',
            'gl_ES' => 'galeegi (Hispaania)',
            'hi_IN' => 'hindi (India)',
            'hr' => 'horvaadi',
            'hu_HU' => 'ungari (Ungari)',
            'hy' => 'armeenia (Armeenia)',
            'id' => 'indoneesia',
            'is_IS' => 'islandi (Island)',
            'it_IT' => 'itaalia (Itaalia)',
            'iw_IL' => 'heebrea (Iisrael)',
            'ja_JP' => 'jaapani (Jaapan)',
            'ka_GE' => 'gruusia (Gruusia)',
            'kk' => 'kasahhi',
            'km_KH' => 'khmeeri (Kambodža)',
            'kn_IN' => 'kannada (India)',
            'ko' => 'korea (Lõuna-Korea)',
            'ky_KG' => 'kirgiisi (Kõrgõzstan)',
            'lo_LA' => 'lao (Laos)',
            'lt' => 'leedu',
            'lv' => 'läti',
            'mk_MK' => 'makedoonia (Põhja-Makedoonia)',
            'ml_IN' => 'malajalami (India)',
            'mn_MN' => 'mongoli (Mongoolia)',
            'mr_IN' => 'marathi (India)',
            'ms' => 'malai',
            'my_MM' => 'birma (Myanmar [Birma])',
            'ne_NP' => 'nepali (Nepal)',
            'nl_NL' => 'hollandi (Holland)',
            'no_NO' => 'norra (Norra)',
            'pl_PL' => 'poola (Poola)',
            'pt_BR' => 'portugali (Brasiilia)',
            'pt_PT' => 'portugali (Portugal)',
            'ro' => 'rumeenia',
            'ru_RU' => 'vene (Venemaa)',
            'si_LK' => 'singali (Sri Lanka)',
            'sk' => 'slovaki',
            'sl' => 'sloveeni',
            'sr' => 'serbia',
            'sv_SE' => 'rootsi (Rootsi)',
            'sw' => 'suahiili',
            'ta_IN' => 'tamili (India)',
            'te_IN' => 'telugu (India)',
            'th' => 'tai',
            'tr_TR' => 'türgi (Türgi)',
            'uk' => 'ukraina',
            'vi' => 'vietnami',
            'zh_CN' => 'hiina (lihtsustatud)',
            'zh_HK' => 'hiina (Hongkong)',
            'zh_TW' => 'hiina (traditsiooniline)',
            'zu' => 'suulu',
        ],
        'eu_ES' => [
            'af' => 'afrikaans',
            'am' => 'amharera',
            'ar' => 'arabiera',
            'az_AZ' => 'azerbaijanera (Azerbaijan)',
            'be' => 'bielorrusiera',
            'bg' => 'bulgariera',
            'bn_BD' => 'bengalera (Bangladesh)',
            'ca' => 'katalan',
            'cs_CZ' => 'txekiera (Txekia)',
            'da_DK' => 'daniera (Danimarka)',
            'de_DE' => 'aleman (Alemania)',
            'el_GR' => 'greziera (Grezia)',
            'en_AU' => 'ingeles (Australia)',
            'en_CA' => 'ingeles (Kanada)',
            'en_GB' => 'ingeles (Erresuma Batua)',
            'en_IN' => 'ingeles (India)',
            'en_SG' => 'ingeles (Singapur)',
            'en_US' => 'ingeles (Ameriketako Estatu Batuak)',
            'en_ZA' => 'ingeles (Hegoafrika)',
            'es_419' => 'espainiera (Latinoamerika)',
            'es_ES' => 'espainiera (Espainia)',
            'es_US' => 'espainiera (Ameriketako Estatu Batuak)',
            'et' => 'estoniera',
            'fa' => 'persiera',
            'fi_FI' => 'finlandiera (Finlandia)',
            'fil' => 'filipinera',
            'fr_CA' => 'frantses (Kanada)',
            'fr_FR' => 'frantses (Frantzia)',
            'gl_ES' => 'galiziera (Espainia)',
            'hi_IN' => 'hindi (India)',
            'hr' => 'kroaziera',
            'hu_HU' => 'hungariera (Hungaria)',
            'hy' => 'armeniera (Armenia)',
            'id' => 'indonesiera',
            'is_IS' => 'islandiera (Islandia)',
            'it_IT' => 'italiera (Italia)',
            'iw_IL' => 'hebreera (Israel)',
            'ja_JP' => 'japoniera (Japonia)',
            'ka_GE' => 'georgiera (Georgia)',
            'kk' => 'kazakhera',
            'km_KH' => 'khemerera (Kanbodia)',
            'kn_IN' => 'kannada (India)',
            'ko' => 'koreera (Hego Korea)',
            'ky_KG' => 'kirgizera (Kirgizistan)',
            'lo_LA' => 'laosera (Laos)',
            'lt' => 'lituaniera',
            'lv' => 'letoniera',
            'mk_MK' => 'mazedoniera (Ipar Mazedonia)',
            'ml_IN' => 'malabarera (India)',
            'mn_MN' => 'mongoliera (Mongolia)',
            'mr_IN' => 'marathera (India)',
            'ms' => 'malaysiera',
            'my_MM' => 'birmaniera (Myanmar [Birmania])',
            'ne_NP' => 'nepalera (Nepal)',
            'nl_NL' => 'nederlandera (Herbehereak)',
            'no_NO' => 'norvegiera (Norvegia)',
            'pl_PL' => 'poloniera (Polonia)',
            'pt_BR' => 'portuges (Brasil)',
            'pt_PT' => 'portuges (Portugal)',
            'ro' => 'errumaniera',
            'ru_RU' => 'errusiera (Errusia)',
            'si_LK' => 'sinhala (Sri Lanka)',
            'sk' => 'eslovakiera',
            'sl' => 'esloveniera',
            'sr' => 'serbiera',
            'sv_SE' => 'suediera (Suedia)',
            'sw' => 'swahilia',
            'ta_IN' => 'tamilera (India)',
            'te_IN' => 'telugu (India)',
            'th' => 'thailandiera',
            'tr_TR' => 'turkiera (Turkia)',
            'uk' => 'ukrainera',
            'vi' => 'vietnamera',
            'zh_CN' => 'txinera (sinplifikatua)',
            'zh_HK' => 'txinera (Hong Kong)',
            'zh_TW' => 'txinera (tradizionala)',
            'zu' => 'zuluera',
        ],
        'fa' => [
            'af' => 'آفریکانس',
            'am' => 'امهری',
            'ar' => 'عربی',
            'az_AZ' => 'ترکی آذربایجانی (جمهوری آذربایجان)',
            'be' => 'بلاروسی',
            'bg' => 'بلغاری',
            'bn_BD' => 'بنگالی (بنگلادش)',
            'ca' => 'کاتالان',
            'cs_CZ' => 'چکی (چک)',
            'da_DK' => 'دانمارکی (دانمارک)',
            'de_DE' => 'آلمانی (آلمان)',
            'el_GR' => 'یونانی (یونان)',
            'en_AU' => 'انگلیسی (استرالیا)',
            'en_CA' => 'انگلیسی (کانادا)',
            'en_GB' => 'انگلیسی (بریتانیا)',
            'en_IN' => 'انگلیسی (هند)',
            'en_SG' => 'انگلیسی (سنگاپور)',
            'en_US' => 'انگلیسی (ایالات متحده)',
            'en_ZA' => 'انگلیسی (افریقای جنوبی)',
            'es_419' => 'اسپانیایی (امریکای لاتین)',
            'es_ES' => 'اسپانیایی (اسپانیا)',
            'es_US' => 'اسپانیایی (ایالات متحده)',
            'et' => 'استونیایی',
            'eu_ES' => 'باسکی (اسپانیا)',
            'fi_FI' => 'فنلاندی (فنلاند)',
            'fil' => 'فیلیپینی',
            'fr_CA' => 'فرانسوی (کانادا)',
            'fr_FR' => 'فرانسوی (فرانسه)',
            'gl_ES' => 'گالیسیایی (اسپانیا)',
            'hi_IN' => 'هندی (هند)',
            'hr' => 'کروات',
            'hu_HU' => 'مجاری (مجارستان)',
            'hy' => 'ارمنی (ارمنستان)',
            'id' => 'اندونزیایی',
            'is_IS' => 'ایسلندی (ایسلند)',
            'it_IT' => 'ایتالیایی (ایتالیا)',
            'iw_IL' => 'عبری (اسرائیل)',
            'ja_JP' => 'ژاپنی (ژاپن)',
            'ka_GE' => 'گرجی (گرجستان)',
            'kk' => 'قزاقی',
            'km_KH' => 'خمری (کامبوج)',
            'kn_IN' => 'کانارا (هند)',
            'ko' => 'کره‌ای (کرهٔ جنوبی)',
            'ky_KG' => 'قرقیزی (قرقیزستان)',
            'lo_LA' => 'لائوسی (لائوس)',
            'lt' => 'لیتوانیایی',
            'lv' => 'لتونیایی',
            'mk_MK' => 'مقدونی (مقدونیهٔ شمالی)',
            'ml_IN' => 'مالایالامی (هند)',
            'mn_MN' => 'مغولی (مغولستان)',
            'mr_IN' => 'مراتی (هند)',
            'ms' => 'مالایی',
            'my_MM' => 'برمه‌ای (میانمار [برمه])',
            'ne_NP' => 'نپالی (نپال)',
            'nl_NL' => 'هلندی (هلند)',
            'no_NO' => 'نروژی (نروژ)',
            'pl_PL' => 'لهستانی (لهستان)',
            'pt_BR' => 'پرتغالی (برزیل)',
            'pt_PT' => 'پرتغالی (پرتغال)',
            'ro' => 'رومانیایی',
            'ru_RU' => 'روسی (روسیه)',
            'si_LK' => 'سینهالی (سری‌لانکا)',
            'sk' => 'اسلواکی',
            'sl' => 'اسلوونیایی',
            'sr' => 'صربی',
            'sv_SE' => 'سوئدی (سوئد)',
            'sw' => 'سواحیلی',
            'ta_IN' => 'تامیلی (هند)',
            'te_IN' => 'تلوگویی (هند)',
            'th' => 'تایلندی',
            'tr_TR' => 'ترکی استانبولی (ترکیه)',
            'uk' => 'اوکراینی',
            'vi' => 'ویتنامی',
            'zh_CN' => 'چینی (ساده‌شده)',
            'zh_HK' => 'چینی (هنگ‌کنگ)',
            'zh_TW' => 'چینی (سنتی)',
            'zu' => 'زولویی',
        ],
        'fi_FI' => [
            'af' => 'Afrikaans',
            'am' => 'Amhara',
            'ar' => 'Arabia',
            'az_AZ' => 'Azeri (Azerbaidžan)',
            'be' => 'Valkovenäjä',
            'bg' => 'Bulgaria',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Katalaani',
            'cs_CZ' => 'Tšekki (Tšekki)',
            'da_DK' => 'Tanska (Tanska)',
            'de_DE' => 'Saksa (Saksa)',
            'el_GR' => 'Kreikka (Kreikka)',
            'en_AU' => 'Englanti (Australia)',
            'en_CA' => 'Englanti (Kanada)',
            'en_GB' => 'Englanti (Iso-Britannia)',
            'en_IN' => 'Englanti (Intia)',
            'en_SG' => 'Englanti (Singapore)',
            'en_US' => 'Englanti (Yhdysvallat)',
            'en_ZA' => 'Englanti (Etelä-Afrikka)',
            'es_419' => 'Espanja (Latinalainen Amerikka)',
            'es_ES' => 'Espanja (Espanja)',
            'es_US' => 'Espanja (Yhdysvallat)',
            'et' => 'Viro',
            'eu_ES' => 'Baski (Espanja)',
            'fa' => 'Persia',
            'fil' => 'Filipino',
            'fr_CA' => 'Ranska (Kanada)',
            'fr_FR' => 'Ranska (Ranska)',
            'gl_ES' => 'Galicia (Espanja)',
            'hi_IN' => 'Hindi (Intia)',
            'hr' => 'Kroatia',
            'hu_HU' => 'Unkari (Unkari)',
            'hy' => 'Armenia (Armenia)',
            'id' => 'Indonesia',
            'is_IS' => 'Islanti (Islanti)',
            'it_IT' => 'Italia (Italia)',
            'iw_IL' => 'Heprea (Israel)',
            'ja_JP' => 'Japani (Japani)',
            'ka_GE' => 'Georgia (Georgia)',
            'kk' => 'Kazakki',
            'km_KH' => 'Khmer (Kambodža)',
            'kn_IN' => 'Kannada (Intia)',
            'ko' => 'Korea (Etelä-Korea)',
            'ky_KG' => 'Kirgiisi (Kirgisia)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Liettua',
            'lv' => 'Latvia',
            'mk_MK' => 'Makedonia (Pohjois-Makedonia)',
            'ml_IN' => 'Malajalam (Intia)',
            'mn_MN' => 'Mongoli (Mongolia)',
            'mr_IN' => 'Marathi (Intia)',
            'ms' => 'Malaiji',
            'my_MM' => 'Burma (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Hollanti (Alankomaat)',
            'no_NO' => 'Norja (Norja)',
            'pl_PL' => 'Puola (Puola)',
            'pt_BR' => 'Portugali (Brasilia)',
            'pt_PT' => 'Portugali (Portugali)',
            'ro' => 'Romania',
            'ru_RU' => 'Venäjä (Venäjä)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovakki',
            'sl' => 'Sloveeni',
            'sr' => 'Serbia',
            'sv_SE' => 'Ruotsi (Ruotsi)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamili (Intia)',
            'te_IN' => 'Telugu (Intia)',
            'th' => 'Thai',
            'tr_TR' => 'Turkki (Turkki)',
            'uk' => 'Ukraina',
            'vi' => 'Vietnam',
            'zh_CN' => 'Kiina (yksinkertaistettu)',
            'zh_HK' => 'Kiina (Hongkong)',
            'zh_TW' => 'Kiina (perinteinen)',
            'zu' => 'Zulu',
        ],
        'fil' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arabic',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusian',
            'bg' => 'Bulgarian',
            'bn_BD' => 'Bangla (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Danish (Denmark)',
            'de_DE' => 'German (Germany)',
            'el_GR' => 'Greek (Greece)',
            'en_AU' => 'Ingles (Australia)',
            'en_CA' => 'Ingles (Canada)',
            'en_GB' => 'Ingles (United Kingdom)',
            'en_IN' => 'Ingles (India)',
            'en_SG' => 'Ingles (Singapore)',
            'en_US' => 'Ingles (Estados Unidos)',
            'en_ZA' => 'Ingles (South Africa)',
            'es_419' => 'Spanish (Latin America)',
            'es_ES' => 'Spanish (Spain)',
            'es_US' => 'Spanish (Estados Unidos)',
            'et' => 'Estonian',
            'eu_ES' => 'Basque (Spain)',
            'fa' => 'Persian',
            'fi_FI' => 'Finnish (Finland)',
            'fr_CA' => 'French (Canada)',
            'fr_FR' => 'French (France)',
            'gl_ES' => 'Galician (Spain)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatian',
            'hu_HU' => 'Hungarian (Hungary)',
            'hy' => 'Armenian (Armenia)',
            'id' => 'Indonesian',
            'is_IS' => 'Icelandic (Iceland)',
            'it_IT' => 'Italian (Italy)',
            'iw_IL' => 'Hebrew (Israel)',
            'ja_JP' => 'Japanese (Japan)',
            'ka_GE' => 'Georgian (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korean (Timog Korea)',
            'ky_KG' => 'Kirghiz (Kyrgyzstan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lithuanian',
            'lv' => 'Latvian',
            'mk_MK' => 'Macedonian (North Macedonia)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolian (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malay',
            'my_MM' => 'Burmese (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Dutch (Netherlands)',
            'no_NO' => 'Norwegian (Norway)',
            'pl_PL' => 'Polish (Poland)',
            'pt_BR' => 'Portuguese (Brazil)',
            'pt_PT' => 'Portuguese (Portugal)',
            'ro' => 'Romanian',
            'ru_RU' => 'Russian (Russia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenian',
            'sr' => 'Serbian',
            'sv_SE' => 'Swedish (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turkish (Turkey)',
            'uk' => 'Ukranian',
            'vi' => 'Vietnamese',
            'zh_CN' => 'Chinese (Pinasimple)',
            'zh_HK' => 'Chinese (Hong Kong)',
            'zh_TW' => 'Chinese (Tradisyonal)',
            'zu' => 'Zulu',
        ],
        'fr_CA' => [
            'af' => 'Afrikaans',
            'am' => 'Amharique',
            'ar' => 'Arabe',
            'az_AZ' => 'Azerbaïdjanais (Azerbaïdjan)',
            'be' => 'Biélorusse',
            'bg' => 'Bulgare',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Tchèque (Tchéquie)',
            'da_DK' => 'Danois (Danemark)',
            'de_DE' => 'Allemand (Allemagne)',
            'el_GR' => 'Grec (Grèce)',
            'en_AU' => 'Anglais (Australie)',
            'en_CA' => 'Anglais (Canada)',
            'en_GB' => 'Anglais (Royaume-Uni)',
            'en_IN' => 'Anglais (Inde)',
            'en_SG' => 'Anglais (Singapour)',
            'en_US' => 'Anglais (États-Unis)',
            'en_ZA' => 'Anglais (Afrique du Sud)',
            'es_419' => 'Espagnol (Amérique latine)',
            'es_ES' => 'Espagnol (Espagne)',
            'es_US' => 'Espagnol (États-Unis)',
            'et' => 'Estonien',
            'eu_ES' => 'Basque (Espagne)',
            'fa' => 'Persan',
            'fi_FI' => 'Finnois (Finlande)',
            'fil' => 'Filipino',
            'gl_ES' => 'Galicien (Espagne)',
            'hi_IN' => 'Hindi (Inde)',
            'hr' => 'Croate',
            'hu_HU' => 'Hongrois (Hongrie)',
            'hy' => 'Arménien (Arménie)',
            'id' => 'Indonésien',
            'is_IS' => 'Islandais (Islande)',
            'it_IT' => 'Italien (Italie)',
            'iw_IL' => 'Hébreu (Israël)',
            'ja_JP' => 'Japonais (Japon)',
            'ka_GE' => 'Géorgien (Géorgie)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodge)',
            'kn_IN' => 'Kannada (Inde)',
            'ko' => 'Coréen (Corée du Sud)',
            'ky_KG' => 'Kirghize (Kirghizistan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lituanien',
            'lv' => 'Letton',
            'mk_MK' => 'Macédonien (Macédoine du Nord)',
            'ml_IN' => 'Malayalam (Inde)',
            'mn_MN' => 'Mongol (Mongolie)',
            'mr_IN' => 'Marathe (Inde)',
            'ms' => 'Malais',
            'my_MM' => 'Birman (Myanmar)',
            'ne_NP' => 'Népalais (Népal)',
            'nl_NL' => 'Néerlandais (Pays-Bas)',
            'no_NO' => 'Norvégien (Norvège)',
            'pl_PL' => 'Polonais (Pologne)',
            'pt_BR' => 'Portugais (Brésil)',
            'pt_PT' => 'Portugais (Portugal)',
            'ro' => 'Roumain',
            'ru_RU' => 'Russe (Russie)',
            'si_LK' => 'Cingalais (Sri Lanka)',
            'sk' => 'Slovaque',
            'sl' => 'Slovène',
            'sr' => 'Serbe',
            'sv_SE' => 'Suédois (Suède)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamoul (Inde)',
            'te_IN' => 'Télougou (Inde)',
            'th' => 'Thaï',
            'tr_TR' => 'Turc (Turquie)',
            'uk' => 'Ukrainien',
            'vi' => 'Vietnamien',
            'zh_CN' => 'Chinois (idéogrammes han simplifiés)',
            'zh_HK' => 'Chinois (Hong Kong)',
            'zh_TW' => 'Chinois (idéogrammes han traditionnels)',
            'zu' => 'Zoulou',
        ],
        'fr_FR' => [
            'af' => 'Afrikaans',
            'am' => 'Amharique',
            'ar' => 'Arabe',
            'az_AZ' => 'Azéri (Azerbaïdjan)',
            'be' => 'Biélorusse',
            'bg' => 'Bulgare',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Catalan',
            'cs_CZ' => 'Tchèque (Tchéquie)',
            'da_DK' => 'Danois (Danemark)',
            'de_DE' => 'Allemand (Allemagne)',
            'el_GR' => 'Grec (Grèce)',
            'en_AU' => 'Anglais (Australie)',
            'en_CA' => 'Anglais (Canada)',
            'en_GB' => 'Anglais (Royaume-Uni)',
            'en_IN' => 'Anglais (Inde)',
            'en_SG' => 'Anglais (Singapour)',
            'en_US' => 'Anglais (États-Unis)',
            'en_ZA' => 'Anglais (Afrique du Sud)',
            'es_419' => 'Espagnol (Amérique latine)',
            'es_ES' => 'Espagnol (Espagne)',
            'es_US' => 'Espagnol (États-Unis)',
            'et' => 'Estonien',
            'eu_ES' => 'Basque (Espagne)',
            'fa' => 'Persan',
            'fi_FI' => 'Finnois (Finlande)',
            'fil' => 'Filipino',
            'gl_ES' => 'Galicien (Espagne)',
            'hi_IN' => 'Hindi (Inde)',
            'hr' => 'Croate',
            'hu_HU' => 'Hongrois (Hongrie)',
            'hy' => 'Arménien (Arménie)',
            'id' => 'Indonésien',
            'is_IS' => 'Islandais (Islande)',
            'it_IT' => 'Italien (Italie)',
            'iw_IL' => 'Hébreu (Israël)',
            'ja_JP' => 'Japonais (Japon)',
            'ka_GE' => 'Géorgien (Géorgie)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Cambodge)',
            'kn_IN' => 'Kannada (Inde)',
            'ko' => 'Coréen (Corée du Sud)',
            'ky_KG' => 'Kirghize (Kirghizistan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lituanien',
            'lv' => 'Letton',
            'mk_MK' => 'Macédonien (Macédoine du Nord)',
            'ml_IN' => 'Malayalam (Inde)',
            'mn_MN' => 'Mongol (Mongolie)',
            'mr_IN' => 'Marathi (Inde)',
            'ms' => 'Malais',
            'my_MM' => 'Birman (Myanmar [Birmanie])',
            'ne_NP' => 'Népalais (Népal)',
            'nl_NL' => 'Néerlandais (Pays-Bas)',
            'no_NO' => 'Norvégien (Norvège)',
            'pl_PL' => 'Polonais (Pologne)',
            'pt_BR' => 'Portugais (Brésil)',
            'pt_PT' => 'Portugais (Portugal)',
            'ro' => 'Roumain',
            'ru_RU' => 'Russe (Russie)',
            'si_LK' => 'Cingalais (Sri Lanka)',
            'sk' => 'Slovaque',
            'sl' => 'Slovène',
            'sr' => 'Serbe',
            'sv_SE' => 'Suédois (Suède)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamoul (Inde)',
            'te_IN' => 'Télougou (Inde)',
            'th' => 'Thaï',
            'tr_TR' => 'Turc (Turquie)',
            'uk' => 'Ukrainien',
            'vi' => 'Vietnamien',
            'zh_CN' => 'Chinois (simplifié)',
            'zh_HK' => 'Chinois (Hong Kong)',
            'zh_TW' => 'Chinois (traditionnel)',
            'zu' => 'Zoulou',
        ],
        'gl_ES' => [
            'af' => 'afrikaans',
            'am' => 'amhárico',
            'ar' => 'árabe',
            'az_AZ' => 'acerbaixano (Acerbaixán)',
            'be' => 'belaruso',
            'bg' => 'búlgaro',
            'bn_BD' => 'bengalí (Bangladesh)',
            'ca' => 'catalán',
            'cs_CZ' => 'checo (Chequia)',
            'da_DK' => 'dinamarqués (Dinamarca)',
            'de_DE' => 'alemán (Alemaña)',
            'el_GR' => 'grego (Grecia)',
            'en_AU' => 'inglés (Australia)',
            'en_CA' => 'inglés (O Canadá)',
            'en_GB' => 'inglés (O Reino Unido)',
            'en_IN' => 'inglés (A India)',
            'en_SG' => 'inglés (Singapur)',
            'en_US' => 'inglés (Os Estados Unidos)',
            'en_ZA' => 'inglés (Suráfrica)',
            'es_419' => 'español (América Latina)',
            'es_ES' => 'español (España)',
            'es_US' => 'español (Os Estados Unidos)',
            'et' => 'estoniano',
            'eu_ES' => 'éuscaro (España)',
            'fa' => 'persa',
            'fi_FI' => 'finés (Finlandia)',
            'fil' => 'filipino',
            'fr_CA' => 'francés (O Canadá)',
            'fr_FR' => 'francés (Francia)',
            'hi_IN' => 'hindi (A India)',
            'hr' => 'croata',
            'hu_HU' => 'húngaro (Hungría)',
            'hy' => 'armenio (Armenia)',
            'id' => 'indonesio',
            'is_IS' => 'islandés (Islandia)',
            'it_IT' => 'italiano (Italia)',
            'iw_IL' => 'hebreo (Israel)',
            'ja_JP' => 'xaponés (O Xapón)',
            'ka_GE' => 'xeorxiano (Xeorxia)',
            'kk' => 'kazako',
            'km_KH' => 'khmer (Camboxa)',
            'kn_IN' => 'kannará (A India)',
            'ko' => 'coreano (Corea do Sur)',
            'ky_KG' => 'kirguiz (Kirguizistán)',
            'lo_LA' => 'laosiano (Laos)',
            'lt' => 'lituano',
            'lv' => 'letón',
            'mk_MK' => 'macedonio (Macedonia do Norte)',
            'ml_IN' => 'malabar (A India)',
            'mn_MN' => 'mongol (Mongolia)',
            'mr_IN' => 'marathi (A India)',
            'ms' => 'malaio',
            'my_MM' => 'birmano (Myanmar [Birmania])',
            'ne_NP' => 'nepalí (Nepal)',
            'nl_NL' => 'neerlandés (Países Baixos)',
            'no_NO' => 'noruegués (Noruega)',
            'pl_PL' => 'polaco (Polonia)',
            'pt_BR' => 'portugués (O Brasil)',
            'pt_PT' => 'portugués (Portugal)',
            'ro' => 'romanés',
            'ru_RU' => 'ruso (Rusia)',
            'si_LK' => 'cingalés (Sri Lanka)',
            'sk' => 'eslovaco',
            'sl' => 'esloveno',
            'sr' => 'serbio',
            'sv_SE' => 'sueco (Suecia)',
            'sw' => 'suahili',
            'ta_IN' => 'támil (A India)',
            'te_IN' => 'telugu (A India)',
            'th' => 'tailandés',
            'tr_TR' => 'turco (Turquía)',
            'uk' => 'ucraíno',
            'vi' => 'vietnamita',
            'zh_CN' => 'chinés (simplificado)',
            'zh_HK' => 'chinés (Hong Kong)',
            'zh_TW' => 'chinés (tradicional)',
            'zu' => 'zulú',
        ],
        'hi_IN' => [
            'af' => 'अफ़्रीकी',
            'am' => 'अम्हेरी',
            'ar' => 'अरबी',
            'az_AZ' => 'अज़रबैजानी (अज़रबैजान)',
            'be' => 'बेलारूसी',
            'bg' => 'बुल्गारियाई',
            'bn_BD' => 'बंगाली (बांग्लादेश)',
            'ca' => 'कातालान',
            'cs_CZ' => 'चेक (चेकिया)',
            'da_DK' => 'डेनिश (डेनमार्क)',
            'de_DE' => 'जर्मन (जर्मनी)',
            'el_GR' => 'यूनानी (यूनान)',
            'en_AU' => 'अंग्रेज़ी (ऑस्ट्रेलिया)',
            'en_CA' => 'अंग्रेज़ी (कनाडा)',
            'en_GB' => 'अंग्रेज़ी (यूनाइटेड किंगडम)',
            'en_IN' => 'अंग्रेज़ी (भारत)',
            'en_SG' => 'अंग्रेज़ी (सिंगापुर)',
            'en_US' => 'अंग्रेज़ी (संयुक्त राज्य)',
            'en_ZA' => 'अंग्रेज़ी (दक्षिण अफ़्रीका)',
            'es_419' => 'स्पेनी (लैटिन अमेरिका)',
            'es_ES' => 'स्पेनी (स्पेन)',
            'es_US' => 'स्पेनी (संयुक्त राज्य)',
            'et' => 'एस्टोनियाई',
            'eu_ES' => 'बास्क (स्पेन)',
            'fa' => 'फ़ारसी',
            'fi_FI' => 'फ़िनिश (फ़िनलैंड)',
            'fil' => 'फ़िलिपीनो',
            'fr_CA' => 'फ़्रेंच (कनाडा)',
            'fr_FR' => 'फ़्रेंच (फ़्रांस)',
            'gl_ES' => 'गैलिशियन (स्पेन)',
            'hr' => 'क्रोएशियाई',
            'hu_HU' => 'हंगेरियाई (हंगरी)',
            'hy' => 'आर्मेनियाई (आर्मेनिया)',
            'id' => 'इंडोनेशियाई',
            'is_IS' => 'आइसलैंडिक (आइसलैंड)',
            'it_IT' => 'इतालवी (इटली)',
            'iw_IL' => 'हिब्रू (इज़राइल)',
            'ja_JP' => 'जापानी (जापान)',
            'ka_GE' => 'जॉर्जियाई (जॉर्जिया)',
            'kk' => 'कज़ाख़',
            'km_KH' => 'खमेर (कंबोडिया)',
            'kn_IN' => 'कन्नड़ (भारत)',
            'ko' => 'कोरियाई (दक्षिण कोरिया)',
            'ky_KG' => 'किर्गीज़ (किर्गिज़स्तान)',
            'lo_LA' => 'लाओ (लाओस)',
            'lt' => 'लिथुआनियाई',
            'lv' => 'लातवियाई',
            'mk_MK' => 'मकदूनियाई (उत्तरी मकदूनिया)',
            'ml_IN' => 'मलयालम (भारत)',
            'mn_MN' => 'मंगोलियाई (मंगोलिया)',
            'mr_IN' => 'मराठी (भारत)',
            'ms' => 'मलय',
            'my_MM' => 'बर्मीज़ (म्यांमार [बर्मा])',
            'ne_NP' => 'नेपाली (नेपाल)',
            'nl_NL' => 'डच (नीदरलैंड)',
            'no_NO' => 'नॉर्वेजियाई (नॉर्वे)',
            'pl_PL' => 'पोलिश (पोलैंड)',
            'pt_BR' => 'पुर्तगाली (ब्राज़ील)',
            'pt_PT' => 'पुर्तगाली (पुर्तगाल)',
            'ro' => 'रोमानियाई',
            'ru_RU' => 'रूसी (रूस)',
            'si_LK' => 'सिंहली (श्रीलंका)',
            'sk' => 'स्लोवाक',
            'sl' => 'स्लोवेनियाई',
            'sr' => 'सर्बियाई',
            'sv_SE' => 'स्वीडिश (स्वीडन)',
            'sw' => 'स्वाहिली',
            'ta_IN' => 'तमिल (भारत)',
            'te_IN' => 'तेलुगू (भारत)',
            'th' => 'थाई',
            'tr_TR' => 'तुर्की (तुर्की)',
            'uk' => 'यूक्रेनियाई',
            'vi' => 'वियतनामी',
            'zh_CN' => 'चीनी (सरलीकृत)',
            'zh_HK' => 'चीनी (हाँग काँग)',
            'zh_TW' => 'चीनी (पारंपरिक)',
            'zu' => 'ज़ुलू',
        ],
        'hr' => [
            'af' => 'Afrikaans',
            'am' => 'Amharski',
            'ar' => 'Arapski',
            'az_AZ' => 'Azerbajdžanski (Azerbajdžan)',
            'be' => 'Bjeloruski',
            'bg' => 'Bugarski',
            'bn_BD' => 'Bangla (Bangladeš)',
            'ca' => 'Katalonski',
            'cs_CZ' => 'Češki (Češka)',
            'da_DK' => 'Danski (Danska)',
            'de_DE' => 'Njemački (Njemačka)',
            'el_GR' => 'Grčki (Grčka)',
            'en_AU' => 'Engleski (Australija)',
            'en_CA' => 'Engleski (Kanada)',
            'en_GB' => 'Engleski (Ujedinjeno Kraljevstvo)',
            'en_IN' => 'Engleski (Indija)',
            'en_SG' => 'Engleski (Singapur)',
            'en_US' => 'Engleski (Sjedinjene Američke Države)',
            'en_ZA' => 'Engleski (Južnoafrička Republika)',
            'es_419' => 'Španjolski (Latinska Amerika)',
            'es_ES' => 'Španjolski (Španjolska)',
            'es_US' => 'Španjolski (Sjedinjene Američke Države)',
            'et' => 'Estonski',
            'eu_ES' => 'Baskijski (Španjolska)',
            'fa' => 'Perzijski',
            'fi_FI' => 'Finski (Finska)',
            'fil' => 'Filipinski',
            'fr_CA' => 'Francuski (Kanada)',
            'fr_FR' => 'Francuski (Francuska)',
            'gl_ES' => 'Galicijski (Španjolska)',
            'hi_IN' => 'Hindski (Indija)',
            'hu_HU' => 'Mađarski (Mađarska)',
            'hy' => 'Armenski (Armenija)',
            'id' => 'Indonezijski',
            'is_IS' => 'Islandski (Island)',
            'it_IT' => 'Talijanski (Italija)',
            'iw_IL' => 'Hebrejski (Izrael)',
            'ja_JP' => 'Japanski (Japan)',
            'ka_GE' => 'Gruzijski (Gruzija)',
            'kk' => 'Kazaški',
            'km_KH' => 'Kmerski (Kambodža)',
            'kn_IN' => 'Karnatački (Indija)',
            'ko' => 'Korejski (Južna Koreja)',
            'ky_KG' => 'Kirgiski (Kirgistan)',
            'lo_LA' => 'Laoski (Laos)',
            'lt' => 'Litavski',
            'lv' => 'Latvijski',
            'mk_MK' => 'Makedonski (Sjeverna Makedonija)',
            'ml_IN' => 'Malajalamski (Indija)',
            'mn_MN' => 'Mongolski (Mongolija)',
            'mr_IN' => 'Marathski (Indija)',
            'ms' => 'Malajski',
            'my_MM' => 'Burmanski (Mjanmar [Burma])',
            'ne_NP' => 'Nepalski (Nepal)',
            'nl_NL' => 'Nizozemski (Nizozemska)',
            'no_NO' => 'Norveški (Norveška)',
            'pl_PL' => 'Poljski (Poljska)',
            'pt_BR' => 'Portugalski (Brazil)',
            'pt_PT' => 'Portugalski (Portugal)',
            'ro' => 'Rumunjski',
            'ru_RU' => 'Ruski (Rusija)',
            'si_LK' => 'Sinhaleški (Šri Lanka)',
            'sk' => 'Slovački',
            'sl' => 'Slovenski',
            'sr' => 'Srpski',
            'sv_SE' => 'Švedski (Švedska)',
            'sw' => 'Svahili',
            'ta_IN' => 'Tamilski (Indija)',
            'te_IN' => 'Teluški (Indija)',
            'th' => 'Tajlandski',
            'tr_TR' => 'Turski (Turska)',
            'uk' => 'Ukrajinski',
            'vi' => 'Vijetnamski',
            'zh_CN' => 'Kineski (pojednostavljeno pismo)',
            'zh_HK' => 'Kineski (Hong Kong)',
            'zh_TW' => 'Kineski (tradicionalno pismo)',
            'zu' => 'Zulu',
        ],
        'hu_HU' => [
            'af' => 'afrikaans',
            'am' => 'amhara',
            'ar' => 'arab',
            'az_AZ' => 'azerbajdzsáni (Azerbajdzsán)',
            'be' => 'belarusz',
            'bg' => 'bolgár',
            'bn_BD' => 'bangla (Banglades)',
            'ca' => 'katalán',
            'cs_CZ' => 'cseh (Csehország)',
            'da_DK' => 'dán (Dánia)',
            'de_DE' => 'német (Németország)',
            'el_GR' => 'görög (Görögország)',
            'en_AU' => 'angol (Ausztrália)',
            'en_CA' => 'angol (Kanada)',
            'en_GB' => 'angol (Egyesült Királyság)',
            'en_IN' => 'angol (India)',
            'en_SG' => 'angol (Szingapúr)',
            'en_US' => 'angol (Egyesült Államok)',
            'en_ZA' => 'angol (Dél-afrikai Köztársaság)',
            'es_419' => 'spanyol (Latin-Amerika)',
            'es_ES' => 'spanyol (Spanyolország)',
            'es_US' => 'spanyol (Egyesült Államok)',
            'et' => 'észt',
            'eu_ES' => 'baszk (Spanyolország)',
            'fa' => 'perzsa',
            'fi_FI' => 'finn (Finnország)',
            'fil' => 'filippínó',
            'fr_CA' => 'francia (Kanada)',
            'fr_FR' => 'francia (Franciaország)',
            'gl_ES' => 'gallego (Spanyolország)',
            'hi_IN' => 'hindi (India)',
            'hr' => 'horvát',
            'hy' => 'örmény (Örményország)',
            'id' => 'indonéz',
            'is_IS' => 'izlandi (Izland)',
            'it_IT' => 'olasz (Olaszország)',
            'iw_IL' => 'héber (Izrael)',
            'ja_JP' => 'japán (Japán)',
            'ka_GE' => 'grúz (Grúzia)',
            'kk' => 'kazah',
            'km_KH' => 'khmer (Kambodzsa)',
            'kn_IN' => 'kannada (India)',
            'ko' => 'koreai (Dél-Korea)',
            'ky_KG' => 'kirgiz (Kirgizisztán)',
            'lo_LA' => 'lao (Laosz)',
            'lt' => 'litván',
            'lv' => 'lett',
            'mk_MK' => 'macedón (Észak-Macedónia)',
            'ml_IN' => 'malajálam (India)',
            'mn_MN' => 'mongol (Mongólia)',
            'mr_IN' => 'maráthi (India)',
            'ms' => 'maláj',
            'my_MM' => 'burmai (Mianmar)',
            'ne_NP' => 'nepáli (Nepál)',
            'nl_NL' => 'holland (Hollandia)',
            'no_NO' => 'norvég (Norvégia)',
            'pl_PL' => 'lengyel (Lengyelország)',
            'pt_BR' => 'portugál (Brazília)',
            'pt_PT' => 'portugál (Portugália)',
            'ro' => 'román',
            'ru_RU' => 'orosz (Oroszország)',
            'si_LK' => 'szingaléz (Srí Lanka)',
            'sk' => 'szlovák',
            'sl' => 'szlovén',
            'sr' => 'szerb',
            'sv_SE' => 'svéd (Svédország)',
            'sw' => 'szuahéli',
            'ta_IN' => 'tamil (India)',
            'te_IN' => 'telugu (India)',
            'th' => 'thai',
            'tr_TR' => 'török (Törökország)',
            'uk' => 'ukrán',
            'vi' => 'vietnámi',
            'zh_CN' => 'kínai (Egyszerűsített)',
            'zh_HK' => 'kínai (Hongkong)',
            'zh_TW' => 'kínai (Hagyományos)',
            'zu' => 'zulu',
        ],
        'hy' => [
            'af' => 'աֆրիկաանս',
            'am' => 'ամհարերեն',
            'ar' => 'արաբերեն',
            'az_AZ' => 'ադրբեջաներեն (Ադրբեջան)',
            'be' => 'բելառուսերեն',
            'bg' => 'բուլղարերեն',
            'bn_BD' => 'բենգալերեն (Բանգլադեշ)',
            'ca' => 'կատալաներեն',
            'cs_CZ' => 'չեխերեն (Չեխիա)',
            'da_DK' => 'դանիերեն (Դանիա)',
            'de_DE' => 'գերմաներեն (Գերմանիա)',
            'el_GR' => 'հունարեն (Հունաստան)',
            'en_AU' => 'անգլերեն (Ավստրալիա)',
            'en_CA' => 'անգլերեն (Կանադա)',
            'en_GB' => 'անգլերեն (Միացյալ Թագավորություն)',
            'en_IN' => 'անգլերեն (Հնդկաստան)',
            'en_SG' => 'անգլերեն (Սինգապուր)',
            'en_US' => 'անգլերեն (Միացյալ Նահանգներ)',
            'en_ZA' => 'անգլերեն (Հարավաֆրիկյան Հանրապետություն)',
            'es_419' => 'իսպաներեն (Լատինական Ամերիկա)',
            'es_ES' => 'իսպաներեն (Իսպանիա)',
            'es_US' => 'իսպաներեն (Միացյալ Նահանգներ)',
            'et' => 'էստոներեն',
            'eu_ES' => 'բասկերեն (Իսպանիա)',
            'fa' => 'պարսկերեն',
            'fi_FI' => 'ֆիններեն (Ֆինլանդիա)',
            'fil' => 'ֆիլիպիներեն',
            'fr_CA' => 'ֆրանսերեն (Կանադա)',
            'fr_FR' => 'ֆրանսերեն (Ֆրանսիա)',
            'gl_ES' => 'գալիսերեն (Իսպանիա)',
            'hi_IN' => 'հինդի (Հնդկաստան)',
            'hr' => 'խորվաթերեն',
            'hu_HU' => 'հունգարերեն (Հունգարիա)',
            'id' => 'ինդոնեզերեն',
            'is_IS' => 'իսլանդերեն (Իսլանդիա)',
            'it_IT' => 'իտալերեն (Իտալիա)',
            'iw_IL' => 'եբրայերեն (Իսրայել)',
            'ja_JP' => 'ճապոներեն (Ճապոնիա)',
            'ka_GE' => 'վրացերեն (Վրաստան)',
            'kk' => 'ղազախերեն',
            'km_KH' => 'քմերերեն (Կամբոջա)',
            'kn_IN' => 'կաննադա (Հնդկաստան)',
            'ko' => 'կորեերեն (Հարավային Կորեա)',
            'ky_KG' => 'ղրղզերեն (Ղրղզստան)',
            'lo_LA' => 'լաոսերեն (Լաոս)',
            'lt' => 'լիտվերեն',
            'lv' => 'լատվիերեն',
            'mk_MK' => 'մակեդոներեն (Հյուսիսային Մակեդոնիա)',
            'ml_IN' => 'մալայալամ (Հնդկաստան)',
            'mn_MN' => 'մոնղոլերեն (Մոնղոլիա)',
            'mr_IN' => 'մարաթի (Հնդկաստան)',
            'ms' => 'մալայերեն',
            'my_MM' => 'բիրմայերեն (Մյանմա [Բիրմա])',
            'ne_NP' => 'նեպալերեն (Նեպալ)',
            'nl_NL' => 'հոլանդերեն (Նիդեռլանդներ)',
            'no_NO' => 'նորվեգերեն (Նորվեգիա)',
            'pl_PL' => 'լեհերեն (Լեհաստան)',
            'pt_BR' => 'պորտուգալերեն (Բրազիլիա)',
            'pt_PT' => 'պորտուգալերեն (Պորտուգալիա)',
            'ro' => 'ռումիներեն',
            'ru_RU' => 'ռուսերեն (Ռուսաստան)',
            'si_LK' => 'սինհալերեն (Շրի Լանկա)',
            'sk' => 'սլովակերեն',
            'sl' => 'սլովեներեն',
            'sr' => 'սերբերեն',
            'sv_SE' => 'շվեդերեն (Շվեդիա)',
            'sw' => 'սուահիլի',
            'ta_IN' => 'թամիլերեն (Հնդկաստան)',
            'te_IN' => 'թելուգու (Հնդկաստան)',
            'th' => 'թայերեն',
            'tr_TR' => 'թուրքերեն (Թուրքիա)',
            'uk' => 'ուկրաիներեն',
            'vi' => 'վիետնամերեն',
            'zh_CN' => 'չինարեն (պարզեցված չինական)',
            'zh_HK' => 'չինարեն (Հոնկոնգ)',
            'zh_TW' => 'չինարեն (ավանդական չինական)',
            'zu' => 'զուլուերեն',
        ],
        'id' => [
            'af' => 'Afrikaans',
            'am' => 'Amharik',
            'ar' => 'Arab',
            'az_AZ' => 'Azerbaijani (Azerbaijan)',
            'be' => 'Belarusia',
            'bg' => 'Bulgaria',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Katalan',
            'cs_CZ' => 'Cheska (Ceko)',
            'da_DK' => 'Dansk (Denmark)',
            'de_DE' => 'Jerman (Jerman)',
            'el_GR' => 'Yunani (Yunani)',
            'en_AU' => 'Inggris (Australia)',
            'en_CA' => 'Inggris (Kanada)',
            'en_GB' => 'Inggris (Inggris Raya)',
            'en_IN' => 'Inggris (India)',
            'en_SG' => 'Inggris (Singapura)',
            'en_US' => 'Inggris (Amerika Serikat)',
            'en_ZA' => 'Inggris (Afrika Selatan)',
            'es_419' => 'Spanyol (Amerika Latin)',
            'es_ES' => 'Spanyol (Spanyol)',
            'es_US' => 'Spanyol (Amerika Serikat)',
            'et' => 'Esti',
            'eu_ES' => 'Basque (Spanyol)',
            'fa' => 'Persia',
            'fi_FI' => 'Suomi (Finlandia)',
            'fil' => 'Filipino',
            'fr_CA' => 'Prancis (Kanada)',
            'fr_FR' => 'Prancis (Prancis)',
            'gl_ES' => 'Galisia (Spanyol)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Kroasia',
            'hu_HU' => 'Hungaria (Hungaria)',
            'hy' => 'Armenia (Armenia)',
            'is_IS' => 'Islandia (Islandia)',
            'it_IT' => 'Italia (Italia)',
            'iw_IL' => 'Ibrani (Israel)',
            'ja_JP' => 'Jepang (Jepang)',
            'ka_GE' => 'Georgia (Georgia)',
            'kk' => 'Kazakh',
            'km_KH' => 'Khmer (Kamboja)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korea (Korea Selatan)',
            'ky_KG' => 'Kirgiz (Kirgistan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lituavi',
            'lv' => 'Latvi',
            'mk_MK' => 'Makedonia (Makedonia Utara)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolia (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Melayu',
            'my_MM' => 'Burma (Myanmar [Burma])',
            'ne_NP' => 'Nepali (Nepal)',
            'nl_NL' => 'Belanda (Belanda)',
            'no_NO' => 'Norwegia (Norwegia)',
            'pl_PL' => 'Polski (Polandia)',
            'pt_BR' => 'Portugis (Brasil)',
            'pt_PT' => 'Portugis (Portugal)',
            'ro' => 'Rumania',
            'ru_RU' => 'Rusia (Rusia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Sloven',
            'sr' => 'Serbia',
            'sv_SE' => 'Swedia (Swedia)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turki (Turki)',
            'uk' => 'Ukraina',
            'vi' => 'Vietnam',
            'zh_CN' => 'Tionghoa (Sederhana)',
            'zh_HK' => 'Tionghoa (Hong Kong)',
            'zh_TW' => 'Tionghoa (Tradisional)',
            'zu' => 'Zulu',
        ],
        'is_IS' => [
            'af' => 'afríkanska',
            'am' => 'amharíska',
            'ar' => 'arabíska',
            'az_AZ' => 'aserska (Aserbaídsjan)',
            'be' => 'hvítrússneska',
            'bg' => 'búlgarska',
            'bn_BD' => 'bengalska (Bangladess)',
            'ca' => 'katalónska',
            'cs_CZ' => 'tékkneska (Tékkland)',
            'da_DK' => 'danska (Danmörk)',
            'de_DE' => 'þýska (Þýskaland)',
            'el_GR' => 'gríska (Grikkland)',
            'en_AU' => 'enska (Ástralía)',
            'en_CA' => 'enska (Kanada)',
            'en_GB' => 'enska (Bretland)',
            'en_IN' => 'enska (Indland)',
            'en_SG' => 'enska (Singapúr)',
            'en_US' => 'enska (Bandaríkin)',
            'en_ZA' => 'enska (Suður-Afríka)',
            'es_419' => 'spænska (Rómanska Ameríka)',
            'es_ES' => 'spænska (Spánn)',
            'es_US' => 'spænska (Bandaríkin)',
            'et' => 'eistneska',
            'eu_ES' => 'baskneska (Spánn)',
            'fa' => 'persneska',
            'fi_FI' => 'finnska (Finnland)',
            'fil' => 'filippseyska',
            'fr_CA' => 'franska (Kanada)',
            'fr_FR' => 'franska (Frakkland)',
            'gl_ES' => 'galíanska (Spánn)',
            'hi_IN' => 'hindí (Indland)',
            'hr' => 'króatíska',
            'hu_HU' => 'ungverska (Ungverjaland)',
            'hy' => 'armenska (Armenía)',
            'id' => 'indónesíska',
            'it_IT' => 'ítalska (Ítalía)',
            'iw_IL' => 'hebreska (Ísrael)',
            'ja_JP' => 'japanska (Japan)',
            'ka_GE' => 'georgíska (Georgía)',
            'kk' => 'kasakska',
            'km_KH' => 'kmer (Kambódía)',
            'kn_IN' => 'kannada (Indland)',
            'ko' => 'kóreska (Suður-Kórea)',
            'ky_KG' => 'kirgiska (Kirgistan)',
            'lo_LA' => 'laó (Laos)',
            'lt' => 'litháíska',
            'lv' => 'lettneska',
            'mk_MK' => 'makedónska (Norður-Makedónía)',
            'ml_IN' => 'malajalam (Indland)',
            'mn_MN' => 'mongólska (Mongólía)',
            'mr_IN' => 'maratí (Indland)',
            'ms' => 'malaíska',
            'my_MM' => 'burmneska (Mjanmar [Búrma])',
            'ne_NP' => 'nepalska (Nepal)',
            'nl_NL' => 'hollenska (Holland)',
            'no_NO' => 'norska (Noregur)',
            'pl_PL' => 'pólska (Pólland)',
            'pt_BR' => 'portúgalska (Brasilía)',
            'pt_PT' => 'portúgalska (Portúgal)',
            'ro' => 'rúmenska',
            'ru_RU' => 'rússneska (Rússland)',
            'si_LK' => 'singalíska (Srí Lanka)',
            'sk' => 'slóvakíska',
            'sl' => 'slóvenska',
            'sr' => 'serbneska',
            'sv_SE' => 'sænska (Svíþjóð)',
            'sw' => 'svahílí',
            'ta_IN' => 'tamílska (Indland)',
            'te_IN' => 'telúgú (Indland)',
            'th' => 'taílenska',
            'tr_TR' => 'tyrkneska (Tyrkland)',
            'uk' => 'úkraínska',
            'vi' => 'víetnamska',
            'zh_CN' => 'kínverska (einfaldað)',
            'zh_HK' => 'kínverska (Hong Kong)',
            'zh_TW' => 'kínverska (hefðbundið)',
            'zu' => 'súlú',
        ],
        'it_IT' => [
            'af' => 'Afrikaans',
            'am' => 'Amarico',
            'ar' => 'Arabo',
            'az_AZ' => 'Azerbaigiano (Azerbaigian)',
            'be' => 'Bielorusso',
            'bg' => 'Bulgaro',
            'bn_BD' => 'Bengalese (Bangladesh)',
            'ca' => 'Catalano',
            'cs_CZ' => 'Ceco (Cechia)',
            'da_DK' => 'Danese (Danimarca)',
            'de_DE' => 'Tedesco (Germania)',
            'el_GR' => 'Greco (Grecia)',
            'en_AU' => 'Inglese (Australia)',
            'en_CA' => 'Inglese (Canada)',
            'en_GB' => 'Inglese (Regno Unito)',
            'en_IN' => 'Inglese (India)',
            'en_SG' => 'Inglese (Singapore)',
            'en_US' => 'Inglese (Stati Uniti)',
            'en_ZA' => 'Inglese (Sudafrica)',
            'es_419' => 'Spagnolo (America Latina)',
            'es_ES' => 'Spagnolo (Spagna)',
            'es_US' => 'Spagnolo (Stati Uniti)',
            'et' => 'Estone',
            'eu_ES' => 'Basco (Spagna)',
            'fa' => 'Persiano',
            'fi_FI' => 'Finlandese (Finlandia)',
            'fil' => 'Filippino',
            'fr_CA' => 'Francese (Canada)',
            'fr_FR' => 'Francese (Francia)',
            'gl_ES' => 'Galiziano (Spagna)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croato',
            'hu_HU' => 'Ungherese (Ungheria)',
            'hy' => 'Armeno (Armenia)',
            'id' => 'Indonesiano',
            'is_IS' => 'Islandese (Islanda)',
            'iw_IL' => 'Ebraico (Israele)',
            'ja_JP' => 'Giapponese (Giappone)',
            'ka_GE' => 'Georgiano (Georgia)',
            'kk' => 'Kazako',
            'km_KH' => 'Khmer (Cambogia)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Coreano (Corea del Sud)',
            'ky_KG' => 'Kirghiso (Kirghizistan)',
            'lo_LA' => 'Lao (Laos)',
            'lt' => 'Lituano',
            'lv' => 'Lettone',
            'mk_MK' => 'Macedone (Macedonia del Nord)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolo (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Malese',
            'my_MM' => 'Birmano (Myanmar [Birmania])',
            'ne_NP' => 'Nepalese (Nepal)',
            'nl_NL' => 'Olandese (Paesi Bassi)',
            'no_NO' => 'Norvegese (Norvegia)',
            'pl_PL' => 'Polacco (Polonia)',
            'pt_BR' => 'Portoghese (Brasile)',
            'pt_PT' => 'Portoghese (Portogallo)',
            'ro' => 'Rumeno',
            'ru_RU' => 'Russo (Russia)',
            'si_LK' => 'Singalese (Sri Lanka)',
            'sk' => 'Slovacco',
            'sl' => 'Sloveno',
            'sr' => 'Serbo',
            'sv_SE' => 'Svedese (Svezia)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turco (Turchia)',
            'uk' => 'Ucraino',
            'vi' => 'Vietnamita',
            'zh_CN' => 'Cinese (semplificato)',
            'zh_HK' => 'Cinese (Hong Kong)',
            'zh_TW' => 'Cinese (tradizionale)',
            'zu' => 'Zulu',
        ],
        'iw_IL' => [
            'af' => 'אפריקאנס',
            'am' => 'אמהרית',
            'ar' => 'ערבית',
            'az_AZ' => 'אזרית (אזרבייג׳ן)',
            'be' => 'בלארוסית',
            'bg' => 'בולגרית',
            'bn_BD' => 'בנגלית (בנגלדש)',
            'ca' => 'קטלאנית',
            'cs_CZ' => 'צ׳כית (צ׳כיה)',
            'da_DK' => 'דנית (דנמרק)',
            'de_DE' => 'גרמנית (גרמניה)',
            'el_GR' => 'יוונית (יוון)',
            'en_AU' => 'אנגלית (אוסטרליה)',
            'en_CA' => 'אנגלית (קנדה)',
            'en_GB' => 'אנגלית (בריטניה)',
            'en_IN' => 'אנגלית (הודו)',
            'en_SG' => 'אנגלית (סינגפור)',
            'en_US' => 'אנגלית (ארצות הברית)',
            'en_ZA' => 'אנגלית (דרום אפריקה)',
            'es_419' => 'ספרדית (אמריקה הלטינית)',
            'es_ES' => 'ספרדית (ספרד)',
            'es_US' => 'ספרדית (ארצות הברית)',
            'et' => 'אסטונית',
            'eu_ES' => 'בסקית (ספרד)',
            'fa' => 'פרסית',
            'fi_FI' => 'פינית (פינלנד)',
            'fil' => 'פיליפינית',
            'fr_CA' => 'צרפתית (קנדה)',
            'fr_FR' => 'צרפתית (צרפת)',
            'gl_ES' => 'גליציאנית (ספרד)',
            'hi_IN' => 'הינדי (הודו)',
            'hr' => 'קרואטית',
            'hu_HU' => 'הונגרית (הונגריה)',
            'hy' => 'ארמנית (ארמניה)',
            'id' => 'אינדונזית',
            'is_IS' => 'איסלנדית (איסלנד)',
            'it_IT' => 'איטלקית (איטליה)',
            'ja_JP' => 'יפנית (יפן)',
            'ka_GE' => 'גאורגית (גאורגיה)',
            'kk' => 'קזחית',
            'km_KH' => 'חמרית (קמבודיה)',
            'kn_IN' => 'קנאדה (הודו)',
            'ko' => 'קוריאנית (קוריאה הדרומית)',
            'ky_KG' => 'קירגיזית (קירגיזסטן)',
            'lo_LA' => 'לאו (לאוס)',
            'lt' => 'ליטאית',
            'lv' => 'לטבית',
            'mk_MK' => 'מקדונית (מקדוניה הצפונית)',
            'ml_IN' => 'מליאלאם (הודו)',
            'mn_MN' => 'מונגולית (מונגוליה)',
            'mr_IN' => 'מראטהי (הודו)',
            'ms' => 'מלאית',
            'my_MM' => 'בורמזית (מיאנמר [בורמה])',
            'ne_NP' => 'נפאלית (נפאל)',
            'nl_NL' => 'הולנדית (הולנד)',
            'no_NO' => 'נורווגית (נורווגיה)',
            'pl_PL' => 'פולנית (פולין)',
            'pt_BR' => 'פורטוגזית (ברזיל)',
            'pt_PT' => 'פורטוגזית (פורטוגל)',
            'ro' => 'רומנית',
            'ru_RU' => 'רוסית (רוסיה)',
            'si_LK' => 'סינהלה (סרי לנקה)',
            'sk' => 'סלובקית',
            'sl' => 'סלובנית',
            'sr' => 'סרבית',
            'sv_SE' => 'שוודית (שוודיה)',
            'sw' => 'סווהילי',
            'ta_IN' => 'טמילית (הודו)',
            'te_IN' => 'טלוגו (הודו)',
            'th' => 'תאית',
            'tr_TR' => 'טורקית (טורקיה)',
            'uk' => 'אוקראינית',
            'vi' => 'וייטנאמית',
            'zh_CN' => 'סינית (פשוט)',
            'zh_HK' => 'סינית (הונג קונג)',
            'zh_TW' => 'סינית (מסורתי)',
            'zu' => 'זולו',
        ],
        'ja_JP' => [
            'af' => 'アフリカーンス語',
            'am' => 'アムハラ語',
            'ar' => 'アラビア語',
            'az_AZ' => 'アゼルバイジャン語 (アゼルバイジャン)',
            'be' => 'ベラルーシ語',
            'bg' => 'ブルガリア語',
            'bn_BD' => 'ベンガル語 (バングラデシュ)',
            'ca' => 'カタロニア語',
            'cs_CZ' => 'チェコ語 (チェコ)',
            'da_DK' => 'デンマーク語 (デンマーク)',
            'de_DE' => 'ドイツ語 (ドイツ)',
            'el_GR' => 'ギリシャ語 (ギリシャ)',
            'en_AU' => '英語 (オーストラリア)',
            'en_CA' => '英語 (カナダ)',
            'en_GB' => '英語 (イギリス)',
            'en_IN' => '英語 (インド)',
            'en_SG' => '英語 (シンガポール)',
            'en_US' => '英語 (アメリカ合衆国)',
            'en_ZA' => '英語 (南アフリカ)',
            'es_419' => 'スペイン語 (ラテンアメリカ)',
            'es_ES' => 'スペイン語 (スペイン)',
            'es_US' => 'スペイン語 (アメリカ合衆国)',
            'et' => 'エストニア語',
            'eu_ES' => 'バスク語 (スペイン)',
            'fa' => 'ペルシア語',
            'fi_FI' => 'フィンランド語 (フィンランド)',
            'fil' => 'フィリピノ語',
            'fr_CA' => 'フランス語 (カナダ)',
            'fr_FR' => 'フランス語 (フランス)',
            'gl_ES' => 'ガリシア語 (スペイン)',
            'hi_IN' => 'ヒンディー語 (インド)',
            'hr' => 'クロアチア語',
            'hu_HU' => 'ハンガリー語 (ハンガリー)',
            'hy' => 'アルメニア語 (アルメニア)',
            'id' => 'インドネシア語',
            'is_IS' => 'アイスランド語 (アイスランド)',
            'it_IT' => 'イタリア語 (イタリア)',
            'iw_IL' => 'ヘブライ語 (イスラエル)',
            'ka_GE' => 'ジョージア語 (ジョージア)',
            'kk' => 'カザフ語',
            'km_KH' => 'クメール語 (カンボジア)',
            'kn_IN' => 'カンナダ語 (インド)',
            'ko' => '韓国語 (韓国)',
            'ky_KG' => 'キルギス語 (キルギス)',
            'lo_LA' => 'ラオ語 (ラオス)',
            'lt' => 'リトアニア語',
            'lv' => 'ラトビア語',
            'mk_MK' => 'マケドニア語 (北マケドニア)',
            'ml_IN' => 'マラヤーラム語 (インド)',
            'mn_MN' => 'モンゴル語 (モンゴル)',
            'mr_IN' => 'マラーティー語 (インド)',
            'ms' => 'マレー語',
            'my_MM' => 'ミャンマー語 (ミャンマー [ビルマ])',
            'ne_NP' => 'ネパール語 (ネパール)',
            'nl_NL' => 'オランダ語 (オランダ)',
            'no_NO' => 'ノルウェー語 (ノルウェー)',
            'pl_PL' => 'ポーランド語 (ポーランド)',
            'pt_BR' => 'ポルトガル語 (ブラジル)',
            'pt_PT' => 'ポルトガル語 (ポルトガル)',
            'ro' => 'ルーマニア語',
            'ru_RU' => 'ロシア語 (ロシア)',
            'si_LK' => 'シンハラ語 (スリランカ)',
            'sk' => 'スロバキア語',
            'sl' => 'スロベニア語',
            'sr' => 'セルビア語',
            'sv_SE' => 'スウェーデン語 (スウェーデン)',
            'sw' => 'スワヒリ語',
            'ta_IN' => 'タミル語 (インド)',
            'te_IN' => 'テルグ語 (インド)',
            'th' => 'タイ語',
            'tr_TR' => 'トルコ語 (トルコ)',
            'uk' => 'ウクライナ語',
            'vi' => 'ベトナム語',
            'zh_CN' => '中国語 (簡体字)',
            'zh_HK' => '中国語 (香港)',
            'zh_TW' => '中国語 (繁体字)',
            'zu' => 'ズールー語',
        ],
        'ka_GE' => [
            'af' => 'აფრიკაანსი',
            'am' => 'ამჰარული',
            'ar' => 'არაბული',
            'az_AZ' => 'აზერბაიჯანული (აზერბაიჯანი)',
            'be' => 'ბელორუსული',
            'bg' => 'ბულგარული',
            'bn_BD' => 'ბენგალური (ბანგლადეში)',
            'ca' => 'კატალანური',
            'cs_CZ' => 'ჩეხური (ჩეხეთი)',
            'da_DK' => 'დანიური (დანია)',
            'de_DE' => 'გერმანული (გერმანია)',
            'el_GR' => 'ბერძნული (საბერძნეთი)',
            'en_AU' => 'ინგლისური (ავსტრალია)',
            'en_CA' => 'ინგლისური (კანადა)',
            'en_GB' => 'ინგლისური (გაერთიანებული სამეფო)',
            'en_IN' => 'ინგლისური (ინდოეთი)',
            'en_SG' => 'ინგლისური (სინგაპური)',
            'en_US' => 'ინგლისური (ამერიკის შეერთებული შტატები)',
            'en_ZA' => 'ინგლისური (სამხრეთ აფრიკის რესპუბლიკა)',
            'es_419' => 'ესპანური (ლათინური ამერიკა)',
            'es_ES' => 'ესპანური (ესპანეთი)',
            'es_US' => 'ესპანური (ამერიკის შეერთებული შტატები)',
            'et' => 'ესტონური',
            'eu_ES' => 'ბასკური (ესპანეთი)',
            'fa' => 'სპარსული',
            'fi_FI' => 'ფინური (ფინეთი)',
            'fil' => 'ფილიპინური',
            'fr_CA' => 'ფრანგული (კანადა)',
            'fr_FR' => 'ფრანგული (საფრანგეთი)',
            'gl_ES' => 'გალისიური (ესპანეთი)',
            'hi_IN' => 'ჰინდი (ინდოეთი)',
            'hr' => 'ხორვატული',
            'hu_HU' => 'უნგრული (უნგრეთი)',
            'hy' => 'სომხური (სომხეთი)',
            'id' => 'ინდონეზიური',
            'is_IS' => 'ისლანდიური (ისლანდია)',
            'it_IT' => 'იტალიური (იტალია)',
            'iw_IL' => 'ებრაული (ისრაელი)',
            'ja_JP' => 'იაპონური (იაპონია)',
            'kk' => 'ყაზახური',
            'km_KH' => 'ქმერული (კამბოჯა)',
            'kn_IN' => 'კანადა (ინდოეთი)',
            'ko' => 'კორეული (სამხრეთ კორეა)',
            'ky_KG' => 'ყირგიზული (ყირგიზეთი)',
            'lo_LA' => 'ლაოსური (ლაოსი)',
            'lt' => 'ლიეტუვური',
            'lv' => 'ლატვიური',
            'mk_MK' => 'მაკედონური (ჩრდილოეთ მაკედონია)',
            'ml_IN' => 'მალაიალამური (ინდოეთი)',
            'mn_MN' => 'მონღოლური (მონღოლეთი)',
            'mr_IN' => 'მარათჰი (ინდოეთი)',
            'ms' => 'მალაიური',
            'my_MM' => 'ბირმული (მიანმარი [ბირმა])',
            'ne_NP' => 'ნეპალური (ნეპალი)',
            'nl_NL' => 'ნიდერლანდური (ნიდერლანდები)',
            'no_NO' => 'ნორვეგიული (ნორვეგია)',
            'pl_PL' => 'პოლონური (პოლონეთი)',
            'pt_BR' => 'პორტუგალიური (ბრაზილია)',
            'pt_PT' => 'პორტუგალიური (პორტუგალია)',
            'ro' => 'რუმინული',
            'ru_RU' => 'რუსული (რუსეთი)',
            'si_LK' => 'სინჰალური (შრი-ლანკა)',
            'sk' => 'სლოვაკური',
            'sl' => 'სლოვენური',
            'sr' => 'სერბული',
            'sv_SE' => 'შვედური (შვედეთი)',
            'sw' => 'სუაჰილი',
            'ta_IN' => 'ტამილური (ინდოეთი)',
            'te_IN' => 'ტელუგუ (ინდოეთი)',
            'th' => 'ტაი',
            'tr_TR' => 'თურქული (თურქეთი)',
            'uk' => 'უკრაინული',
            'vi' => 'ვიეტნამური',
            'zh_CN' => 'ჩინური (გამარტივებული)',
            'zh_HK' => 'ჩინური (ჰონკონგი)',
            'zh_TW' => 'ჩინური (ტრადიციული)',
            'zu' => 'ზულუ',
        ],
        'kk' => [
            'af' => 'африкаанс тілі',
            'am' => 'амхар тілі',
            'ar' => 'араб тілі',
            'az_AZ' => 'әзірбайжан тілі (Әзірбайжан)',
            'be' => 'беларусь тілі',
            'bg' => 'болгар тілі',
            'bn_BD' => 'бенгал тілі (Бангладеш)',
            'ca' => 'каталан тілі',
            'cs_CZ' => 'чех тілі (Чехия)',
            'da_DK' => 'дат тілі (Дания)',
            'de_DE' => 'неміс тілі (Германия)',
            'el_GR' => 'грек тілі (Грекия)',
            'en_AU' => 'ағылшын тілі (Австралия)',
            'en_CA' => 'ағылшын тілі (Канада)',
            'en_GB' => 'ағылшын тілі (Ұлыбритания)',
            'en_IN' => 'ағылшын тілі (Үндістан)',
            'en_SG' => 'ағылшын тілі (Сингапур)',
            'en_US' => 'ағылшын тілі (Америка Құрама Штаттары)',
            'en_ZA' => 'ағылшын тілі (Оңтүстік Африка Республикасы)',
            'es_419' => 'испан тілі (Латын Америкасы)',
            'es_ES' => 'испан тілі (Испания)',
            'es_US' => 'испан тілі (Америка Құрама Штаттары)',
            'et' => 'эстон тілі',
            'eu_ES' => 'баск тілі (Испания)',
            'fa' => 'парсы тілі',
            'fi_FI' => 'фин тілі (Финляндия)',
            'fil' => 'филиппин тілі',
            'fr_CA' => 'француз тілі (Канада)',
            'fr_FR' => 'француз тілі (Франция)',
            'gl_ES' => 'галисия тілі (Испания)',
            'hi_IN' => 'хинди тілі (Үндістан)',
            'hr' => 'хорват тілі',
            'hu_HU' => 'венгр тілі (Венгрия)',
            'hy' => 'армян тілі (Армения)',
            'id' => 'индонезия тілі',
            'is_IS' => 'исланд тілі (Исландия)',
            'it_IT' => 'итальян тілі (Италия)',
            'iw_IL' => 'иврит тілі (Израиль)',
            'ja_JP' => 'жапон тілі (Жапония)',
            'ka_GE' => 'грузин тілі (Грузия)',
            'km_KH' => 'кхмер тілі (Камбоджа)',
            'kn_IN' => 'каннада тілі (Үндістан)',
            'ko' => 'корей тілі (Оңтүстік Корея)',
            'ky_KG' => 'қырғыз тілі (Қырғызстан)',
            'lo_LA' => 'лаос тілі (Лаос)',
            'lt' => 'литва тілі',
            'lv' => 'латыш тілі',
            'mk_MK' => 'македон тілі (Солтүстік Македония)',
            'ml_IN' => 'малаялам тілі (Үндістан)',
            'mn_MN' => 'моңғол тілі (Моңғолия)',
            'mr_IN' => 'маратхи тілі (Үндістан)',
            'ms' => 'малай тілі',
            'my_MM' => 'бирма тілі (Мьянма [Бирма])',
            'ne_NP' => 'непал тілі (Непал)',
            'nl_NL' => 'нидерланд тілі (Нидерланд)',
            'no_NO' => 'норвег тілі (Норвегия)',
            'pl_PL' => 'поляк тілі (Польша)',
            'pt_BR' => 'португал тілі (Бразилия)',
            'pt_PT' => 'португал тілі (Португалия)',
            'ro' => 'румын тілі',
            'ru_RU' => 'орыс тілі (Ресей)',
            'si_LK' => 'сингал тілі (Шри-Ланка)',
            'sk' => 'словак тілі',
            'sl' => 'словен тілі',
            'sr' => 'серб тілі',
            'sv_SE' => 'швед тілі (Швеция)',
            'sw' => 'суахили тілі',
            'ta_IN' => 'тамил тілі (Үндістан)',
            'te_IN' => 'телугу тілі (Үндістан)',
            'th' => 'тай тілі',
            'tr_TR' => 'түрік тілі (Түркия)',
            'uk' => 'украин тілі',
            'vi' => 'вьетнам тілі',
            'zh_CN' => 'қытай тілі (жеңілдетілген қытай иероглифы)',
            'zh_HK' => 'қытай тілі (Сянган)',
            'zh_TW' => 'қытай тілі (дәстүрлі қытай иероглифы)',
            'zu' => 'зулу тілі',
        ],
        'km_KH' => [
            'af' => 'អាហ្វ្រិកាន',
            'am' => 'អាំហារិក',
            'ar' => 'អារ៉ាប់',
            'az_AZ' => 'អាស៊ែបៃហ្សង់ (អាស៊ែបៃហ្សង់)',
            'be' => 'បេឡារុស',
            'bg' => 'ប៊ុលហ្គារី',
            'bn_BD' => 'បង់ក្លាដែស (បង់ក្លាដែស)',
            'ca' => 'កាតាឡាន',
            'cs_CZ' => 'ឆែក (ឆែគា)',
            'da_DK' => 'ដាណឺម៉ាក (ដាណឺម៉ាក)',
            'de_DE' => 'អាល្លឺម៉ង់ (អាល្លឺម៉ង់)',
            'el_GR' => 'ក្រិក (ក្រិក)',
            'en_AU' => 'អង់គ្លេស (អូស្ត្រាលី)',
            'en_CA' => 'អង់គ្លេស (កាណាដា)',
            'en_GB' => 'អង់គ្លេស (ចក្រភពអង់គ្លេស)',
            'en_IN' => 'អង់គ្លេស (ឥណ្ឌា)',
            'en_SG' => 'អង់គ្លេស (សិង្ហបុរី)',
            'en_US' => 'អង់គ្លេស (សហរដ្ឋអាមេរិក)',
            'en_ZA' => 'អង់គ្លេស (អាហ្វ្រិកខាងត្បូង)',
            'es_419' => 'អេស្ប៉ាញ (អាមេរិកឡាទីន)',
            'es_ES' => 'អេស្ប៉ាញ (អេស្ប៉ាញ)',
            'es_US' => 'អេស្ប៉ាញ (សហរដ្ឋអាមេរិក)',
            'et' => 'អេស្តូនី',
            'eu_ES' => 'បាសខ៍ (អេស្ប៉ាញ)',
            'fa' => 'ភឺសៀន',
            'fi_FI' => 'ហ្វាំងឡង់ (ហ្វាំងឡង់)',
            'fil' => 'ហ្វីលីពីន',
            'fr_CA' => 'បារាំង (កាណាដា)',
            'fr_FR' => 'បារាំង (បារាំង)',
            'gl_ES' => 'ហ្គាលីស្យាន (អេស្ប៉ាញ)',
            'hi_IN' => 'ហិណ្ឌី (ឥណ្ឌា)',
            'hr' => 'ក្រូអាត',
            'hu_HU' => 'ហុងគ្រី (ហុងគ្រី)',
            'hy' => 'អាមេនី (អាមេនី)',
            'id' => 'ឥណ្ឌូណេស៊ី',
            'is_IS' => 'អ៊ីស្លង់ (អ៊ីស្លង់)',
            'it_IT' => 'អ៊ីតាលី (អ៊ីតាលី)',
            'iw_IL' => 'ហេប្រឺ (អ៊ីស្រាអែល)',
            'ja_JP' => 'ជប៉ុន (ជប៉ុន)',
            'ka_GE' => 'ហ្សកហ្ស៊ី (ហ្សកហ្ស៊ី)',
            'kk' => 'កាហ្សាក់',
            'kn_IN' => 'ខាណាដា (ឥណ្ឌា)',
            'ko' => 'កូរ៉េ (កូរ៉េខាងត្បូង)',
            'ky_KG' => 'កៀហ្ស៊ីស (កៀហ្ស៊ីស៊ីស្ថាន)',
            'lo_LA' => 'ឡាវ (ឡាវ)',
            'lt' => 'លីទុយអានី',
            'lv' => 'ឡាតវី',
            'mk_MK' => 'ម៉ាសេដូនី (ម៉ាសេដ្វានខាងជើង)',
            'ml_IN' => 'ម៉ាឡាយ៉ាឡាម (ឥណ្ឌា)',
            'mn_MN' => 'ម៉ុងហ្គោលី (ម៉ុងហ្គោលី)',
            'mr_IN' => 'ម៉ារ៉ាធី (ឥណ្ឌា)',
            'ms' => 'ម៉ាឡេ',
            'my_MM' => 'ភូមា (មីយ៉ាន់ម៉ា [ភូមា])',
            'ne_NP' => 'នេប៉ាល់ (នេប៉ាល់)',
            'nl_NL' => 'ហូឡង់ (ហូឡង់)',
            'no_NO' => 'ន័រវែស (ន័រវែស)',
            'pl_PL' => 'ប៉ូឡូញ (ប៉ូឡូញ)',
            'pt_BR' => 'ព័រទុយហ្គាល់ (ប្រេស៊ីល)',
            'pt_PT' => 'ព័រទុយហ្គាល់ (ព័រទុយហ្គាល់)',
            'ro' => 'រូម៉ានី',
            'ru_RU' => 'រុស្ស៊ី (រុស្ស៊ី)',
            'si_LK' => 'ស្រីលង្កា (ស្រីលង្កា)',
            'sk' => 'ស្លូវ៉ាគី',
            'sl' => 'ស្លូវ៉ានី',
            'sr' => 'ស៊ែប',
            'sv_SE' => 'ស៊ុយអែត (ស៊ុយអែត)',
            'sw' => 'ស្វាហ៊ីលី',
            'ta_IN' => 'តាមីល (ឥណ្ឌា)',
            'te_IN' => 'តេលុគុ (ឥណ្ឌា)',
            'th' => 'ថៃ',
            'tr_TR' => 'ទួរគី (តួកគី)',
            'uk' => 'អ៊ុយក្រែន',
            'vi' => 'វៀតណាម',
            'zh_CN' => 'ចិន (អក្សរចិនកាត់)',
            'zh_HK' => 'ចិន (ហុងកុង តំបន់រដ្ឋបាលពិសេសចិន)',
            'zh_TW' => 'ចិន (អក្សរចិនពេញ)',
            'zu' => 'ហ្សូលូ',
        ],
        'kn_IN' => [
            'af' => 'ಆಫ್ರಿಕಾನ್ಸ್',
            'am' => 'ಅಂಹರಿಕ್',
            'ar' => 'ಅರೇಬಿಕ್',
            'az_AZ' => 'ಅಜೆರ್ಬೈಜಾನಿ (ಅಜರ್ಬೈಜಾನ್)',
            'be' => 'ಬೆಲರೂಸಿಯನ್',
            'bg' => 'ಬಲ್ಗೇರಿಯನ್',
            'bn_BD' => 'ಬಾಂಗ್ಲಾ (ಬಾಂಗ್ಲಾದೇಶ)',
            'ca' => 'ಕೆಟಲಾನ್',
            'cs_CZ' => 'ಜೆಕ್ (ಝೆಕಿಯಾ)',
            'da_DK' => 'ಡ್ಯಾನಿಶ್ (ಡೆನ್ಮಾರ್ಕ್)',
            'de_DE' => 'ಜರ್ಮನ್ (ಜರ್ಮನಿ)',
            'el_GR' => 'ಗ್ರೀಕ್ (ಗ್ರೀಸ್)',
            'en_AU' => 'ಇಂಗ್ಲಿಷ್ (ಆಸ್ಟ್ರೇಲಿಯಾ)',
            'en_CA' => 'ಇಂಗ್ಲಿಷ್ (ಕೆನಡಾ)',
            'en_GB' => 'ಇಂಗ್ಲಿಷ್ (ಯುನೈಟೆಡ್ ಕಿಂಗ್‌ಡಮ್)',
            'en_IN' => 'ಇಂಗ್ಲಿಷ್ (ಭಾರತ)',
            'en_SG' => 'ಇಂಗ್ಲಿಷ್ (ಸಿಂಗಪುರ್)',
            'en_US' => 'ಇಂಗ್ಲಿಷ್ (ಯುನೈಟೆಡ್ ಸ್ಟೇಟ್ಸ್)',
            'en_ZA' => 'ಇಂಗ್ಲಿಷ್ (ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ)',
            'es_419' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಲ್ಯಾಟಿನ್ ಅಮೇರಿಕಾ)',
            'es_ES' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಸ್ಪೇನ್)',
            'es_US' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಯುನೈಟೆಡ್ ಸ್ಟೇಟ್ಸ್)',
            'et' => 'ಎಸ್ಟೊನಿಯನ್',
            'eu_ES' => 'ಬಾಸ್ಕ್ (ಸ್ಪೇನ್)',
            'fa' => 'ಪರ್ಶಿಯನ್',
            'fi_FI' => 'ಫಿನ್ನಿಶ್ (ಫಿನ್‌ಲ್ಯಾಂಡ್)',
            'fil' => 'ಫಿಲಿಪಿನೊ',
            'fr_CA' => 'ಫ್ರೆಂಚ್ (ಕೆನಡಾ)',
            'fr_FR' => 'ಫ್ರೆಂಚ್ (ಫ್ರಾನ್ಸ್)',
            'gl_ES' => 'ಗ್ಯಾಲಿಶಿಯನ್ (ಸ್ಪೇನ್)',
            'hi_IN' => 'ಹಿಂದಿ (ಭಾರತ)',
            'hr' => 'ಕ್ರೊಯೇಶಿಯನ್',
            'hu_HU' => 'ಹಂಗೇರಿಯನ್ (ಹಂಗೇರಿ)',
            'hy' => 'ಅರ್ಮೇನಿಯನ್ (ಆರ್ಮೇನಿಯ)',
            'id' => 'ಇಂಡೋನೇಶಿಯನ್',
            'is_IS' => 'ಐಸ್‌ಲ್ಯಾಂಡಿಕ್ (ಐಸ್‌ಲ್ಯಾಂಡ್)',
            'it_IT' => 'ಇಟಾಲಿಯನ್ (ಇಟಲಿ)',
            'iw_IL' => 'ಹೀಬ್ರೂ (ಇಸ್ರೇಲ್)',
            'ja_JP' => 'ಜಾಪನೀಸ್ (ಜಪಾನ್)',
            'ka_GE' => 'ಜಾರ್ಜಿಯನ್ (ಜಾರ್ಜಿಯಾ)',
            'kk' => 'ಕಝಕ್',
            'km_KH' => 'ಖಮೇರ್ (ಕಾಂಬೋಡಿಯಾ)',
            'ko' => 'ಕೊರಿಯನ್ (ದಕ್ಷಿಣ ಕೊರಿಯಾ)',
            'ky_KG' => 'ಕಿರ್ಗಿಜ್ (ಕಿರ್ಗಿಸ್ಥಾನ್)',
            'lo_LA' => 'ಲಾವೋ (ಲಾವೋಸ್)',
            'lt' => 'ಲಿಥುವೇನಿಯನ್',
            'lv' => 'ಲಾಟ್ವಿಯನ್',
            'mk_MK' => 'ಮೆಸಿಡೋನಿಯನ್ (ಉತ್ತರ ಮ್ಯಾಸಿಡೋನಿಯಾ)',
            'ml_IN' => 'ಮಲಯಾಳಂ (ಭಾರತ)',
            'mn_MN' => 'ಮಂಗೋಲಿಯನ್ (ಮಂಗೋಲಿಯಾ)',
            'mr_IN' => 'ಮರಾಠಿ (ಭಾರತ)',
            'ms' => 'ಮಲಯ್',
            'my_MM' => 'ಬರ್ಮೀಸ್ (ಮಯನ್ಮಾರ್ [ಬರ್ಮಾ])',
            'ne_NP' => 'ನೇಪಾಳಿ (ನೇಪಾಳ)',
            'nl_NL' => 'ಡಚ್ (ನೆದರ್‌ಲ್ಯಾಂಡ್ಸ್)',
            'no_NO' => 'ನಾರ್ವೇಜಿಯನ್ (ನಾರ್ವೆ)',
            'pl_PL' => 'ಪೊಲಿಶ್ (ಪೋಲ್ಯಾಂಡ್)',
            'pt_BR' => 'ಪೋರ್ಚುಗೀಸ್ (ಬ್ರೆಜಿಲ್)',
            'pt_PT' => 'ಪೋರ್ಚುಗೀಸ್ (ಪೋರ್ಚುಗಲ್)',
            'ro' => 'ರೊಮೇನಿಯನ್',
            'ru_RU' => 'ರಷ್ಯನ್ (ರಷ್ಯಾ)',
            'si_LK' => 'ಸಿಂಹಳ (ಶ್ರೀಲಂಕಾ)',
            'sk' => 'ಸ್ಲೋವಾಕ್',
            'sl' => 'ಸ್ಲೋವೇನಿಯನ್',
            'sr' => 'ಸೆರ್ಬಿಯನ್',
            'sv_SE' => 'ಸ್ವೀಡಿಷ್ (ಸ್ವೀಡನ್)',
            'sw' => 'ಸ್ವಹಿಲಿ',
            'ta_IN' => 'ತಮಿಳು (ಭಾರತ)',
            'te_IN' => 'ತೆಲುಗು (ಭಾರತ)',
            'th' => 'ಥಾಯ್',
            'tr_TR' => 'ಟರ್ಕಿಶ್ (ಟರ್ಕಿ)',
            'uk' => 'ಉಕ್ರೇನಿಯನ್',
            'vi' => 'ವಿಯೆಟ್ನಾಮೀಸ್',
            'zh_CN' => 'ಚೈನೀಸ್ (ಸರಳೀಕೃತ)',
            'zh_HK' => 'ಚೈನೀಸ್ (ಹಾಂಗ್ ಕಾಂಗ್)',
            'zh_TW' => 'ಚೈನೀಸ್ (ಸಾಂಪ್ರದಾಯಿಕ)',
            'zu' => 'ಜುಲು',
        ],
        'ko' => [
            'af' => '아프리칸스어',
            'am' => '암하라어',
            'ar' => '아랍어',
            'az_AZ' => '아제르바이잔어(아제르바이잔)',
            'be' => '벨라루스어',
            'bg' => '불가리아어',
            'bn_BD' => '벵골어(방글라데시)',
            'ca' => '카탈로니아어',
            'cs_CZ' => '체코어(체코)',
            'da_DK' => '덴마크어(덴마크)',
            'de_DE' => '독일어(독일)',
            'el_GR' => '그리스어(그리스)',
            'en_AU' => '영어(오스트레일리아)',
            'en_CA' => '영어(캐나다)',
            'en_GB' => '영어(영국)',
            'en_IN' => '영어(인도)',
            'en_SG' => '영어(싱가포르)',
            'en_US' => '영어(미국)',
            'en_ZA' => '영어(남아프리카)',
            'es_419' => '스페인어(라틴 아메리카)',
            'es_ES' => '스페인어(스페인)',
            'es_US' => '스페인어(미국)',
            'et' => '에스토니아어',
            'eu_ES' => '바스크어(스페인)',
            'fa' => '페르시아어',
            'fi_FI' => '핀란드어(핀란드)',
            'fil' => '필리핀어',
            'fr_CA' => '프랑스어(캐나다)',
            'fr_FR' => '프랑스어(프랑스)',
            'gl_ES' => '갈리시아어(스페인)',
            'hi_IN' => '힌디어(인도)',
            'hr' => '크로아티아어',
            'hu_HU' => '헝가리어(헝가리)',
            'hy' => '아르메니아어(아르메니아)',
            'id' => '인도네시아어',
            'is_IS' => '아이슬란드어(아이슬란드)',
            'it_IT' => '이탈리아어(이탈리아)',
            'iw_IL' => '히브리어(이스라엘)',
            'ja_JP' => '일본어(일본)',
            'ka_GE' => '조지아어(조지아)',
            'kk' => '카자흐어',
            'km_KH' => '크메르어(캄보디아)',
            'kn_IN' => '칸나다어(인도)',
            'ky_KG' => '키르기스어(키르기스스탄)',
            'lo_LA' => '라오어(라오스)',
            'lt' => '리투아니아어',
            'lv' => '라트비아어',
            'mk_MK' => '마케도니아어(북마케도니아)',
            'ml_IN' => '말라얄람어(인도)',
            'mn_MN' => '몽골어(몽골)',
            'mr_IN' => '마라티어(인도)',
            'ms' => '말레이어',
            'my_MM' => '버마어(미얀마)',
            'ne_NP' => '네팔어(네팔)',
            'nl_NL' => '네덜란드어(네덜란드)',
            'no_NO' => '노르웨이어(노르웨이)',
            'pl_PL' => '폴란드어(폴란드)',
            'pt_BR' => '포르투갈어(브라질)',
            'pt_PT' => '포르투갈어(포르투갈)',
            'ro' => '루마니아어',
            'ru_RU' => '러시아어(러시아)',
            'si_LK' => '스리랑카어(스리랑카)',
            'sk' => '슬로바키아어',
            'sl' => '슬로베니아어',
            'sr' => '세르비아어',
            'sv_SE' => '스웨덴어(스웨덴)',
            'sw' => '스와힐리어',
            'ta_IN' => '타밀어(인도)',
            'te_IN' => '텔루구어(인도)',
            'th' => '태국어',
            'tr_TR' => '터키어(터키)',
            'uk' => '우크라이나어',
            'vi' => '베트남어',
            'zh_CN' => '중국어(간체)',
            'zh_HK' => '중국어(홍콩)',
            'zh_TW' => '중국어(번체)',
            'zu' => '줄루어',
        ],
        'ky_KG' => [
            'af' => 'африкаанча',
            'am' => 'амхарча',
            'ar' => 'арабча',
            'az_AZ' => 'азербайжанча (Азербайжан)',
            'be' => 'беларусча',
            'bg' => 'болгарча',
            'bn_BD' => 'бангладешче (Бангладеш)',
            'ca' => 'каталонча',
            'cs_CZ' => 'чехче (Чехия)',
            'da_DK' => 'датча (Дания)',
            'de_DE' => 'немисче (Германия)',
            'el_GR' => 'грекче (Греция)',
            'en_AU' => 'англисче (Австралия)',
            'en_CA' => 'англисче (Канада)',
            'en_GB' => 'англисче (Улуу Британия)',
            'en_IN' => 'англисче (Индия)',
            'en_SG' => 'англисче (Сингапур)',
            'en_US' => 'англисче (Кошмо Штаттар)',
            'en_ZA' => 'англисче (Түштүк-Африка Республикасы)',
            'es_419' => 'испанча (Латын Америкасы)',
            'es_ES' => 'испанча (Испания)',
            'es_US' => 'испанча (Кошмо Штаттар)',
            'et' => 'эстончо',
            'eu_ES' => 'баскча (Испания)',
            'fa' => 'фарсча',
            'fi_FI' => 'финче (Финляндия)',
            'fil' => 'филипинче',
            'fr_CA' => 'французча (Канада)',
            'fr_FR' => 'французча (Франция)',
            'gl_ES' => 'галисияча (Испания)',
            'hi_IN' => 'хиндиче (Индия)',
            'hr' => 'хорватча',
            'hu_HU' => 'венгерче (Венгрия)',
            'hy' => 'армянча (Армения)',
            'id' => 'индонезияча',
            'is_IS' => 'исландча (Исландия)',
            'it_IT' => 'италиянча (Италия)',
            'iw_IL' => 'ивритче (Израиль)',
            'ja_JP' => 'жапончо (Япония)',
            'ka_GE' => 'грузинче (Грузия)',
            'kk' => 'казакча',
            'km_KH' => 'кмерче (Камбоджа)',
            'kn_IN' => 'каннадача (Индия)',
            'ko' => 'корейче (Түштүк Корея)',
            'lo_LA' => 'лаочо (Лаос)',
            'lt' => 'литовчо',
            'lv' => 'латышча',
            'mk_MK' => 'македончо (Түндүк Македония)',
            'ml_IN' => 'малайаламча (Индия)',
            'mn_MN' => 'монголчо (Монголия)',
            'mr_IN' => 'маратиче (Индия)',
            'ms' => 'малайча',
            'my_MM' => 'бурмача (Мьянма [Бирма])',
            'ne_NP' => 'непалча (Непал)',
            'nl_NL' => 'голландча (Нидерланд)',
            'no_NO' => 'норвежче (Норвегия)',
            'pl_PL' => 'полякча (Польша)',
            'pt_BR' => 'португалча (Бразилия)',
            'pt_PT' => 'португалча (Португалия)',
            'ro' => 'румынча',
            'ru_RU' => 'орусча (Россия)',
            'si_LK' => 'сингалача (Шри-Ланка)',
            'sk' => 'словакча',
            'sl' => 'словенче',
            'sr' => 'сербче',
            'sv_SE' => 'шведче (Швеция)',
            'sw' => 'суахиличе',
            'ta_IN' => 'тамилче (Индия)',
            'te_IN' => 'телугуча (Индия)',
            'th' => 'тайча',
            'tr_TR' => 'түркчө (Түркия)',
            'uk' => 'украинче',
            'vi' => 'вьетнамча',
            'zh_CN' => 'кытайча (Жөнөкөйлөштүрүлгөн)',
            'zh_HK' => 'кытайча (Гонконг)',
            'zh_TW' => 'кытайча (Салттуу)',
            'zu' => 'зулуча',
        ],
        'lo_LA' => [
            'af' => 'ອາຟຣິການ',
            'am' => 'ອຳຮາຣິກ',
            'ar' => 'ອາຣັບ',
            'az_AZ' => 'ອາເຊີໄບຈານິ (ອາເຊີໄບຈານ)',
            'be' => 'ເບລາຣັສຊຽນ',
            'bg' => 'ບັງກາຣຽນ',
            'bn_BD' => 'ເບັງກາລີ (ບັງກະລາເທດ)',
            'ca' => 'ຄາຕາລານ',
            'cs_CZ' => 'ເຊກ (ເຊັກເຊຍ)',
            'da_DK' => 'ແດນິຊ (ເດນມາກ)',
            'de_DE' => 'ເຢຍລະມັນ (ເຢຍລະມັນ)',
            'el_GR' => 'ກຣີກ (ກຣີຊ)',
            'en_AU' => 'ອັງກິດ (ອອສເຕຣເລຍ)',
            'en_CA' => 'ອັງກິດ (ແຄນາດາ)',
            'en_GB' => 'ອັງກິດ (ສະຫະລາດຊະອະນາຈັກ)',
            'en_IN' => 'ອັງກິດ (ອິນເດຍ)',
            'en_SG' => 'ອັງກິດ (ສິງກະໂປ)',
            'en_US' => 'ອັງກິດ (ສະຫະລັດ)',
            'en_ZA' => 'ອັງກິດ (ອາຟຣິກາໃຕ້)',
            'es_419' => 'ສະແປນນິຊ (ລາຕິນ ອາເມລິກາ)',
            'es_ES' => 'ສະແປນນິຊ (ສະເປນ)',
            'es_US' => 'ສະແປນນິຊ (ສະຫະລັດ)',
            'et' => 'ເອສໂຕນຽນ',
            'eu_ES' => 'ບັສກີ (ສະເປນ)',
            'fa' => 'ເປີຊຽນ',
            'fi_FI' => 'ຟິນນິຊ (ຟິນແລນ)',
            'fil' => 'ຟີລິປີໂນ',
            'fr_CA' => 'ຝຣັ່ງ (ແຄນາດາ)',
            'fr_FR' => 'ຝຣັ່ງ (ຝຣັ່ງ)',
            'gl_ES' => 'ກາລິຊຽນ (ສະເປນ)',
            'hi_IN' => 'ຮິນດິ (ອິນເດຍ)',
            'hr' => 'ໂຄຣເອທຽນ',
            'hu_HU' => 'ຮັງກາຣຽນ (ຮັງກາຣີ)',
            'hy' => 'ອາເມນຽນ (ອາເມເນຍ)',
            'id' => 'ອິນໂດເນຊຽນ',
            'is_IS' => 'ໄອສແລນດິກ (ໄອສແລນ)',
            'it_IT' => 'ອິຕາລຽນ (ອິຕາລີ)',
            'iw_IL' => 'ຮີບຣິວ (ອິສຣາເອວ)',
            'ja_JP' => 'ຍີ່ປຸ່ນ (ຍີ່ປຸ່ນ)',
            'ka_GE' => 'ຈໍຈຽນ (ຈໍເຈຍ)',
            'kk' => 'ຄາຊັກ',
            'km_KH' => 'ຂະເໝນ (ກຳປູເຈຍ)',
            'kn_IN' => 'ຄັນນາດາ (ອິນເດຍ)',
            'ko' => 'ເກົາຫລີ (ເກົາຫລີໃຕ້)',
            'ky_KG' => 'ເກຍກີສ (ຄຽກກິດສະຖານ)',
            'lt' => 'ລິທົວນຽນ',
            'lv' => 'ລັດວຽນ',
            'mk_MK' => 'ແມຊິໂດນຽນ (ແມຊິໂດເນຍເໜືອ)',
            'ml_IN' => 'ມາເລອາລຳ (ອິນເດຍ)',
            'mn_MN' => 'ມອງໂກເລຍ (ມອງໂກເລຍ)',
            'mr_IN' => 'ມາຣາທີ (ອິນເດຍ)',
            'ms' => 'ມາເລ',
            'my_MM' => 'ມຽນມາ (ມຽນມາ [ເບີມາ])',
            'ne_NP' => 'ເນປາລີ (ເນປານ)',
            'nl_NL' => 'ດັຊ (ເນເທີແລນ)',
            'no_NO' => 'ນໍເວຍ (ນໍເວ)',
            'pl_PL' => 'ໂປລິຊ (ໂປແລນ)',
            'pt_BR' => 'ປອກຕຸຍກິສ (ບຣາຊິວ)',
            'pt_PT' => 'ປອກຕຸຍກິສ (ພອລທູໂກ)',
            'ro' => 'ໂຣແມນຽນ',
            'ru_RU' => 'ລັດເຊຍ (ຣັດເຊຍ)',
            'si_LK' => 'ສິນຫາລາ (ສີລັງກາ)',
            'sk' => 'ສະໂລແວັກ',
            'sl' => 'ສະໂລເວນຽນ',
            'sr' => 'ເຊີບຽນ',
            'sv_SE' => 'ສະວີດິຊ (ສະວີເດັນ)',
            'sw' => 'ຊວາຮີລິ',
            'ta_IN' => 'ທາມິລ (ອິນເດຍ)',
            'te_IN' => 'ເຕລູກູ (ອິນເດຍ)',
            'th' => 'ໄທ',
            'tr_TR' => 'ເທີຄິຊ (ເທີຄີ)',
            'uk' => 'ຢູເຄຣນຽນ',
            'vi' => 'ຫວຽດນາມ',
            'zh_CN' => 'ຈີນ (ແບບຮຽບງ່າຍ)',
            'zh_HK' => 'ຈີນ (ຮົງກົງ)',
            'zh_TW' => 'ຈີນ (ແບບດັ້ງເດີມ)',
            'zu' => 'ຊູລູ',
        ],
        'lt' => [
            'af' => 'afrikanų',
            'am' => 'amharų',
            'ar' => 'arabų',
            'az_AZ' => 'azerbaidžaniečių (Azerbaidžanas)',
            'be' => 'baltarusių',
            'bg' => 'bulgarų',
            'bn_BD' => 'bengalų (Bangladešas)',
            'ca' => 'katalonų',
            'cs_CZ' => 'čekų (Čekija)',
            'da_DK' => 'danų (Danija)',
            'de_DE' => 'vokiečių (Vokietija)',
            'el_GR' => 'graikų (Graikija)',
            'en_AU' => 'anglų (Australija)',
            'en_CA' => 'anglų (Kanada)',
            'en_GB' => 'anglų (Jungtinė Karalystė)',
            'en_IN' => 'anglų (Indija)',
            'en_SG' => 'anglų (Singapūras)',
            'en_US' => 'anglų (Jungtinės Valstijos)',
            'en_ZA' => 'anglų (Pietų Afrika)',
            'es_419' => 'ispanų (Lotynų Amerika)',
            'es_ES' => 'ispanų (Ispanija)',
            'es_US' => 'ispanų (Jungtinės Valstijos)',
            'et' => 'estų',
            'eu_ES' => 'baskų (Ispanija)',
            'fa' => 'persų',
            'fi_FI' => 'suomių (Suomija)',
            'fil' => 'filipiniečių',
            'fr_CA' => 'prancūzų (Kanada)',
            'fr_FR' => 'prancūzų (Prancūzija)',
            'gl_ES' => 'galisų (Ispanija)',
            'hi_IN' => 'hindi (Indija)',
            'hr' => 'kroatų',
            'hu_HU' => 'vengrų (Vengrija)',
            'hy' => 'armėnų (Armėnija)',
            'id' => 'indoneziečių',
            'is_IS' => 'islandų (Islandija)',
            'it_IT' => 'italų (Italija)',
            'iw_IL' => 'hebrajų (Izraelis)',
            'ja_JP' => 'japonų (Japonija)',
            'ka_GE' => 'gruzinų (Gruzija)',
            'kk' => 'kazachų',
            'km_KH' => 'khmerų (Kambodža)',
            'kn_IN' => 'kanadų (Indija)',
            'ko' => 'korėjiečių (Pietų Korėja)',
            'ky_KG' => 'kirgizų (Kirgizija)',
            'lo_LA' => 'laosiečių (Laosas)',
            'lv' => 'latvių',
            'mk_MK' => 'makedonų (Šiaurės Makedonija)',
            'ml_IN' => 'malajalių (Indija)',
            'mn_MN' => 'mongolų (Mongolija)',
            'mr_IN' => 'maratų (Indija)',
            'ms' => 'malajiečių',
            'my_MM' => 'birmiečių (Mianmaras [Birma])',
            'ne_NP' => 'nepaliečių (Nepalas)',
            'nl_NL' => 'olandų (Nyderlandai)',
            'no_NO' => 'norvegų (Norvegija)',
            'pl_PL' => 'lenkų (Lenkija)',
            'pt_BR' => 'portugalų (Brazilija)',
            'pt_PT' => 'portugalų (Portugalija)',
            'ro' => 'rumunų',
            'ru_RU' => 'rusų (Rusija)',
            'si_LK' => 'sinhalų (Šri Lanka)',
            'sk' => 'slovakų',
            'sl' => 'slovėnų',
            'sr' => 'serbų',
            'sv_SE' => 'švedų (Švedija)',
            'sw' => 'suahilių',
            'ta_IN' => 'tamilų (Indija)',
            'te_IN' => 'telugų (Indija)',
            'th' => 'tajų',
            'tr_TR' => 'turkų (Turkija)',
            'uk' => 'ukrainiečių',
            'vi' => 'vietnamiečių',
            'zh_CN' => 'kinų (supaprastinti)',
            'zh_HK' => 'kinų (Honkongas)',
            'zh_TW' => 'kinų (tradiciniai)',
            'zu' => 'zulų',
        ],
        'lv' => [
            'af' => 'afrikandu',
            'am' => 'amharu',
            'ar' => 'arābu',
            'az_AZ' => 'azerbaidžāņu (Azerbaidžāna)',
            'be' => 'baltkrievu',
            'bg' => 'bulgāru',
            'bn_BD' => 'bengāļu (Bangladeša)',
            'ca' => 'katalāņu',
            'cs_CZ' => 'čehu (Čehija)',
            'da_DK' => 'dāņu (Dānija)',
            'de_DE' => 'vācu (Vācija)',
            'el_GR' => 'grieķu (Grieķija)',
            'en_AU' => 'angļu (Austrālija)',
            'en_CA' => 'angļu (Kanāda)',
            'en_GB' => 'angļu (Apvienotā Karaliste)',
            'en_IN' => 'angļu (Indija)',
            'en_SG' => 'angļu (Singapūra)',
            'en_US' => 'angļu (Amerikas Savienotās Valstis)',
            'en_ZA' => 'angļu (Dienvidāfrikas Republika)',
            'es_419' => 'spāņu (Latīņamerika)',
            'es_ES' => 'spāņu (Spānija)',
            'es_US' => 'spāņu (Amerikas Savienotās Valstis)',
            'et' => 'igauņu',
            'eu_ES' => 'basku (Spānija)',
            'fa' => 'persiešu',
            'fi_FI' => 'somu (Somija)',
            'fil' => 'filipīniešu',
            'fr_CA' => 'franču (Kanāda)',
            'fr_FR' => 'franču (Francija)',
            'gl_ES' => 'galisiešu (Spānija)',
            'hi_IN' => 'hindi (Indija)',
            'hr' => 'horvātu',
            'hu_HU' => 'ungāru (Ungārija)',
            'hy' => 'armēņu (Armēnija)',
            'id' => 'indonēziešu',
            'is_IS' => 'islandiešu (Islande)',
            'it_IT' => 'itāļu (Itālija)',
            'iw_IL' => 'ivrits (Izraēla)',
            'ja_JP' => 'japāņu (Japāna)',
            'ka_GE' => 'gruzīnu (Gruzija)',
            'kk' => 'kazahu',
            'km_KH' => 'khmeru (Kambodža)',
            'kn_IN' => 'kannadu (Indija)',
            'ko' => 'korejiešu (Dienvidkoreja)',
            'ky_KG' => 'kirgīzu (Kirgizstāna)',
            'lo_LA' => 'laosiešu (Laosa)',
            'lt' => 'lietuviešu',
            'mk_MK' => 'maķedoniešu (Ziemeļmaķedonija)',
            'ml_IN' => 'malajalu (Indija)',
            'mn_MN' => 'mongoļu (Mongolija)',
            'mr_IN' => 'marathu (Indija)',
            'ms' => 'malajiešu',
            'my_MM' => 'birmiešu (Mjanma [Birma])',
            'ne_NP' => 'nepāliešu (Nepāla)',
            'nl_NL' => 'holandiešu (Nīderlande)',
            'no_NO' => 'norvēģu (Norvēģija)',
            'pl_PL' => 'poļu (Polija)',
            'pt_BR' => 'portugāļu (Brazīlija)',
            'pt_PT' => 'portugāļu (Portugāle)',
            'ro' => 'rumāņu',
            'ru_RU' => 'krievu (Krievija)',
            'si_LK' => 'singāļu (Šrilanka)',
            'sk' => 'slovāku',
            'sl' => 'slovēņu',
            'sr' => 'serbu',
            'sv_SE' => 'zviedru (Zviedrija)',
            'sw' => 'svahili',
            'ta_IN' => 'tamilu (Indija)',
            'te_IN' => 'telugu (Indija)',
            'th' => 'taju',
            'tr_TR' => 'turku (Turcija)',
            'uk' => 'ukraiņu',
            'vi' => 'vjetnamiešu',
            'zh_CN' => 'ķīniešu (vienkāršotā)',
            'zh_HK' => 'ķīniešu (Honkonga)',
            'zh_TW' => 'ķīniešu (tradicionālā)',
            'zu' => 'zulu',
        ],
        'mk_MK' => [
            'af' => 'африканс',
            'am' => 'амхарски',
            'ar' => 'арапски',
            'az_AZ' => 'азербејџански (Азербејџан)',
            'be' => 'белоруски',
            'bg' => 'бугарски',
            'bn_BD' => 'бенгалски (Бангладеш)',
            'ca' => 'каталонски',
            'cs_CZ' => 'чешки (Чешка)',
            'da_DK' => 'дански (Данска)',
            'de_DE' => 'германски (Германија)',
            'el_GR' => 'грчки (Грција)',
            'en_AU' => 'англиски (Австралија)',
            'en_CA' => 'англиски (Канада)',
            'en_GB' => 'англиски (Обединето Кралство)',
            'en_IN' => 'англиски (Индија)',
            'en_SG' => 'англиски (Сингапур)',
            'en_US' => 'англиски (Соединети Американски Држави)',
            'en_ZA' => 'англиски (Јужноафриканска Република)',
            'es_419' => 'шпански (Латинска Америка)',
            'es_ES' => 'шпански (Шпанија)',
            'es_US' => 'шпански (Соединети Американски Држави)',
            'et' => 'естонски',
            'eu_ES' => 'баскиски (Шпанија)',
            'fa' => 'персиски',
            'fi_FI' => 'фински (Финска)',
            'fil' => 'филипински',
            'fr_CA' => 'француски (Канада)',
            'fr_FR' => 'француски (Франција)',
            'gl_ES' => 'галициски (Шпанија)',
            'hi_IN' => 'хинди (Индија)',
            'hr' => 'хрватски',
            'hu_HU' => 'унгарски (Унгарија)',
            'hy' => 'ерменски (Ерменија)',
            'id' => 'индонезиски',
            'is_IS' => 'исландски (Исланд)',
            'it_IT' => 'италијански (Италија)',
            'iw_IL' => 'хебрејски (Израел)',
            'ja_JP' => 'јапонски (Јапонија)',
            'ka_GE' => 'грузиски (Грузија)',
            'kk' => 'казашки',
            'km_KH' => 'кмерски (Камбоџа)',
            'kn_IN' => 'каннада (Индија)',
            'ko' => 'корејски (Јужна Кореја)',
            'ky_KG' => 'киргиски (Киргистан)',
            'lo_LA' => 'лаошки (Лаос)',
            'lt' => 'литвански',
            'lv' => 'латвиски',
            'ml_IN' => 'малајамски (Индија)',
            'mn_MN' => 'монголски (Монголија)',
            'mr_IN' => 'марати (Индија)',
            'ms' => 'малајски',
            'my_MM' => 'бурмански (Мјанмар [Бурма])',
            'ne_NP' => 'непалски (Непал)',
            'nl_NL' => 'холандски (Холандија)',
            'no_NO' => 'норвешки (Норвешка)',
            'pl_PL' => 'полски (Полска)',
            'pt_BR' => 'португалски (Бразил)',
            'pt_PT' => 'португалски (Португалија)',
            'ro' => 'романски',
            'ru_RU' => 'руски (Русија)',
            'si_LK' => 'синхалски (Шри Ланка)',
            'sk' => 'словачки',
            'sl' => 'словенечки',
            'sr' => 'српски',
            'sv_SE' => 'шведски (Шведска)',
            'sw' => 'свахили',
            'ta_IN' => 'тамилски (Индија)',
            'te_IN' => 'телугу (Индија)',
            'th' => 'тајландски',
            'tr_TR' => 'турски (Турција)',
            'uk' => 'украински',
            'vi' => 'виетнамски',
            'zh_CN' => 'кинески (поедноставено)',
            'zh_HK' => 'кинески (Хонг Конг)',
            'zh_TW' => 'кинески (традиционално)',
            'zu' => 'зулу',
        ],
        'ml_IN' => [
            'af' => 'ആഫ്രിക്കാൻസ്',
            'am' => 'അംഹാരിക്',
            'ar' => 'അറബിക്',
            'az_AZ' => 'അസർബൈജാനി (അസർബൈജാൻ)',
            'be' => 'ബെലാറുഷ്യൻ',
            'bg' => 'ബൾഗേറിയൻ',
            'bn_BD' => 'ബംഗാളി (ബംഗ്ലാദേശ്)',
            'ca' => 'കറ്റാലാൻ',
            'cs_CZ' => 'ചെക്ക് (ചെക്കിയ)',
            'da_DK' => 'ഡാനിഷ് (ഡെൻമാർക്ക്)',
            'de_DE' => 'ജർമ്മൻ (ജർമ്മനി)',
            'el_GR' => 'ഗ്രീക്ക് (ഗ്രീസ്)',
            'en_AU' => 'ഇംഗ്ലീഷ് (ഓസ്‌ട്രേലിയ)',
            'en_CA' => 'ഇംഗ്ലീഷ് (കാനഡ)',
            'en_GB' => 'ഇംഗ്ലീഷ് (യുണൈറ്റഡ് കിംഗ്ഡം)',
            'en_IN' => 'ഇംഗ്ലീഷ് (ഇന്ത്യ)',
            'en_SG' => 'ഇംഗ്ലീഷ് (സിംഗപ്പൂർ)',
            'en_US' => 'ഇംഗ്ലീഷ് (അമേരിക്കൻ ഐക്യനാടുകൾ)',
            'en_ZA' => 'ഇംഗ്ലീഷ് (ദക്ഷിണാഫ്രിക്ക)',
            'es_419' => 'സ്‌പാനിഷ് (ലാറ്റിനമേരിക്ക)',
            'es_ES' => 'സ്‌പാനിഷ് (സ്‌പെയിൻ)',
            'es_US' => 'സ്‌പാനിഷ് (അമേരിക്കൻ ഐക്യനാടുകൾ)',
            'et' => 'എസ്റ്റോണിയൻ',
            'eu_ES' => 'ബാസ്‌ക് (സ്‌പെയിൻ)',
            'fa' => 'പേർഷ്യൻ',
            'fi_FI' => 'ഫിന്നിഷ് (ഫിൻലാൻഡ്)',
            'fil' => 'ഫിലിപ്പിനോ',
            'fr_CA' => 'ഫ്രഞ്ച് (കാനഡ)',
            'fr_FR' => 'ഫ്രഞ്ച് (ഫ്രാൻസ്)',
            'gl_ES' => 'ഗലീഷ്യൻ (സ്‌പെയിൻ)',
            'hi_IN' => 'ഹിന്ദി (ഇന്ത്യ)',
            'hr' => 'ക്രൊയേഷ്യൻ',
            'hu_HU' => 'ഹംഗേറിയൻ (ഹംഗറി)',
            'hy' => 'അർമേനിയൻ (അർമേനിയ)',
            'id' => 'ഇന്തോനേഷ്യൻ',
            'is_IS' => 'ഐസ്‌ലാൻഡിക് (ഐസ്‌ലാന്റ്)',
            'it_IT' => 'ഇറ്റാലിയൻ (ഇറ്റലി)',
            'iw_IL' => 'ഹീബ്രു (ഇസ്രായേൽ)',
            'ja_JP' => 'ജാപ്പനീസ് (ജപ്പാൻ)',
            'ka_GE' => 'ജോർജിയൻ (ജോർജ്ജിയ)',
            'kk' => 'കസാഖ്',
            'km_KH' => 'ഖമെർ (കംബോഡിയ)',
            'kn_IN' => 'കന്നഡ (ഇന്ത്യ)',
            'ko' => 'കൊറിയൻ (ദക്ഷിണകൊറിയ)',
            'ky_KG' => 'കിർഗിസ് (കിർഗിസ്ഥാൻ)',
            'lo_LA' => 'ലാവോ (ലാവോസ്)',
            'lt' => 'ലിത്വാനിയൻ',
            'lv' => 'ലാറ്റ്വിയൻ',
            'mk_MK' => 'മാസിഡോണിയൻ (നോർത്ത് മാസിഡോണിയ)',
            'mn_MN' => 'മംഗോളിയൻ (മംഗോളിയ)',
            'mr_IN' => 'മറാത്തി (ഇന്ത്യ)',
            'ms' => 'മലെയ്',
            'my_MM' => 'ബർമീസ് (മ്യാൻമാർ [ബർമ്മ])',
            'ne_NP' => 'നേപ്പാളി (നേപ്പാൾ)',
            'nl_NL' => 'ഡച്ച് (നെതർലാൻഡ്‌സ്)',
            'no_NO' => 'നോർവീജിയൻ (നോർവെ)',
            'pl_PL' => 'പോളിഷ് (പോളണ്ട്)',
            'pt_BR' => 'പോർച്ചുഗീസ് (ബ്രസീൽ)',
            'pt_PT' => 'പോർച്ചുഗീസ് (പോർച്ചുഗൽ)',
            'ro' => 'റൊമാനിയൻ',
            'ru_RU' => 'റഷ്യൻ (റഷ്യ)',
            'si_LK' => 'സിംഹള (ശ്രീലങ്ക)',
            'sk' => 'സ്ലോവാക്',
            'sl' => 'സ്ലോവേനിയൻ',
            'sr' => 'സെർബിയൻ',
            'sv_SE' => 'സ്വീഡിഷ് (സ്വീഡൻ)',
            'sw' => 'സ്വാഹിലി',
            'ta_IN' => 'തമിഴ് (ഇന്ത്യ)',
            'te_IN' => 'തെലുങ്ക് (ഇന്ത്യ)',
            'th' => 'തായ്',
            'tr_TR' => 'ടർക്കിഷ് (തുർക്കി)',
            'uk' => 'ഉക്രേനിയൻ',
            'vi' => 'വിയറ്റ്നാമീസ്',
            'zh_CN' => 'ചൈനീസ് (ലളിതവൽക്കരിച്ചത്)',
            'zh_HK' => 'ചൈനീസ് (ഹോങ്കോങ്)',
            'zh_TW' => 'ചൈനീസ് (പരമ്പരാഗതം)',
            'zu' => 'സുലു',
        ],
        'mn_MN' => [
            'af' => 'африкаанс',
            'am' => 'амхар',
            'ar' => 'араб',
            'az_AZ' => 'азербайжан (Азербайжан)',
            'be' => 'беларусь',
            'bg' => 'болгар',
            'bn_BD' => 'бенгал (Бангладеш)',
            'ca' => 'каталан',
            'cs_CZ' => 'чех (Чех)',
            'da_DK' => 'дани (Дани)',
            'de_DE' => 'герман (Герман)',
            'el_GR' => 'грек (Грек)',
            'en_AU' => 'англи (Австрали)',
            'en_CA' => 'англи (Канад)',
            'en_GB' => 'англи (Их Британи)',
            'en_IN' => 'англи (Энэтхэг)',
            'en_SG' => 'англи (Сингапур)',
            'en_US' => 'англи (Америкийн Нэгдсэн Улс)',
            'en_ZA' => 'англи (Өмнөд Африк)',
            'es_419' => 'испани (Латин Америк)',
            'es_ES' => 'испани (Испани)',
            'es_US' => 'испани (Америкийн Нэгдсэн Улс)',
            'et' => 'эстони',
            'eu_ES' => 'баск (Испани)',
            'fa' => 'перс',
            'fi_FI' => 'фин (Финлянд)',
            'fil' => 'филипино',
            'fr_CA' => 'франц (Канад)',
            'fr_FR' => 'франц (Франц)',
            'gl_ES' => 'галего (Испани)',
            'hi_IN' => 'хинди (Энэтхэг)',
            'hr' => 'хорват',
            'hu_HU' => 'мажар (Унгар)',
            'hy' => 'армен (Армени)',
            'id' => 'индонези',
            'is_IS' => 'исланд (Исланд)',
            'it_IT' => 'итали (Итали)',
            'iw_IL' => 'еврей (Израиль)',
            'ja_JP' => 'япон (Япон)',
            'ka_GE' => 'гүрж (Гүрж)',
            'kk' => 'казах',
            'km_KH' => 'кхмер (Камбож)',
            'kn_IN' => 'каннада (Энэтхэг)',
            'ko' => 'солонгос (Өмнөд Солонгос)',
            'ky_KG' => 'киргиз (Кыргызстан)',
            'lo_LA' => 'лаос (Лаос)',
            'lt' => 'литва',
            'lv' => 'латви',
            'mk_MK' => 'македон (Хойд Македон)',
            'ml_IN' => 'малаялам (Энэтхэг)',
            'mr_IN' => 'марати (Энэтхэг)',
            'ms' => 'малай',
            'my_MM' => 'бирм (Мьянмар)',
            'ne_NP' => 'балба (Балба)',
            'nl_NL' => 'нидерланд (Нидерланд)',
            'no_NO' => 'норвеги (Норвеги)',
            'pl_PL' => 'польш (Польш)',
            'pt_BR' => 'португал (Бразил)',
            'pt_PT' => 'португал (Португал)',
            'ro' => 'румын',
            'ru_RU' => 'орос (Орос)',
            'si_LK' => 'синхала (Шри-Ланка)',
            'sk' => 'словак',
            'sl' => 'словени',
            'sr' => 'серб',
            'sv_SE' => 'швед (Швед)',
            'sw' => 'свахили',
            'ta_IN' => 'тамил (Энэтхэг)',
            'te_IN' => 'тэлүгү (Энэтхэг)',
            'th' => 'тай',
            'tr_TR' => 'турк (Турк)',
            'uk' => 'украин',
            'vi' => 'вьетнам',
            'zh_CN' => 'хятад (хялбаршуулсан)',
            'zh_HK' => 'хятад (Хонг Конг)',
            'zh_TW' => 'хятад (уламжлалт)',
            'zu' => 'зулу',
        ],
        'mr_IN' => [
            'af' => 'अफ्रिकान्स',
            'am' => 'अम्हारिक',
            'ar' => 'अरबी',
            'az_AZ' => 'अझरबैजानी (अझरबैजान)',
            'be' => 'बेलारुशियन',
            'bg' => 'बल्गेरियन',
            'bn_BD' => 'बंगाली (बांगलादेश)',
            'ca' => 'कातालान',
            'cs_CZ' => 'झेक (झेकिया)',
            'da_DK' => 'डॅनिश (डेन्मार्क)',
            'de_DE' => 'जर्मन (जर्मनी)',
            'el_GR' => 'ग्रीक (ग्रीस)',
            'en_AU' => 'इंग्रजी (ऑस्ट्रेलिया)',
            'en_CA' => 'इंग्रजी (कॅनडा)',
            'en_GB' => 'इंग्रजी (युनायटेड किंगडम)',
            'en_IN' => 'इंग्रजी (भारत)',
            'en_SG' => 'इंग्रजी (सिंगापूर)',
            'en_US' => 'इंग्रजी (युनायटेड स्टेट्स)',
            'en_ZA' => 'इंग्रजी (दक्षिण आफ्रिका)',
            'es_419' => 'स्पॅनिश (लॅटिन अमेरिका)',
            'es_ES' => 'स्पॅनिश (स्पेन)',
            'es_US' => 'स्पॅनिश (युनायटेड स्टेट्स)',
            'et' => 'इस्टोनियन',
            'eu_ES' => 'बास्क (स्पेन)',
            'fa' => 'फारसी',
            'fi_FI' => 'फिन्निश (फिनलंड)',
            'fil' => 'फिलिपिनो',
            'fr_CA' => 'फ्रेंच (कॅनडा)',
            'fr_FR' => 'फ्रेंच (फ्रान्स)',
            'gl_ES' => 'गॅलिशियन (स्पेन)',
            'hi_IN' => 'हिंदी (भारत)',
            'hr' => 'क्रोएशियन',
            'hu_HU' => 'हंगेरियन (हंगेरी)',
            'hy' => 'आर्मेनियन (अर्मेनिया)',
            'id' => 'इंडोनेशियन',
            'is_IS' => 'आईसलँडिक (आइसलँड)',
            'it_IT' => 'इटालियन (इटली)',
            'iw_IL' => 'हिब्रू (इस्त्राइल)',
            'ja_JP' => 'जपानी (जपान)',
            'ka_GE' => 'जॉर्जियन (जॉर्जिया)',
            'kk' => 'कझाक',
            'km_KH' => 'ख्मेर (कंबोडिया)',
            'kn_IN' => 'कन्नड (भारत)',
            'ko' => 'कोरियन (दक्षिण कोरिया)',
            'ky_KG' => 'किरगीझ (किरगिझस्तान)',
            'lo_LA' => 'लाओ (लाओस)',
            'lt' => 'लिथुआनियन',
            'lv' => 'लात्व्हियन',
            'mk_MK' => 'मॅसेडोनियन (उत्तर मॅसेडोनिया)',
            'ml_IN' => 'मल्याळम (भारत)',
            'mn_MN' => 'मंगोलियन (मंगोलिया)',
            'ms' => 'मलय',
            'my_MM' => 'बर्मी (म्यानमार [बर्मा])',
            'ne_NP' => 'नेपाळी (नेपाळ)',
            'nl_NL' => 'डच (नेदरलँड)',
            'no_NO' => 'नोर्वेजियन (नॉर्वे)',
            'pl_PL' => 'पोलिश (पोलंड)',
            'pt_BR' => 'पोर्तुगीज (ब्राझिल)',
            'pt_PT' => 'पोर्तुगीज (पोर्तुगाल)',
            'ro' => 'रोमानियन',
            'ru_RU' => 'रशियन (रशिया)',
            'si_LK' => 'सिंहला (श्रीलंका)',
            'sk' => 'स्लोव्हाक',
            'sl' => 'स्लोव्हेनियन',
            'sr' => 'सर्बियन',
            'sv_SE' => 'स्वीडिश (स्वीडन)',
            'sw' => 'स्वाहिली',
            'ta_IN' => 'तामिळ (भारत)',
            'te_IN' => 'तेलगू (भारत)',
            'th' => 'थाई',
            'tr_TR' => 'तुर्की (तुर्की)',
            'uk' => 'युक्रेनियन',
            'vi' => 'व्हिएतनामी',
            'zh_CN' => 'चीनी (सरलीकृत)',
            'zh_HK' => 'चीनी (हाँगकाँग)',
            'zh_TW' => 'चीनी (पारंपारिक)',
            'zu' => 'झुलू',
        ],
        'ms' => [
            'af' => 'Afrikaans',
            'am' => 'Amharic',
            'ar' => 'Arab',
            'az_AZ' => 'Azerbaijan (Azerbaijan)',
            'be' => 'Belarus',
            'bg' => 'Bulgaria',
            'bn_BD' => 'Benggala (Bangladesh)',
            'ca' => 'Catalonia',
            'cs_CZ' => 'Czech (Czechia)',
            'da_DK' => 'Denmark (Denmark)',
            'de_DE' => 'Jerman (Jerman)',
            'el_GR' => 'Greek (Greece)',
            'en_AU' => 'Inggeris (Australia)',
            'en_CA' => 'Inggeris (Kanada)',
            'en_GB' => 'Inggeris (United Kingdom)',
            'en_IN' => 'Inggeris (India)',
            'en_SG' => 'Inggeris (Singapura)',
            'en_US' => 'Inggeris (Amerika Syarikat)',
            'en_ZA' => 'Inggeris (Afrika Selatan)',
            'es_419' => 'Sepanyol (Amerika Latin)',
            'es_ES' => 'Sepanyol (Sepanyol)',
            'es_US' => 'Sepanyol (Amerika Syarikat)',
            'et' => 'Estonia',
            'eu_ES' => 'Basque (Sepanyol)',
            'fa' => 'Parsi',
            'fi_FI' => 'Finland (Finland)',
            'fil' => 'Filipina',
            'fr_CA' => 'Perancis (Kanada)',
            'fr_FR' => 'Perancis (Perancis)',
            'gl_ES' => 'Galicia (Sepanyol)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Croatia',
            'hu_HU' => 'Hungary (Hungary)',
            'hy' => 'Armenia (Armenia)',
            'id' => 'Indonesia',
            'is_IS' => 'Iceland (Iceland)',
            'it_IT' => 'Itali (Itali)',
            'iw_IL' => 'Ibrani (Israel)',
            'ja_JP' => 'Jepun (Jepun)',
            'ka_GE' => 'Georgia (Georgia)',
            'kk' => 'Kazakhstan',
            'km_KH' => 'Khmer (Kemboja)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Korea (Korea Selatan)',
            'ky_KG' => 'Kirghiz (Kyrgyzstan)',
            'lo_LA' => 'Laos (Laos)',
            'lt' => 'Lithuania',
            'lv' => 'Latvia',
            'mk_MK' => 'Macedonia (Macedonia Utara)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongolia (Mongolia)',
            'mr_IN' => 'Marathi (India)',
            'my_MM' => 'Burma (Myanmar [Burma])',
            'ne_NP' => 'Nepal (Nepal)',
            'nl_NL' => 'Belanda (Belanda)',
            'no_NO' => 'Norway (Norway)',
            'pl_PL' => 'Poland (Poland)',
            'pt_BR' => 'Portugis (Brazil)',
            'pt_PT' => 'Portugis (Portugal)',
            'ro' => 'Romania',
            'ru_RU' => 'Rusia (Rusia)',
            'si_LK' => 'Sinhala (Sri Lanka)',
            'sk' => 'Slovak',
            'sl' => 'Slovenia',
            'sr' => 'Serbia',
            'sv_SE' => 'Sweden (Sweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turki (Turki)',
            'uk' => 'Ukraine',
            'vi' => 'Vietnam',
            'zh_CN' => 'Cina (Ringkas)',
            'zh_HK' => 'Cina (Hong Kong)',
            'zh_TW' => 'Cina (Tradisional)',
            'zu' => 'Zulu',
        ],
        'my_MM' => [
            'af' => 'တောင်အာဖရိက',
            'am' => 'အမ်ဟာရစ်ခ်',
            'ar' => 'အာရဗီ',
            'az_AZ' => 'အဇာဘိုင်ဂျန် (အဇာဘိုင်ဂျန်)',
            'be' => 'ဘီလာရုစ်',
            'bg' => 'ဘူလ်ဂေးရီးယား',
            'bn_BD' => 'ဘင်္ဂါလီ (ဘင်္ဂလားဒေ့ရှ်)',
            'ca' => 'ကတ်တလန်',
            'cs_CZ' => 'ချက် (ချက်ကီယား)',
            'da_DK' => 'ဒိန်းမတ် (ဒိန်းမတ်)',
            'de_DE' => 'ဂျာမန် (ဂျာမနီ)',
            'el_GR' => 'ဂရိ (ဂရိ)',
            'en_AU' => 'အင်္ဂလိပ် (ဩစတြေးလျ)',
            'en_CA' => 'အင်္ဂလိပ် (ကနေဒါ)',
            'en_GB' => 'အင်္ဂလိပ် (ယူနိုက်တက်ကင်းဒမ်း)',
            'en_IN' => 'အင်္ဂလိပ် (အိန္ဒိယ)',
            'en_SG' => 'အင်္ဂလိပ် (စင်္ကာပူ)',
            'en_US' => 'အင်္ဂလိပ် (အမေရိကန် ပြည်ထောင်စု)',
            'en_ZA' => 'အင်္ဂလိပ် (တောင်အာဖရိက)',
            'es_419' => 'စပိန် (လက်တင်အမေရိက)',
            'es_ES' => 'စပိန် (စပိန်)',
            'es_US' => 'စပိန် (အမေရိကန် ပြည်ထောင်စု)',
            'et' => 'အက်စ်တိုးနီးယား',
            'eu_ES' => 'ဘာစ်ခ် (စပိန်)',
            'fa' => 'ပါရှန်',
            'fi_FI' => 'ဖင်လန် (ဖင်လန်)',
            'fil' => 'ဖိလစ်ပိုင်',
            'fr_CA' => 'ပြင်သစ် (ကနေဒါ)',
            'fr_FR' => 'ပြင်သစ် (ပြင်သစ်)',
            'gl_ES' => 'ဂါလီစီယာ (စပိန်)',
            'hi_IN' => 'ဟိန်ဒူ (အိန္ဒိယ)',
            'hr' => 'ခရိုအေးရှား',
            'hu_HU' => 'ဟန်ဂေရီ (ဟန်ဂေရီ)',
            'hy' => 'အာမေးနီးယား (အာမေးနီးယား)',
            'id' => 'အင်ဒိုနီးရှား',
            'is_IS' => 'အိုက်စ်လန် (အိုက်စလန်)',
            'it_IT' => 'အီတလီ (အီတလီ)',
            'iw_IL' => 'ဟီးဘရူး (အစ္စရေး)',
            'ja_JP' => 'ဂျပန် (ဂျပန်)',
            'ka_GE' => 'ဂျော်ဂျီယာ (ဂျော်ဂျီယာ)',
            'kk' => 'ကာဇာချ',
            'km_KH' => 'ခမာ (ကမ္ဘောဒီးယား)',
            'kn_IN' => 'ကန်နာဒါ (အိန္ဒိယ)',
            'ko' => 'ကိုရီးယား (တောင်ကိုရီးယား)',
            'ky_KG' => 'ကာဂျစ် (ကာဂျစ္စတန်)',
            'lo_LA' => 'လာအို (လာအို)',
            'lt' => 'လစ်သူဝေးနီးယား',
            'lv' => 'လတ်ဗီးယား',
            'mk_MK' => 'မက်ဆီဒိုးနီးယား (မြောက် မက်ဆီဒိုးနီးယား)',
            'ml_IN' => 'မလေယာလမ် (အိန္ဒိယ)',
            'mn_MN' => 'မွန်ဂိုလီးယား (မွန်ဂိုးလီးယား)',
            'mr_IN' => 'မာရသီ (အိန္ဒိယ)',
            'ms' => 'မလေး',
            'ne_NP' => 'နီပေါ (နီပေါ)',
            'nl_NL' => 'ဒတ်ခ်ျ (နယ်သာလန်)',
            'no_NO' => 'နော်ဝေး (နော်ဝေ)',
            'pl_PL' => 'ပိုလန် (ပိုလန်)',
            'pt_BR' => 'ပေါ်တူဂီ (ဘရာဇီး)',
            'pt_PT' => 'ပေါ်တူဂီ (ပေါ်တူဂီ)',
            'ro' => 'ရိုမေနီယား',
            'ru_RU' => 'ရုရှ (ရုရှား)',
            'si_LK' => 'စင်ဟာလာ (သီရိလင်္ကာ)',
            'sk' => 'ဆလိုဗက်',
            'sl' => 'ဆလိုဗေးနီးယား',
            'sr' => 'ဆားဘီးယား',
            'sv_SE' => 'ဆွီဒင် (ဆွီဒင်)',
            'sw' => 'ဆွာဟီလီ',
            'ta_IN' => 'တမီးလ် (အိန္ဒိယ)',
            'te_IN' => 'တီလီဂူ (အိန္ဒိယ)',
            'th' => 'ထိုင်း',
            'tr_TR' => 'တူရကီ (တူရကီ)',
            'uk' => 'ယူကရိန်း',
            'vi' => 'ဗီယက်နမ်',
            'zh_CN' => 'တရုတ် (ရိုးရှင်း)',
            'zh_HK' => 'တရုတ် (ဟောင်ကောင်)',
            'zh_TW' => 'တရုတ် (ရိုးရာ)',
            'zu' => 'ဇူးလူး',
        ],
        'ne_NP' => [
            'af' => 'अफ्रिकान्स',
            'am' => 'अम्हारिक',
            'ar' => 'अरबी',
            'az_AZ' => 'अजरबैजानी (अजरबैजान)',
            'be' => 'बेलारुसी',
            'bg' => 'बुल्गेरियाली',
            'bn_BD' => 'बंगाली (बङ्गलादेश)',
            'ca' => 'क्याटालन',
            'cs_CZ' => 'चेक (चेकिया)',
            'da_DK' => 'डेनिस (डेनमार्क)',
            'de_DE' => 'जर्मन (जर्मनी)',
            'el_GR' => 'ग्रीक (ग्रीस)',
            'en_AU' => 'अङ्ग्रेजी (अष्ट्रेलिया)',
            'en_CA' => 'अङ्ग्रेजी (क्यानाडा)',
            'en_GB' => 'अङ्ग्रेजी (संयुक्त अधिराज्य)',
            'en_IN' => 'अङ्ग्रेजी (भारत)',
            'en_SG' => 'अङ्ग्रेजी (सिङ्गापुर)',
            'en_US' => 'अङ्ग्रेजी (संयुक्त राज्य)',
            'en_ZA' => 'अङ्ग्रेजी (दक्षिण अफ्रिका)',
            'es_419' => 'स्पेनी (ल्याटिन अमेरिका)',
            'es_ES' => 'स्पेनी (स्पेन)',
            'es_US' => 'स्पेनी (संयुक्त राज्य)',
            'et' => 'इस्टोनियन',
            'eu_ES' => 'बास्क (स्पेन)',
            'fa' => 'फारसी',
            'fi_FI' => 'फिनिस (फिनल्याण्ड)',
            'fil' => 'फिलिपिनी',
            'fr_CA' => 'फ्रान्सेली (क्यानाडा)',
            'fr_FR' => 'फ्रान्सेली (फ्रान्स)',
            'gl_ES' => 'गलिसियाली (स्पेन)',
            'hi_IN' => 'हिन्दी (भारत)',
            'hr' => 'क्रोयसियाली',
            'hu_HU' => 'हङ्गेरियाली (हङ्गेरी)',
            'hy' => 'आर्मेनियाली (आर्मेनिया)',
            'id' => 'इन्डोनेसियाली',
            'is_IS' => 'आइसल्यान्डियाली (आइस्ल्याण्ड)',
            'it_IT' => 'इटालेली (इटली)',
            'iw_IL' => 'हिब्रु (इजरायल)',
            'ja_JP' => 'जापानी (जापान)',
            'ka_GE' => 'जर्जियाली (जर्जिया)',
            'kk' => 'काजाख',
            'km_KH' => 'खमेर (कम्बोडिया)',
            'kn_IN' => 'कन्नाडा (भारत)',
            'ko' => 'कोरियाली (दक्षिण कोरिया)',
            'ky_KG' => 'किर्गिज (किर्गिस्तान)',
            'lo_LA' => 'लाओ (लाओस)',
            'lt' => 'लिथुआनियाली',
            'lv' => 'लात्भियाली',
            'mk_MK' => 'म्यासेडोनियन (उत्तर म्यासेडोनिया)',
            'ml_IN' => 'मलयालम (भारत)',
            'mn_MN' => 'मङ्गोलियाली (मङ्गोलिया)',
            'mr_IN' => 'मराठी (भारत)',
            'ms' => 'मलाय',
            'my_MM' => 'बर्मेली (म्यान्मार [बर्मा])',
            'nl_NL' => 'डच (नेदरल्याण्ड)',
            'no_NO' => 'नर्वेली (नर्वे)',
            'pl_PL' => 'पोलिस (पोल्याण्ड)',
            'pt_BR' => 'पोर्तुगी (ब्राजिल)',
            'pt_PT' => 'पोर्तुगी (पोर्चुगल)',
            'ro' => 'रोमानियाली',
            'ru_RU' => 'रसियाली (रूस)',
            'si_LK' => 'सिन्हाली (श्रीलङ्का)',
            'sk' => 'स्लोभाकियाली',
            'sl' => 'स्लोभेनियाली',
            'sr' => 'सर्बियाली',
            'sv_SE' => 'स्विडिस (स्विडेन)',
            'sw' => 'स्वाहिली',
            'ta_IN' => 'तामिल (भारत)',
            'te_IN' => 'तेलुगु (भारत)',
            'th' => 'थाई',
            'tr_TR' => 'टर्किश (टर्की)',
            'uk' => 'युक्रेनी',
            'vi' => 'भियतनामी',
            'zh_CN' => 'चिनियाँ (सरलिकृत चिनियाँ)',
            'zh_HK' => 'चिनियाँ (हङकङ)',
            'zh_TW' => 'चिनियाँ (परम्परागत चिनियाँ)',
            'zu' => 'जुलु',
        ],
        'nl_NL' => [
            'af' => 'Afrikaans',
            'am' => 'Amhaars',
            'ar' => 'Arabisch',
            'az_AZ' => 'Azerbeidzjaans (Azerbeidzjan)',
            'be' => 'Wit-Russisch',
            'bg' => 'Bulgaars',
            'bn_BD' => 'Bengaals (Bangladesh)',
            'ca' => 'Catalaans',
            'cs_CZ' => 'Tsjechisch (Tsjechië)',
            'da_DK' => 'Deens (Denemarken)',
            'de_DE' => 'Duits (Duitsland)',
            'el_GR' => 'Grieks (Griekenland)',
            'en_AU' => 'Engels (Australië)',
            'en_CA' => 'Engels (Canada)',
            'en_GB' => 'Engels (Verenigd Koninkrijk)',
            'en_IN' => 'Engels (India)',
            'en_SG' => 'Engels (Singapore)',
            'en_US' => 'Engels (Verenigde Staten)',
            'en_ZA' => 'Engels (Zuid-Afrika)',
            'es_419' => 'Spaans (Latijns-Amerika)',
            'es_ES' => 'Spaans (Spanje)',
            'es_US' => 'Spaans (Verenigde Staten)',
            'et' => 'Estisch',
            'eu_ES' => 'Baskisch (Spanje)',
            'fa' => 'Perzisch',
            'fi_FI' => 'Fins (Finland)',
            'fil' => 'Filipijns',
            'fr_CA' => 'Frans (Canada)',
            'fr_FR' => 'Frans (Frankrijk)',
            'gl_ES' => 'Galicisch (Spanje)',
            'hi_IN' => 'Hindi (India)',
            'hr' => 'Kroatisch',
            'hu_HU' => 'Hongaars (Hongarije)',
            'hy' => 'Armeens (Armenië)',
            'id' => 'Indonesisch',
            'is_IS' => 'IJslands (IJsland)',
            'it_IT' => 'Italiaans (Italië)',
            'iw_IL' => 'Hebreeuws (Israël)',
            'ja_JP' => 'Japans (Japan)',
            'ka_GE' => 'Georgisch (Georgië)',
            'kk' => 'Kazachs',
            'km_KH' => 'Khmer (Cambodja)',
            'kn_IN' => 'Kannada (India)',
            'ko' => 'Koreaans (Zuid-Korea)',
            'ky_KG' => 'Kirgizisch (Kirgizië)',
            'lo_LA' => 'Laotiaans (Laos)',
            'lt' => 'Litouws',
            'lv' => 'Lets',
            'mk_MK' => 'Macedonisch (Noord-Macedonië)',
            'ml_IN' => 'Malayalam (India)',
            'mn_MN' => 'Mongools (Mongolië)',
            'mr_IN' => 'Marathi (India)',
            'ms' => 'Maleis',
            'my_MM' => 'Birmaans (Myanmar [Birma])',
            'ne_NP' => 'Nepalees (Nepal)',
            'no_NO' => 'Noors (Noorwegen)',
            'pl_PL' => 'Pools (Polen)',
            'pt_BR' => 'Portugees (Brazilië)',
            'pt_PT' => 'Portugees (Portugal)',
            'ro' => 'Roemeens',
            'ru_RU' => 'Russisch (Rusland)',
            'si_LK' => 'Singalees (Sri Lanka)',
            'sk' => 'Slowaaks',
            'sl' => 'Sloveens',
            'sr' => 'Servisch',
            'sv_SE' => 'Zweeds (Zweden)',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (India)',
            'te_IN' => 'Telugu (India)',
            'th' => 'Thai',
            'tr_TR' => 'Turks (Turkije)',
            'uk' => 'Oekraïens',
            'vi' => 'Vietnamees',
            'zh_CN' => 'Chinees (vereenvoudigd)',
            'zh_HK' => 'Chinees (Hongkong)',
            'zh_TW' => 'Chinees (traditioneel)',
            'zu' => 'Zoeloe',
        ],
        'no_NO' => [
            'af' => 'afrikaans',
            'am' => 'amharisk',
            'ar' => 'arabisk',
            'az_AZ' => 'aserbajdsjansk (Aserbajdsjan)',
            'be' => 'hviterussisk',
            'bg' => 'bulgarsk',
            'bn_BD' => 'bengali (Bangladesh)',
            'ca' => 'katalansk',
            'cs_CZ' => 'tsjekkisk (Tsjekkia)',
            'da_DK' => 'dansk (Danmark)',
            'de_DE' => 'tysk (Tyskland)',
            'el_GR' => 'gresk (Hellas)',
            'en_AU' => 'engelsk (Australia)',
            'en_CA' => 'engelsk (Canada)',
            'en_GB' => 'engelsk (Storbritannia)',
            'en_IN' => 'engelsk (India)',
            'en_SG' => 'engelsk (Singapore)',
            'en_US' => 'engelsk (USA)',
            'en_ZA' => 'engelsk (Sør-Afrika)',
            'es_419' => 'spansk (Latin-Amerika)',
            'es_ES' => 'spansk (Spania)',
            'es_US' => 'spansk (USA)',
            'et' => 'estisk',
            'eu_ES' => 'baskisk (Spania)',
            'fa' => 'persisk',
            'fi_FI' => 'finsk (Finland)',
            'fil' => 'filipino',
            'fr_CA' => 'fransk (Canada)',
            'fr_FR' => 'fransk (Frankrike)',
            'gl_ES' => 'galisisk (Spania)',
            'hi_IN' => 'hindi (India)',
            'hr' => 'kroatisk',
            'hu_HU' => 'ungarsk (Ungarn)',
            'hy' => 'armensk (Armenia)',
            'id' => 'indonesisk',
            'is_IS' => 'islandsk (Island)',
            'it_IT' => 'italiensk (Italia)',
            'iw_IL' => 'hebraisk (Israel)',
            'ja_JP' => 'japansk (Japan)',
            'ka_GE' => 'georgisk (Georgia)',
            'kk' => 'kasakhisk',
            'km_KH' => 'khmer (Kambodsja)',
            'kn_IN' => 'kannada (India)',
            'ko' => 'koreansk (Sør-Korea)',
            'ky_KG' => 'kirgisisk (Kirgisistan)',
            'lo_LA' => 'laotisk (Laos)',
            'lt' => 'litauisk',
            'lv' => 'latvisk',
            'mk_MK' => 'makedonsk (Nord-Makedonia)',
            'ml_IN' => 'malayalam (India)',
            'mn_MN' => 'mongolsk (Mongolia)',
            'mr_IN' => 'marathi (India)',
            'ms' => 'malayisk',
            'my_MM' => 'burmesisk (Myanmar [Burma])',
            'ne_NP' => 'nepali (Nepal)',
            'nl_NL' => 'nederlandsk (Nederland)',
            'pl_PL' => 'polsk (Polen)',
            'pt_BR' => 'portugisisk (Brasil)',
            'pt_PT' => 'portugisisk (Portugal)',
            'ro' => 'rumensk',
            'ru_RU' => 'russisk (Russland)',
            'si_LK' => 'singalesisk (Sri Lanka)',
            'sk' => 'slovakisk',
            'sl' => 'slovensk',
            'sr' => 'serbisk',
            'sv_SE' => 'svensk (Sverige)',
            'sw' => 'swahili',
            'ta_IN' => 'tamil (India)',
            'te_IN' => 'telugu (India)',
            'th' => 'thai',
            'tr_TR' => 'tyrkisk (Tyrkia)',
            'uk' => 'ukrainsk',
            'vi' => 'vietnamesisk',
            'zh_CN' => 'kinesisk (forenklet)',
            'zh_HK' => 'kinesisk (Hongkong)',
            'zh_TW' => 'kinesisk (tradisjonell)',
            'zu' => 'zulu',
        ],
        'pl_PL' => [
            'af' => 'afrikaans',
            'am' => 'amharski',
            'ar' => 'arabski',
            'az_AZ' => 'azerbejdżański (Azerbejdżan)',
            'be' => 'białoruski',
            'bg' => 'bułgarski',
            'bn_BD' => 'bengalski (Bangladesz)',
            'ca' => 'kataloński',
            'cs_CZ' => 'czeski (Czechy)',
            'da_DK' => 'duński (Dania)',
            'de_DE' => 'niemiecki (Niemcy)',
            'el_GR' => 'grecki (Grecja)',
            'en_AU' => 'angielski (Australia)',
            'en_CA' => 'angielski (Kanada)',
            'en_GB' => 'angielski (Wielka Brytania)',
            'en_IN' => 'angielski (Indie)',
            'en_SG' => 'angielski (Singapur)',
            'en_US' => 'angielski (Stany Zjednoczone)',
            'en_ZA' => 'angielski (Republika Południowej Afryki)',
            'es_419' => 'hiszpański (Ameryka Łacińska)',
            'es_ES' => 'hiszpański (Hiszpania)',
            'es_US' => 'hiszpański (Stany Zjednoczone)',
            'et' => 'estoński',
            'eu_ES' => 'baskijski (Hiszpania)',
            'fa' => 'perski',
            'fi_FI' => 'fiński (Finlandia)',
            'fil' => 'filipino',
            'fr_CA' => 'francuski (Kanada)',
            'fr_FR' => 'francuski (Francja)',
            'gl_ES' => 'galicyjski (Hiszpania)',
            'hi_IN' => 'hindi (Indie)',
            'hr' => 'chorwacki',
            'hu_HU' => 'węgierski (Węgry)',
            'hy' => 'ormiański (Armenia)',
            'id' => 'indonezyjski',
            'is_IS' => 'islandzki (Islandia)',
            'it_IT' => 'włoski (Włochy)',
            'iw_IL' => 'hebrajski (Izrael)',
            'ja_JP' => 'japoński (Japonia)',
            'ka_GE' => 'gruziński (Gruzja)',
            'kk' => 'kazachski',
            'km_KH' => 'khmerski (Kambodża)',
            'kn_IN' => 'kannada (Indie)',
            'ko' => 'koreański (Korea Południowa)',
            'ky_KG' => 'kirgiski (Kirgistan)',
            'lo_LA' => 'laotański (Laos)',
            'lt' => 'litewski',
            'lv' => 'łotewski',
            'mk_MK' => 'macedoński (Macedonia Północna)',
            'ml_IN' => 'malajalam (Indie)',
            'mn_MN' => 'mongolski (Mongolia)',
            'mr_IN' => 'marathi (Indie)',
            'ms' => 'malajski',
            'my_MM' => 'birmański (Mjanma [Birma])',
            'ne_NP' => 'nepalski (Nepal)',
            'nl_NL' => 'niderlandzki (Holandia)',
            'no_NO' => 'norweski (Norwegia)',
            'pt_BR' => 'portugalski (Brazylia)',
            'pt_PT' => 'portugalski (Portugalia)',
            'ro' => 'rumuński',
            'ru_RU' => 'rosyjski (Rosja)',
            'si_LK' => 'syngaleski (Sri Lanka)',
            'sk' => 'słowacki',
            'sl' => 'słoweński',
            'sr' => 'serbski',
            'sv_SE' => 'szwedzki (Szwecja)',
            'sw' => 'suahili',
            'ta_IN' => 'tamilski (Indie)',
            'te_IN' => 'telugu (Indie)',
            'th' => 'tajski',
            'tr_TR' => 'turecki (Turcja)',
            'uk' => 'ukraiński',
            'vi' => 'wietnamski',
            'zh_CN' => 'chiński (uproszczone)',
            'zh_HK' => 'chiński (Hongkong)',
            'zh_TW' => 'chiński (tradycyjne)',
            'zu' => 'zulu',
        ],
        'pt_BR' => [
            'af' => 'Africâner',
            'am' => 'Amárico',
            'ar' => 'Árabe',
            'az_AZ' => 'Azerbaijano (Azerbaijão)',
            'be' => 'Bielorrusso',
            'bg' => 'Búlgaro',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Catalão',
            'cs_CZ' => 'Tcheco (Tchéquia)',
            'da_DK' => 'Dinamarquês (Dinamarca)',
            'de_DE' => 'Alemão (Alemanha)',
            'el_GR' => 'Grego (Grécia)',
            'en_AU' => 'Inglês (Austrália)',
            'en_CA' => 'Inglês (Canadá)',
            'en_GB' => 'Inglês (Reino Unido)',
            'en_IN' => 'Inglês (Índia)',
            'en_SG' => 'Inglês (Singapura)',
            'en_US' => 'Inglês (Estados Unidos)',
            'en_ZA' => 'Inglês (África do Sul)',
            'es_419' => 'Espanhol (América Latina)',
            'es_ES' => 'Espanhol (Espanha)',
            'es_US' => 'Espanhol (Estados Unidos)',
            'et' => 'Estoniano',
            'eu_ES' => 'Basco (Espanha)',
            'fa' => 'Persa',
            'fi_FI' => 'Finlandês (Finlândia)',
            'fil' => 'Filipino',
            'fr_CA' => 'Francês (Canadá)',
            'fr_FR' => 'Francês (França)',
            'gl_ES' => 'Galego (Espanha)',
            'hi_IN' => 'Híndi (Índia)',
            'hr' => 'Croata',
            'hu_HU' => 'Húngaro (Hungria)',
            'hy' => 'Armênio (Armênia)',
            'id' => 'Indonésio',
            'is_IS' => 'Islandês (Islândia)',
            'it_IT' => 'Italiano (Itália)',
            'iw_IL' => 'Hebraico (Israel)',
            'ja_JP' => 'Japonês (Japão)',
            'ka_GE' => 'Georgiano (Geórgia)',
            'kk' => 'Cazaque',
            'km_KH' => 'Khmer (Camboja)',
            'kn_IN' => 'Canarim (Índia)',
            'ko' => 'Coreano (Coreia do Sul)',
            'ky_KG' => 'Quirguiz (Quirguistão)',
            'lo_LA' => 'Laosiano (Laos)',
            'lt' => 'Lituano',
            'lv' => 'Letão',
            'mk_MK' => 'Macedônio (Macedônia do Norte)',
            'ml_IN' => 'Malaiala (Índia)',
            'mn_MN' => 'Mongol (Mongólia)',
            'mr_IN' => 'Marati (Índia)',
            'ms' => 'Malaio',
            'my_MM' => 'Birmanês (Mianmar [Birmânia])',
            'ne_NP' => 'Nepalês (Nepal)',
            'nl_NL' => 'Holandês (Países Baixos)',
            'no_NO' => 'Norueguês (Noruega)',
            'pl_PL' => 'Polonês (Polônia)',
            'ro' => 'Romeno',
            'ru_RU' => 'Russo (Rússia)',
            'si_LK' => 'Cingalês (Sri Lanka)',
            'sk' => 'Eslovaco',
            'sl' => 'Esloveno',
            'sr' => 'Sérvio',
            'sv_SE' => 'Sueco (Suécia)',
            'sw' => 'Suaíli',
            'ta_IN' => 'Tâmil (Índia)',
            'te_IN' => 'Télugo (Índia)',
            'th' => 'Tailandês',
            'tr_TR' => 'Turco (Turquia)',
            'uk' => 'Ucraniano',
            'vi' => 'Vietnamita',
            'zh_CN' => 'Chinês (simplificado)',
            'zh_HK' => 'Chinês (Hong Kong)',
            'zh_TW' => 'Chinês (tradicional)',
            'zu' => 'Zulu',
        ],
        'pt_PT' => [
            'af' => 'Africanês',
            'am' => 'Amárico',
            'ar' => 'Árabe',
            'az_AZ' => 'Azerbaijano (Azerbaijão)',
            'be' => 'Bielorrusso',
            'bg' => 'Búlgaro',
            'bn_BD' => 'Bengalês (Bangladeche)',
            'ca' => 'Catalão',
            'cs_CZ' => 'Checo (Chéquia)',
            'da_DK' => 'Dinamarquês (Dinamarca)',
            'de_DE' => 'Alemão (Alemanha)',
            'el_GR' => 'Grego (Grécia)',
            'en_AU' => 'Inglês (Austrália)',
            'en_CA' => 'Inglês (Canadá)',
            'en_GB' => 'Inglês (Reino Unido)',
            'en_IN' => 'Inglês (Índia)',
            'en_SG' => 'Inglês (Singapura)',
            'en_US' => 'Inglês (Estados Unidos)',
            'en_ZA' => 'Inglês (África do Sul)',
            'es_419' => 'Espanhol (América Latina)',
            'es_ES' => 'Espanhol (Espanha)',
            'es_US' => 'Espanhol (Estados Unidos)',
            'et' => 'Estónio',
            'eu_ES' => 'Basco (Espanha)',
            'fa' => 'Persa',
            'fi_FI' => 'Finlandês (Finlândia)',
            'fil' => 'Filipino',
            'fr_CA' => 'Francês (Canadá)',
            'fr_FR' => 'Francês (França)',
            'gl_ES' => 'Galego (Espanha)',
            'hi_IN' => 'Hindi (Índia)',
            'hr' => 'Croata',
            'hu_HU' => 'Húngaro (Hungria)',
            'hy' => 'Arménio (Arménia)',
            'id' => 'Indonésio',
            'is_IS' => 'Islandês (Islândia)',
            'it_IT' => 'Italiano (Itália)',
            'iw_IL' => 'Hebraico (Israel)',
            'ja_JP' => 'Japonês (Japão)',
            'ka_GE' => 'Georgiano (Geórgia)',
            'kk' => 'Cazaque',
            'km_KH' => 'Khmer (Camboja)',
            'kn_IN' => 'Canarim (Índia)',
            'ko' => 'Coreano (Coreia do Sul)',
            'ky_KG' => 'Quirguiz (Quirguistão)',
            'lo_LA' => 'Laosiano (Laos)',
            'lt' => 'Lituano',
            'lv' => 'Letão',
            'mk_MK' => 'Macedónio (Macedónia do Norte)',
            'ml_IN' => 'Malaiala (Índia)',
            'mn_MN' => 'Mongol (Mongólia)',
            'mr_IN' => 'Marata (Índia)',
            'ms' => 'Malaio',
            'my_MM' => 'Birmanês (Mianmar [Birmânia])',
            'ne_NP' => 'Nepalês (Nepal)',
            'nl_NL' => 'Neerlandês (Países Baixos)',
            'no_NO' => 'Norueguês (Noruega)',
            'pl_PL' => 'Polaco (Polónia)',
            'ro' => 'Romeno',
            'ru_RU' => 'Russo (Rússia)',
            'si_LK' => 'Cingalês (Sri Lanca)',
            'sk' => 'Eslovaco',
            'sl' => 'Esloveno',
            'sr' => 'Sérvio',
            'sv_SE' => 'Sueco (Suécia)',
            'sw' => 'Suaíli',
            'ta_IN' => 'Tâmil (Índia)',
            'te_IN' => 'Telugu (Índia)',
            'th' => 'Tailandês',
            'tr_TR' => 'Turco (Turquia)',
            'uk' => 'Ucraniano',
            'vi' => 'Vietnamita',
            'zh_CN' => 'Chinês (simplificado)',
            'zh_HK' => 'Chinês (Hong Kong)',
            'zh_TW' => 'Chinês (tradicional)',
            'zu' => 'Zulu',
        ],
        'ro' => [
            'af' => 'afrikaans',
            'am' => 'amharică',
            'ar' => 'arabă',
            'az_AZ' => 'azeră (Azerbaidjan)',
            'be' => 'belarusă',
            'bg' => 'bulgară',
            'bn_BD' => 'bengaleză (Bangladesh)',
            'ca' => 'catalană',
            'cs_CZ' => 'cehă (Cehia)',
            'da_DK' => 'daneză (Danemarca)',
            'de_DE' => 'germană (Germania)',
            'el_GR' => 'greacă (Grecia)',
            'en_AU' => 'engleză (Australia)',
            'en_CA' => 'engleză (Canada)',
            'en_GB' => 'engleză (Regatul Unit)',
            'en_IN' => 'engleză (India)',
            'en_SG' => 'engleză (Singapore)',
            'en_US' => 'engleză (Statele Unite ale Americii)',
            'en_ZA' => 'engleză (Africa de Sud)',
            'es_419' => 'spaniolă (America Latină)',
            'es_ES' => 'spaniolă (Spania)',
            'es_US' => 'spaniolă (Statele Unite ale Americii)',
            'et' => 'estonă',
            'eu_ES' => 'bască (Spania)',
            'fa' => 'persană',
            'fi_FI' => 'finlandeză (Finlanda)',
            'fil' => 'filipineză',
            'fr_CA' => 'franceză (Canada)',
            'fr_FR' => 'franceză (Franța)',
            'gl_ES' => 'galiciană (Spania)',
            'hi_IN' => 'hindi (India)',
            'hr' => 'croată',
            'hu_HU' => 'maghiară (Ungaria)',
            'hy' => 'armeană (Armenia)',
            'id' => 'indoneziană',
            'is_IS' => 'islandeză (Islanda)',
            'it_IT' => 'italiană (Italia)',
            'iw_IL' => 'ebraică (Israel)',
            'ja_JP' => 'japoneză (Japonia)',
            'ka_GE' => 'georgiană (Georgia)',
            'kk' => 'kazahă',
            'km_KH' => 'khmeră (Cambodgia)',
            'kn_IN' => 'kannada (India)',
            'ko' => 'coreeană (Coreea de Sud)',
            'ky_KG' => 'kârgâză (Kârgâzstan)',
            'lo_LA' => 'laoțiană (Laos)',
            'lt' => 'lituaniană',
            'lv' => 'letonă',
            'mk_MK' => 'macedoneană (Macedonia de Nord)',
            'ml_IN' => 'malayalam (India)',
            'mn_MN' => 'mongolă (Mongolia)',
            'mr_IN' => 'marathi (India)',
            'ms' => 'malaeză',
            'my_MM' => 'birmană (Myanmar [Birmania])',
            'ne_NP' => 'nepaleză (Nepal)',
            'nl_NL' => 'neerlandeză (Țările de Jos)',
            'no_NO' => 'norvegiană (Norvegia)',
            'pl_PL' => 'poloneză (Polonia)',
            'pt_BR' => 'portugheză (Brazilia)',
            'pt_PT' => 'portugheză (Portugalia)',
            'ru_RU' => 'rusă (Rusia)',
            'si_LK' => 'singhaleză (Sri Lanka)',
            'sk' => 'slovacă',
            'sl' => 'slovenă',
            'sr' => 'sârbă',
            'sv_SE' => 'suedeză (Suedia)',
            'sw' => 'swahili',
            'ta_IN' => 'tamilă (India)',
            'te_IN' => 'telugu (India)',
            'th' => 'thailandeză',
            'tr_TR' => 'turcă (Turcia)',
            'uk' => 'ucraineană',
            'vi' => 'vietnameză',
            'zh_CN' => 'chineză (simplificată)',
            'zh_HK' => 'chineză (Hong Kong)',
            'zh_TW' => 'chineză (tradițională)',
            'zu' => 'zulu',
        ],
        'ru_RU' => [
            'af' => 'Африкаанс',
            'am' => 'Амхарский',
            'ar' => 'Арабский',
            'az_AZ' => 'Азербайджанский (Азербайджан)',
            'be' => 'Белорусский',
            'bg' => 'Болгарский',
            'bn_BD' => 'Бенгальский (Бангладеш)',
            'ca' => 'Каталанский',
            'cs_CZ' => 'Чешский (Чехия)',
            'da_DK' => 'Датский (Дания)',
            'de_DE' => 'Немецкий (Германия)',
            'el_GR' => 'Греческий (Греция)',
            'en_AU' => 'Английский (Австралия)',
            'en_CA' => 'Английский (Канада)',
            'en_GB' => 'Английский (Великобритания)',
            'en_IN' => 'Английский (Индия)',
            'en_SG' => 'Английский (Сингапур)',
            'en_US' => 'Английский (Соединенные Штаты)',
            'en_ZA' => 'Английский (Южно-Африканская Республика)',
            'es_419' => 'Испанский (Латинская Америка)',
            'es_ES' => 'Испанский (Испания)',
            'es_US' => 'Испанский (Соединенные Штаты)',
            'et' => 'Эстонский',
            'eu_ES' => 'Баскский (Испания)',
            'fa' => 'Персидский',
            'fi_FI' => 'Финский (Финляндия)',
            'fil' => 'Филиппинский',
            'fr_CA' => 'Французский (Канада)',
            'fr_FR' => 'Французский (Франция)',
            'gl_ES' => 'Галисийский (Испания)',
            'hi_IN' => 'Хинди (Индия)',
            'hr' => 'Хорватский',
            'hu_HU' => 'Венгерский (Венгрия)',
            'hy' => 'Армянский (Армения)',
            'id' => 'Индонезийский',
            'is_IS' => 'Исландский (Исландия)',
            'it_IT' => 'Итальянский (Италия)',
            'iw_IL' => 'Иврит (Израиль)',
            'ja_JP' => 'Японский (Япония)',
            'ka_GE' => 'Грузинский (Грузия)',
            'kk' => 'Казахский',
            'km_KH' => 'Кхмерский (Камбоджа)',
            'kn_IN' => 'Каннада (Индия)',
            'ko' => 'Корейский (Республика Корея)',
            'ky_KG' => 'Киргизский (Киргизия)',
            'lo_LA' => 'Лаосский (Лаос)',
            'lt' => 'Литовский',
            'lv' => 'Латышский',
            'mk_MK' => 'Македонский (Северная Македония)',
            'ml_IN' => 'Малаялам (Индия)',
            'mn_MN' => 'Монгольский (Монголия)',
            'mr_IN' => 'Маратхи (Индия)',
            'ms' => 'Малайский',
            'my_MM' => 'Бирманский (Мьянма [Бирма])',
            'ne_NP' => 'Непальский (Непал)',
            'nl_NL' => 'Нидерландский (Нидерланды)',
            'no_NO' => 'Норвежский (Норвегия)',
            'pl_PL' => 'Польский (Польша)',
            'pt_BR' => 'Португальский (Бразилия)',
            'pt_PT' => 'Португальский (Португалия)',
            'ro' => 'Румынский',
            'si_LK' => 'Сингальский (Шри-Ланка)',
            'sk' => 'Словацкий',
            'sl' => 'Словенский',
            'sr' => 'Сербский',
            'sv_SE' => 'Шведский (Швеция)',
            'sw' => 'Суахили',
            'ta_IN' => 'Тамильский (Индия)',
            'te_IN' => 'Телугу (Индия)',
            'th' => 'Тайский',
            'tr_TR' => 'Турецкий (Турция)',
            'uk' => 'Украинский',
            'vi' => 'Вьетнамский',
            'zh_CN' => 'Китайский (упрощенная китайская)',
            'zh_HK' => 'Китайский (Гонконг)',
            'zh_TW' => 'Китайский (традиционная китайская)',
            'zu' => 'Зулу',
        ],
        'si_LK' => [
            'af' => 'අෆ්රිකාන්ස්',
            'am' => 'ඇම්හාරික්',
            'ar' => 'අරාබි',
            'az_AZ' => 'අසර්බයිජාන් (අසර්බයිජානය)',
            'be' => 'බෙලරුසියානු',
            'bg' => 'බල්ගේරියානු',
            'bn_BD' => 'බෙංගාලි (බංග්ලාදේශය)',
            'ca' => 'කැටලන්',
            'cs_CZ' => 'චෙක් (චෙචියාව)',
            'da_DK' => 'ඩැනිශ් (ඩෙන්මාර්කය)',
            'de_DE' => 'ජර්මන් (ජර්මනිය)',
            'el_GR' => 'ග්‍රීක (ග්‍රීසිය)',
            'en_AU' => 'ඉංග්‍රීසි (ඕස්ට්‍රේලියාව)',
            'en_CA' => 'ඉංග්‍රීසි (කැනඩාව)',
            'en_GB' => 'ඉංග්‍රීසි (එක්සත් රාජධානිය)',
            'en_IN' => 'ඉංග්‍රීසි (ඉන්දියාව)',
            'en_SG' => 'ඉංග්‍රීසි (සිංගප්පූරුව)',
            'en_US' => 'ඉංග්‍රීසි (එක්සත් ජනපදය)',
            'en_ZA' => 'ඉංග්‍රීසි (දකුණු අප්‍රිකාව)',
            'es_419' => 'ස්පාඤ්ඤ (ලතින් ඇමෙරිකාව)',
            'es_ES' => 'ස්පාඤ්ඤ (ස්පාඤ්ඤය)',
            'es_US' => 'ස්පාඤ්ඤ (එක්සත් ජනපදය)',
            'et' => 'එස්තෝනියානු',
            'eu_ES' => 'බාස්ක් (ස්පාඤ්ඤය)',
            'fa' => 'පර්සියානු',
            'fi_FI' => 'ෆින්ලන්ත (ෆින්ලන්තය)',
            'fil' => 'පිලිපීන',
            'fr_CA' => 'ප්‍රංශ (කැනඩාව)',
            'fr_FR' => 'ප්‍රංශ (ප්‍රංශය)',
            'gl_ES' => 'ගැලීසියානු (ස්පාඤ්ඤය)',
            'hi_IN' => 'හින්දි (ඉන්දියාව)',
            'hr' => 'කෝඒෂියානු',
            'hu_HU' => 'හන්ගේරියානු (හන්ගේරියාව)',
            'hy' => 'ආර්මේනියානු (ආර්මේනියාව)',
            'id' => 'ඉන්දුනීසියානු',
            'is_IS' => 'අයිස්ලන්ත (අයිස්ලන්තය)',
            'it_IT' => 'ඉතාලි (ඉතාලිය)',
            'iw_IL' => 'හීබෲ (ඊශ්‍රායලය)',
            'ja_JP' => 'ජපන් (ජපානය)',
            'ka_GE' => 'ජෝර්ජියානු (ජෝර්ජියාව)',
            'kk' => 'කසාඛ්',
            'km_KH' => 'කමර් (කාම්බෝජය)',
            'kn_IN' => 'කණ්ණඩ (ඉන්දියාව)',
            'ko' => 'කොරියානු (දකුණු කොරියාව)',
            'ky_KG' => 'කිර්ගිස් (කිර්ගිස්තානය)',
            'lo_LA' => 'ලාඕ (ලාඕසය)',
            'lt' => 'ලිතුවේනියානු',
            'lv' => 'ලැට්වියානු',
            'mk_MK' => 'මැසිඩෝනියානු (උතුරු මැසිඩෝනියාව)',
            'ml_IN' => 'මලයාලම් (ඉන්දියාව)',
            'mn_MN' => 'මොංගෝලියානු (මොන්ගෝලියාව)',
            'mr_IN' => 'මරාති (ඉන්දියාව)',
            'ms' => 'මැලේ',
            'my_MM' => 'බුරුම (මියන්මාරය [බුරුමය])',
            'ne_NP' => 'නේපාල (නේපාලය)',
            'nl_NL' => 'ලන්දේසි (නෙදර්ලන්තය)',
            'no_NO' => 'නෝර්වීජියානු බොක්මල් (නෝර්වේ)',
            'pl_PL' => 'පෝලන්ත (පෝලන්තය)',
            'pt_BR' => 'පෘතුගීසි (බ්‍රසීලය)',
            'pt_PT' => 'පෘතුගීසි (පෘතුගාලය)',
            'ro' => 'රොමේනියානු',
            'ru_RU' => 'රුසියානු (රුසියාව)',
            'sk' => 'ස්ලෝවැක්',
            'sl' => 'ස්ලෝවේනියානු',
            'sr' => 'සර්බියානු',
            'sv_SE' => 'ස්වීඩන් (ස්වීඩනය)',
            'sw' => 'ස්වාහිලි',
            'ta_IN' => 'දෙමළ (ඉන්දියාව)',
            'te_IN' => 'තෙළිඟු (ඉන්දියාව)',
            'th' => 'තායි',
            'tr_TR' => 'තුර්කි (තුර්කිය)',
            'uk' => 'යුක්රේනියානු',
            'vi' => 'වියට්නාම්',
            'zh_CN' => 'චීන (සුළුකළ)',
            'zh_HK' => 'චීන (හොංකොං)',
            'zh_TW' => 'චීන (සාම්ප්‍රදායික)',
            'zu' => 'සුලු',
        ],
        'sk' => [
            'af' => 'Afrikánčina',
            'am' => 'Amharčina',
            'ar' => 'Arabčina',
            'az_AZ' => 'Azerbajdžančina (Azerbajdžan)',
            'be' => 'Bieloruština',
            'bg' => 'Bulharčina',
            'bn_BD' => 'Bengálčina (Bangladéš)',
            'ca' => 'Katalánčina',
            'cs_CZ' => 'Čeština (Česko)',
            'da_DK' => 'Dánčina (Dánsko)',
            'de_DE' => 'Nemčina (Nemecko)',
            'el_GR' => 'Gréčtina (Grécko)',
            'en_AU' => 'Angličtina (Austrália)',
            'en_CA' => 'Angličtina (Kanada)',
            'en_GB' => 'Angličtina (Spojené kráľovstvo)',
            'en_IN' => 'Angličtina (India)',
            'en_SG' => 'Angličtina (Singapur)',
            'en_US' => 'Angličtina (Spojené štáty)',
            'en_ZA' => 'Angličtina (Južná Afrika)',
            'es_419' => 'Španielčina (Latinská Amerika)',
            'es_ES' => 'Španielčina (Španielsko)',
            'es_US' => 'Španielčina (Spojené štáty)',
            'et' => 'Estónčina',
            'eu_ES' => 'Baskičtina (Španielsko)',
            'fa' => 'Perzština',
            'fi_FI' => 'Fínčina (Fínsko)',
            'fil' => 'Filipínčina',
            'fr_CA' => 'Francúzština (Kanada)',
            'fr_FR' => 'Francúzština (Francúzsko)',
            'gl_ES' => 'Galícijčina (Španielsko)',
            'hi_IN' => 'Hindčina (India)',
            'hr' => 'Chorvátčina',
            'hu_HU' => 'Maďarčina (Maďarsko)',
            'hy' => 'Arménčina (Arménsko)',
            'id' => 'Indonézština',
            'is_IS' => 'Islandčina (Island)',
            'it_IT' => 'Taliančina (Taliansko)',
            'iw_IL' => 'Hebrejčina (Izrael)',
            'ja_JP' => 'Japončina (Japonsko)',
            'ka_GE' => 'Gruzínčina (Gruzínsko)',
            'kk' => 'Kazaština',
            'km_KH' => 'Khmérčina (Kambodža)',
            'kn_IN' => 'Kannadčina (India)',
            'ko' => 'Kórejčina (Južná Kórea)',
            'ky_KG' => 'Kirgizština (Kirgizsko)',
            'lo_LA' => 'Laoština (Laos)',
            'lt' => 'Litovčina',
            'lv' => 'Lotyština',
            'mk_MK' => 'Macedónčina (Severné Macedónsko)',
            'ml_IN' => 'Malajálamčina (India)',
            'mn_MN' => 'Mongolčina (Mongolsko)',
            'mr_IN' => 'Maráthčina (India)',
            'ms' => 'Malajčina',
            'my_MM' => 'Barmčina (Mjanmarsko)',
            'ne_NP' => 'Nepálčina (Nepál)',
            'nl_NL' => 'Holandčina (Holandsko)',
            'no_NO' => 'Nórčina (Nórsko)',
            'pl_PL' => 'Poľština (Poľsko)',
            'pt_BR' => 'Portugalčina (Brazília)',
            'pt_PT' => 'Portugalčina (Portugalsko)',
            'ro' => 'Rumunčina',
            'ru_RU' => 'Ruština (Rusko)',
            'si_LK' => 'Sinhalčina (Srí Lanka)',
            'sl' => 'Slovinčina',
            'sr' => 'Srbčina',
            'sv_SE' => 'Švédčina (Švédsko)',
            'sw' => 'Swahilčina',
            'ta_IN' => 'Tamilčina (India)',
            'te_IN' => 'Telugčina (India)',
            'th' => 'Thajčina',
            'tr_TR' => 'Turečtina (Turecko)',
            'uk' => 'Ukrajinčina',
            'vi' => 'Vietnamčina',
            'zh_CN' => 'Čínština (zjednodušené)',
            'zh_HK' => 'Čínština (Hongkong)',
            'zh_TW' => 'Čínština (tradičné)',
            'zu' => 'Zuluština',
        ],
        'sl' => [
            'af' => 'afrikanščina',
            'am' => 'amharščina',
            'ar' => 'arabščina',
            'az_AZ' => 'azerbajdžanščina (Azerbajdžan)',
            'be' => 'beloruščina',
            'bg' => 'bolgarščina',
            'bn_BD' => 'bengalščina (Bangladeš)',
            'ca' => 'katalonščina',
            'cs_CZ' => 'češčina (Češka)',
            'da_DK' => 'danščina (Danska)',
            'de_DE' => 'nemščina (Nemčija)',
            'el_GR' => 'grščina (Grčija)',
            'en_AU' => 'angleščina (Avstralija)',
            'en_CA' => 'angleščina (Kanada)',
            'en_GB' => 'angleščina (Združeno kraljestvo)',
            'en_IN' => 'angleščina (Indija)',
            'en_SG' => 'angleščina (Singapur)',
            'en_US' => 'angleščina (Združene države Amerike)',
            'en_ZA' => 'angleščina (Južnoafriška republika)',
            'es_419' => 'španščina (Latinska Amerika)',
            'es_ES' => 'španščina (Španija)',
            'es_US' => 'španščina (Združene države Amerike)',
            'et' => 'estonščina',
            'eu_ES' => 'baskovščina (Španija)',
            'fa' => 'perzijščina',
            'fi_FI' => 'finščina (Finska)',
            'fil' => 'filipinščina',
            'fr_CA' => 'francoščina (Kanada)',
            'fr_FR' => 'francoščina (Francija)',
            'gl_ES' => 'galicijščina (Španija)',
            'hi_IN' => 'hindujščina (Indija)',
            'hr' => 'hrvaščina',
            'hu_HU' => 'madžarščina (Madžarska)',
            'hy' => 'armenščina (Armenija)',
            'id' => 'indonezijščina',
            'is_IS' => 'islandščina (Islandija)',
            'it_IT' => 'italijanščina (Italija)',
            'iw_IL' => 'hebrejščina (Izrael)',
            'ja_JP' => 'japonščina (Japonska)',
            'ka_GE' => 'gruzijščina (Gruzija)',
            'kk' => 'kazaščina',
            'km_KH' => 'kmerščina (Kambodža)',
            'kn_IN' => 'kanareščina (Indija)',
            'ko' => 'korejščina (Južna Koreja)',
            'ky_KG' => 'kirgiščina (Kirgizistan)',
            'lo_LA' => 'laoščina (Laos)',
            'lt' => 'litovščina',
            'lv' => 'latvijščina',
            'mk_MK' => 'makedonščina (Severna Makedonija)',
            'ml_IN' => 'malajalamščina (Indija)',
            'mn_MN' => 'mongolščina (Mongolija)',
            'mr_IN' => 'maratščina (Indija)',
            'ms' => 'malajščina',
            'my_MM' => 'burmanščina (Mjanmar [Burma])',
            'ne_NP' => 'nepalščina (Nepal)',
            'nl_NL' => 'nizozemščina (Nizozemska)',
            'no_NO' => 'norveščina (Norveška)',
            'pl_PL' => 'poljščina (Poljska)',
            'pt_BR' => 'portugalščina (Brazilija)',
            'pt_PT' => 'portugalščina (Portugalska)',
            'ro' => 'romunščina',
            'ru_RU' => 'ruščina (Rusija)',
            'si_LK' => 'sinhalščina (Šrilanka)',
            'sk' => 'slovaščina',
            'sr' => 'srbščina',
            'sv_SE' => 'švedščina (Švedska)',
            'sw' => 'svahili',
            'ta_IN' => 'tamilščina (Indija)',
            'te_IN' => 'telugijščina (Indija)',
            'th' => 'tajščina',
            'tr_TR' => 'turščina (Turčija)',
            'uk' => 'ukrajinščina',
            'vi' => 'vietnamščina',
            'zh_CN' => 'kitajščina (poenostavljena pisava han)',
            'zh_HK' => 'kitajščina (Hongkong)',
            'zh_TW' => 'kitajščina (tradicionalna pisava han)',
            'zu' => 'zulujščina',
        ],
        'sr' => [
            'af' => 'африканс',
            'am' => 'амхарски',
            'ar' => 'арапски',
            'az_AZ' => 'азербејџански (Азербејџан)',
            'be' => 'белоруски',
            'bg' => 'бугарски',
            'bn_BD' => 'бенгалски (Бангладеш)',
            'ca' => 'каталонски',
            'cs_CZ' => 'чешки (Чешка)',
            'da_DK' => 'дански (Данска)',
            'de_DE' => 'немачки (Немачка)',
            'el_GR' => 'грчки (Грчка)',
            'en_AU' => 'енглески (Аустралија)',
            'en_CA' => 'енглески (Канада)',
            'en_GB' => 'енглески (Уједињено Краљевство)',
            'en_IN' => 'енглески (Индија)',
            'en_SG' => 'енглески (Сингапур)',
            'en_US' => 'енглески (Сједињене Државе)',
            'en_ZA' => 'енглески (Јужноафричка Република)',
            'es_419' => 'шпански (Латинска Америка)',
            'es_ES' => 'шпански (Шпанија)',
            'es_US' => 'шпански (Сједињене Државе)',
            'et' => 'естонски',
            'eu_ES' => 'баскијски (Шпанија)',
            'fa' => 'персијски',
            'fi_FI' => 'фински (Финска)',
            'fil' => 'филипински',
            'fr_CA' => 'француски (Канада)',
            'fr_FR' => 'француски (Француска)',
            'gl_ES' => 'галицијски (Шпанија)',
            'hi_IN' => 'хинди (Индија)',
            'hr' => 'хрватски',
            'hu_HU' => 'мађарски (Мађарска)',
            'hy' => 'јерменски (Јерменија)',
            'id' => 'индонежански',
            'is_IS' => 'исландски (Исланд)',
            'it_IT' => 'италијански (Италија)',
            'iw_IL' => 'хебрејски (Израел)',
            'ja_JP' => 'јапански (Јапан)',
            'ka_GE' => 'грузијски (Грузија)',
            'kk' => 'казашки',
            'km_KH' => 'кмерски (Камбоџа)',
            'kn_IN' => 'канада (Индија)',
            'ko' => 'корејски (Јужна Кореја)',
            'ky_KG' => 'киргиски (Киргистан)',
            'lo_LA' => 'лаоски (Лаос)',
            'lt' => 'литвански',
            'lv' => 'летонски',
            'mk_MK' => 'македонски (Северна Македонија)',
            'ml_IN' => 'малајалам (Индија)',
            'mn_MN' => 'монголски (Монголија)',
            'mr_IN' => 'марати (Индија)',
            'ms' => 'малајски',
            'my_MM' => 'бурмански (Мијанмар [Бурма])',
            'ne_NP' => 'непалски (Непал)',
            'nl_NL' => 'холандски (Холандија)',
            'no_NO' => 'норвешки (Норвешка)',
            'pl_PL' => 'пољски (Пољска)',
            'pt_BR' => 'португалски (Бразил)',
            'pt_PT' => 'португалски (Португалија)',
            'ro' => 'румунски',
            'ru_RU' => 'руски (Русија)',
            'si_LK' => 'синхалешки (Шри Ланка)',
            'sk' => 'словачки',
            'sl' => 'словеначки',
            'sv_SE' => 'шведски (Шведска)',
            'sw' => 'свахили',
            'ta_IN' => 'тамилски (Индија)',
            'te_IN' => 'телугу (Индија)',
            'th' => 'тајски',
            'tr_TR' => 'турски (Турска)',
            'uk' => 'украјински',
            'vi' => 'вијетнамски',
            'zh_CN' => 'кинески (поједностављено кинеско писмо)',
            'zh_HK' => 'кинески (Хонгконг)',
            'zh_TW' => 'кинески (традиционално кинеско писмо)',
            'zu' => 'зулу',
        ],
        'sv_SE' => [
            'af' => 'Afrikaans',
            'am' => 'Amhariska',
            'ar' => 'Arabiska',
            'az_AZ' => 'Azerbajdzjanska (Azerbajdzjan)',
            'be' => 'Vitryska',
            'bg' => 'Bulgariska',
            'bn_BD' => 'Bengali (Bangladesh)',
            'ca' => 'Katalanska',
            'cs_CZ' => 'Tjeckiska (Tjeckien)',
            'da_DK' => 'Danska (Danmark)',
            'de_DE' => 'Tyska (Tyskland)',
            'el_GR' => 'Grekiska (Grekland)',
            'en_AU' => 'Engelska (Australien)',
            'en_CA' => 'Engelska (Kanada)',
            'en_GB' => 'Engelska (Storbritannien)',
            'en_IN' => 'Engelska (Indien)',
            'en_SG' => 'Engelska (Singapore)',
            'en_US' => 'Engelska (USA)',
            'en_ZA' => 'Engelska (Sydafrika)',
            'es_419' => 'Spanska (Latinamerika)',
            'es_ES' => 'Spanska (Spanien)',
            'es_US' => 'Spanska (USA)',
            'et' => 'Estniska',
            'eu_ES' => 'Baskiska (Spanien)',
            'fa' => 'Persiska',
            'fi_FI' => 'Finska (Finland)',
            'fil' => 'Filippinska',
            'fr_CA' => 'Franska (Kanada)',
            'fr_FR' => 'Franska (Frankrike)',
            'gl_ES' => 'Galiciska (Spanien)',
            'hi_IN' => 'Hindi (Indien)',
            'hr' => 'Kroatiska',
            'hu_HU' => 'Ungerska (Ungern)',
            'hy' => 'Armeniska (Armenien)',
            'id' => 'Indonesiska',
            'is_IS' => 'Isländska (Island)',
            'it_IT' => 'Italienska (Italien)',
            'iw_IL' => 'Hebreiska (Israel)',
            'ja_JP' => 'Japanska (Japan)',
            'ka_GE' => 'Georgiska (Georgien)',
            'kk' => 'Kazakiska',
            'km_KH' => 'Kambodjanska (Kambodja)',
            'kn_IN' => 'Kannada (Indien)',
            'ko' => 'Koreanska (Sydkorea)',
            'ky_KG' => 'Kirgiziska (Kirgizistan)',
            'lo_LA' => 'Laotiska (Laos)',
            'lt' => 'Litauiska',
            'lv' => 'Lettiska',
            'mk_MK' => 'Makedonska (Nordmakedonien)',
            'ml_IN' => 'Malayalam (Indien)',
            'mn_MN' => 'Mongoliska (Mongoliet)',
            'mr_IN' => 'Marathi (Indien)',
            'ms' => 'Malajiska',
            'my_MM' => 'Burmesiska (Myanmar [Burma])',
            'ne_NP' => 'Nepalesiska (Nepal)',
            'nl_NL' => 'Nederländska (Nederländerna)',
            'no_NO' => 'Norska (Norge)',
            'pl_PL' => 'Polska (Polen)',
            'pt_BR' => 'Portugisiska (Brasilien)',
            'pt_PT' => 'Portugisiska (Portugal)',
            'ro' => 'Rumänska',
            'ru_RU' => 'Ryska (Ryssland)',
            'si_LK' => 'Singalesiska (Sri Lanka)',
            'sk' => 'Slovakiska',
            'sl' => 'Slovenska',
            'sr' => 'Serbiska',
            'sw' => 'Swahili',
            'ta_IN' => 'Tamil (Indien)',
            'te_IN' => 'Telugu (Indien)',
            'th' => 'Thailändska',
            'tr_TR' => 'Turkiska (Turkiet)',
            'uk' => 'Ukrainska',
            'vi' => 'Vietnamesiska',
            'zh_CN' => 'Kinesiska (förenklade)',
            'zh_HK' => 'Kinesiska (Hongkong)',
            'zh_TW' => 'Kinesiska (traditionella)',
            'zu' => 'Zulu',
        ],
        'sw' => [
            'af' => 'Kiafrikana',
            'am' => 'Kiamhari',
            'ar' => 'Kiarabu',
            'az_AZ' => 'Kiazerbaijani (Azerbaijani)',
            'be' => 'Kibelarusi',
            'bg' => 'Kibulgaria',
            'bn_BD' => 'Kibengali (Bangladeshi)',
            'ca' => 'Kikatalani',
            'cs_CZ' => 'Kicheki (Chechia)',
            'da_DK' => 'Kidenmaki (Denmark)',
            'de_DE' => 'Kijerumani (Ujerumani)',
            'el_GR' => 'Kigiriki (Ugiriki)',
            'en_AU' => 'Kiingereza (Australia)',
            'en_CA' => 'Kiingereza (Kanada)',
            'en_GB' => 'Kiingereza (Ufalme wa Muungano)',
            'en_IN' => 'Kiingereza (India)',
            'en_SG' => 'Kiingereza (Singapore)',
            'en_US' => 'Kiingereza (Marekani)',
            'en_ZA' => 'Kiingereza (Afrika Kusini)',
            'es_419' => 'Kihispania (Amerika ya Kilatini)',
            'es_ES' => 'Kihispania (Uhispania)',
            'es_US' => 'Kihispania (Marekani)',
            'et' => 'Kiestonia',
            'eu_ES' => 'Kibaski (Uhispania)',
            'fa' => 'Kiajemi',
            'fi_FI' => 'Kifini (Ufini)',
            'fil' => 'Kifilipino',
            'fr_CA' => 'Kifaransa (Kanada)',
            'fr_FR' => 'Kifaransa (Ufaransa)',
            'gl_ES' => 'Kigalisi (Uhispania)',
            'hi_IN' => 'Kihindi (India)',
            'hr' => 'Kikroeshia',
            'hu_HU' => 'Kihungaria (Hungaria)',
            'hy' => 'Kiarmenia (Armenia)',
            'id' => 'Kiindonesia',
            'is_IS' => 'Kiisilandi (Aisilandi)',
            'it_IT' => 'Kiitaliano (Italia)',
            'iw_IL' => 'Kiebrania (Israeli)',
            'ja_JP' => 'Kijapani (Japani)',
            'ka_GE' => 'Kijojia (Jojia)',
            'kk' => 'Kikazakh',
            'km_KH' => 'Kikambodia (Kambodia)',
            'kn_IN' => 'Kikannada (India)',
            'ko' => 'Kikorea (Korea Kusini)',
            'ky_KG' => 'Kikyrgyz (Kirigizistani)',
            'lo_LA' => 'Kilaosi (Laos)',
            'lt' => 'Kilithuania',
            'lv' => 'Kilatvia',
            'mk_MK' => 'Kimacedonia (Masedonia ya Kaskazini)',
            'ml_IN' => 'Kimalayalamu (India)',
            'mn_MN' => 'Kimongolia (Mongolia)',
            'mr_IN' => 'Kimarathi (India)',
            'ms' => 'Kimalei',
            'my_MM' => 'Kiburma (Myanmar [Burma])',
            'ne_NP' => 'Kinepali (Nepal)',
            'nl_NL' => 'Kiholanzi (Uholanzi)',
            'no_NO' => 'Kinorwe (Norway)',
            'pl_PL' => 'Kipolandi (Poland)',
            'pt_BR' => 'Kireno (Brazil)',
            'pt_PT' => 'Kireno (Ureno)',
            'ro' => 'Kiromania',
            'ru_RU' => 'Kirusi (Urusi)',
            'si_LK' => 'Kisinhala (Sri Lanka)',
            'sk' => 'Kislovakia',
            'sl' => 'Kislovenia',
            'sr' => 'Kiserbia',
            'sv_SE' => 'Kiswidi (Uswidi)',
            'ta_IN' => 'Kitamili (India)',
            'te_IN' => 'Kitelugu (India)',
            'th' => 'Kithai',
            'tr_TR' => 'Kituruki (Uturuki)',
            'uk' => 'Kiukraini',
            'vi' => 'Kivietinamu',
            'zh_CN' => 'Kichina (Rahisi)',
            'zh_HK' => 'Kichina (Hong Kong)',
            'zh_TW' => 'Kichina (Cha jadi)',
            'zu' => 'Kizulu',
        ],
        'ta_IN' => [
            'af' => 'ஆஃப்ரிகான்ஸ்',
            'am' => 'அம்ஹாரிக்',
            'ar' => 'அரபிக்',
            'az_AZ' => 'அசர்பைஜானி (அசர்பைஜான்)',
            'be' => 'பெலாருஷியன்',
            'bg' => 'பல்கேரியன்',
            'bn_BD' => 'வங்காளம் (பங்களாதேஷ்)',
            'ca' => 'கேட்டலான்',
            'cs_CZ' => 'செக் (செசியா)',
            'da_DK' => 'டேனிஷ் (டென்மார்க்)',
            'de_DE' => 'ஜெர்மன் (ஜெர்மனி)',
            'el_GR' => 'கிரேக்கம் (கிரீஸ்)',
            'en_AU' => 'ஆங்கிலம் (ஆஸ்திரேலியா)',
            'en_CA' => 'ஆங்கிலம் (கனடா)',
            'en_GB' => 'ஆங்கிலம் (யுனைடெட் கிங்டம்)',
            'en_IN' => 'ஆங்கிலம் (இந்தியா)',
            'en_SG' => 'ஆங்கிலம் (சிங்கப்பூர்)',
            'en_US' => 'ஆங்கிலம் (அமெரிக்கா)',
            'en_ZA' => 'ஆங்கிலம் (தென் ஆப்பிரிக்கா)',
            'es_419' => 'ஸ்பானிஷ் (லத்தீன் அமெரிக்கா)',
            'es_ES' => 'ஸ்பானிஷ் (ஸ்பெயின்)',
            'es_US' => 'ஸ்பானிஷ் (அமெரிக்கா)',
            'et' => 'எஸ்டோனியன்',
            'eu_ES' => 'பாஸ்க் (ஸ்பெயின்)',
            'fa' => 'பெர்ஷியன்',
            'fi_FI' => 'ஃபின்னிஷ் (பின்லாந்து)',
            'fil' => 'ஃபிலிபினோ',
            'fr_CA' => 'பிரெஞ்சு (கனடா)',
            'fr_FR' => 'பிரெஞ்சு (பிரான்ஸ்)',
            'gl_ES' => 'காலிஸியன் (ஸ்பெயின்)',
            'hi_IN' => 'இந்தி (இந்தியா)',
            'hr' => 'குரோஷியன்',
            'hu_HU' => 'ஹங்கேரியன் (ஹங்கேரி)',
            'hy' => 'ஆர்மேனியன் (அர்மேனியா)',
            'id' => 'இந்தோனேஷியன்',
            'is_IS' => 'ஐஸ்லேண்டிக் (ஐஸ்லாந்து)',
            'it_IT' => 'இத்தாலியன் (இத்தாலி)',
            'iw_IL' => 'ஹீப்ரூ (இஸ்ரேல்)',
            'ja_JP' => 'ஜப்பானியம் (ஜப்பான்)',
            'ka_GE' => 'ஜார்ஜியன் (ஜார்ஜியா)',
            'kk' => 'கசாக்',
            'km_KH' => 'கெமெர் (கம்போடியா)',
            'kn_IN' => 'கன்னடம் (இந்தியா)',
            'ko' => 'கொரியன் (தென் கொரியா)',
            'ky_KG' => 'கிர்கிஸ் (கிர்கிஸ்தான்)',
            'lo_LA' => 'லாவோ (லாவோஸ்)',
            'lt' => 'லிதுவேனியன்',
            'lv' => 'லாட்வியன்',
            'mk_MK' => 'மாஸிடோனியன் (வடக்கு மாசிடோனியா)',
            'ml_IN' => 'மலையாளம் (இந்தியா)',
            'mn_MN' => 'மங்கோலியன் (மங்கோலியா)',
            'mr_IN' => 'மராத்தி (இந்தியா)',
            'ms' => 'மலாய்',
            'my_MM' => 'பர்மீஸ் (மியான்மார் [பர்மா])',
            'ne_NP' => 'நேபாளி (நேபாளம்)',
            'nl_NL' => 'டச்சு (நெதர்லாந்து)',
            'no_NO' => 'நார்வேஜியன் (நார்வே)',
            'pl_PL' => 'போலிஷ் (போலந்து)',
            'pt_BR' => 'போர்ச்சுக்கீஸ் (பிரேசில்)',
            'pt_PT' => 'போர்ச்சுக்கீஸ் (போர்ச்சுக்கல்)',
            'ro' => 'ரோமேனியன்',
            'ru_RU' => 'ரஷியன் (ரஷ்யா)',
            'si_LK' => 'சிங்களம் (இலங்கை)',
            'sk' => 'ஸ்லோவாக்',
            'sl' => 'ஸ்லோவேனியன்',
            'sr' => 'செர்பியன்',
            'sv_SE' => 'ஸ்வீடிஷ் (ஸ்வீடன்)',
            'sw' => 'ஸ்வாஹிலி',
            'te_IN' => 'தெலுங்கு (இந்தியா)',
            'th' => 'தாய்',
            'tr_TR' => 'துருக்கிஷ் (துருக்கி)',
            'uk' => 'உக்ரைனியன்',
            'vi' => 'வியட்நாமீஸ்',
            'zh_CN' => 'சீனம் (எளிதாக்கப்பட்டது)',
            'zh_HK' => 'சீனம் (ஹாங்காங்)',
            'zh_TW' => 'சீனம் (பாரம்பரியம்)',
            'zu' => 'ஜுலு',
        ],
        'te_IN' => [
            'af' => 'ఆఫ్రికాన్స్',
            'am' => 'అమ్హారిక్',
            'ar' => 'అరబిక్',
            'az_AZ' => 'అజర్బైజాని (అజర్బైజాన్)',
            'be' => 'బెలారుషియన్',
            'bg' => 'బల్గేరియన్',
            'bn_BD' => 'బంగ్లా (బంగ్లాదేశ్)',
            'ca' => 'కాటలాన్',
            'cs_CZ' => 'చెక్ (చెకియా)',
            'da_DK' => 'డానిష్ (డెన్మార్క్)',
            'de_DE' => 'జర్మన్ (జర్మనీ)',
            'el_GR' => 'గ్రీక్ (గ్రీస్)',
            'en_AU' => 'ఆంగ్లం (ఆస్ట్రేలియా)',
            'en_CA' => 'ఆంగ్లం (కెనడా)',
            'en_GB' => 'ఆంగ్లం (యునైటెడ్ కింగ్‌డమ్)',
            'en_IN' => 'ఆంగ్లం (భారతదేశం)',
            'en_SG' => 'ఆంగ్లం (సింగపూర్)',
            'en_US' => 'ఆంగ్లం (యునైటెడ్ స్టేట్స్)',
            'en_ZA' => 'ఆంగ్లం (దక్షిణ ఆఫ్రికా)',
            'es_419' => 'స్పానిష్ (లాటిన్ అమెరికా)',
            'es_ES' => 'స్పానిష్ (స్పెయిన్)',
            'es_US' => 'స్పానిష్ (యునైటెడ్ స్టేట్స్)',
            'et' => 'ఎస్టోనియన్',
            'eu_ES' => 'బాస్క్యూ (స్పెయిన్)',
            'fa' => 'పర్షియన్',
            'fi_FI' => 'ఫిన్నిష్ (ఫిన్లాండ్)',
            'fil' => 'ఫిలిపినో',
            'fr_CA' => 'ఫ్రెంచ్ (కెనడా)',
            'fr_FR' => 'ఫ్రెంచ్ (ఫ్రాన్స్‌)',
            'gl_ES' => 'గాలిషియన్ (స్పెయిన్)',
            'hi_IN' => 'హిందీ (భారతదేశం)',
            'hr' => 'క్రొయేషియన్',
            'hu_HU' => 'హంగేరియన్ (హంగేరీ)',
            'hy' => 'ఆర్మేనియన్ (ఆర్మేనియా)',
            'id' => 'ఇండోనేషియన్',
            'is_IS' => 'ఐస్లాండిక్ (ఐస్లాండ్)',
            'it_IT' => 'ఇటాలియన్ (ఇటలీ)',
            'iw_IL' => 'హిబ్రూ (ఇజ్రాయెల్)',
            'ja_JP' => 'జపనీస్ (జపాన్)',
            'ka_GE' => 'జార్జియన్ (జార్జియా)',
            'kk' => 'కజఖ్',
            'km_KH' => 'ఖ్మేర్ (కంబోడియా)',
            'kn_IN' => 'కన్నడ (భారతదేశం)',
            'ko' => 'కొరియన్ (దక్షిణ కొరియా)',
            'ky_KG' => 'కిర్గిజ్ (కిర్గిజిస్తాన్)',
            'lo_LA' => 'లావో (లావోస్)',
            'lt' => 'లిథువేనియన్',
            'lv' => 'లాట్వియన్',
            'mk_MK' => 'మాసిడోనియన్ (ఉత్తర మాసిడోనియా)',
            'ml_IN' => 'మలయాళం (భారతదేశం)',
            'mn_MN' => 'మంగోలియన్ (మంగోలియా)',
            'mr_IN' => 'మరాఠీ (భారతదేశం)',
            'ms' => 'మలయ్',
            'my_MM' => 'బర్మీస్ (మయన్మార్)',
            'ne_NP' => 'నేపాలి (నేపాల్)',
            'nl_NL' => 'డచ్ (నెదర్లాండ్స్)',
            'no_NO' => 'నార్వేజియన్ (నార్వే)',
            'pl_PL' => 'పోలిష్ (పోలాండ్)',
            'pt_BR' => 'పోర్చుగీస్ (బ్రెజిల్)',
            'pt_PT' => 'పోర్చుగీస్ (పోర్చుగల్)',
            'ro' => 'రోమేనియన్',
            'ru_RU' => 'రష్యన్ (రష్యా)',
            'si_LK' => 'సింహళం (శ్రీలంక)',
            'sk' => 'స్లోవక్',
            'sl' => 'స్లోవేనియన్',
            'sr' => 'సెర్బియన్',
            'sv_SE' => 'స్వీడిష్ (స్వీడన్)',
            'sw' => 'స్వాహిలి',
            'ta_IN' => 'తమిళము (భారతదేశం)',
            'th' => 'థాయ్',
            'tr_TR' => 'టర్కిష్ (టర్కీ)',
            'uk' => 'ఉక్రెయినియన్',
            'vi' => 'వియత్నామీస్',
            'zh_CN' => 'చైనీస్ (సరళీకృతం)',
            'zh_HK' => 'చైనీస్ (హాంకాంగ్)',
            'zh_TW' => 'చైనీస్ (సాంప్రదాయక)',
            'zu' => 'జూలూ',
        ],
        'th' => [
            'af' => 'แอฟริกานส์',
            'am' => 'อัมฮารา',
            'ar' => 'อาหรับ',
            'az_AZ' => 'อาเซอร์ไบจาน (อาเซอร์ไบจาน)',
            'be' => 'เบลารุส',
            'bg' => 'บัลแกเรีย',
            'bn_BD' => 'บังกลา (บังกลาเทศ)',
            'ca' => 'คาตาลัน',
            'cs_CZ' => 'เช็ก (เช็ก)',
            'da_DK' => 'เดนมาร์ก (เดนมาร์ก)',
            'de_DE' => 'เยอรมัน (เยอรมนี)',
            'el_GR' => 'กรีก (กรีซ)',
            'en_AU' => 'อังกฤษ (ออสเตรเลีย)',
            'en_CA' => 'อังกฤษ (แคนาดา)',
            'en_GB' => 'อังกฤษ (สหราชอาณาจักร)',
            'en_IN' => 'อังกฤษ (อินเดีย)',
            'en_SG' => 'อังกฤษ (สิงคโปร์)',
            'en_US' => 'อังกฤษ (สหรัฐอเมริกา)',
            'en_ZA' => 'อังกฤษ (แอฟริกาใต้)',
            'es_419' => 'สเปน (ละตินอเมริกา)',
            'es_ES' => 'สเปน (สเปน)',
            'es_US' => 'สเปน (สหรัฐอเมริกา)',
            'et' => 'เอสโตเนีย',
            'eu_ES' => 'บาสก์ (สเปน)',
            'fa' => 'เปอร์เซีย',
            'fi_FI' => 'ฟินแลนด์ (ฟินแลนด์)',
            'fil' => 'ฟิลิปปินส์',
            'fr_CA' => 'ฝรั่งเศส (แคนาดา)',
            'fr_FR' => 'ฝรั่งเศส (ฝรั่งเศส)',
            'gl_ES' => 'กาลิเซีย (สเปน)',
            'hi_IN' => 'ฮินดี (อินเดีย)',
            'hr' => 'โครเอเชีย',
            'hu_HU' => 'ฮังการี (ฮังการี)',
            'hy' => 'อาร์เมเนีย (อาร์เมเนีย)',
            'id' => 'อินโดนีเซีย',
            'is_IS' => 'ไอซ์แลนด์ (ไอซ์แลนด์)',
            'it_IT' => 'อิตาลี (อิตาลี)',
            'iw_IL' => 'ฮิบรู (อิสราเอล)',
            'ja_JP' => 'ญี่ปุ่น (ญี่ปุ่น)',
            'ka_GE' => 'จอร์เจีย (จอร์เจีย)',
            'kk' => 'คาซัค',
            'km_KH' => 'เขมร (กัมพูชา)',
            'kn_IN' => 'กันนาดา (อินเดีย)',
            'ko' => 'เกาหลี (เกาหลีใต้)',
            'ky_KG' => 'คีร์กีซ (คีร์กีซสถาน)',
            'lo_LA' => 'ลาว (ลาว)',
            'lt' => 'ลิทัวเนีย',
            'lv' => 'ลัตเวีย',
            'mk_MK' => 'มาซิโดเนีย (มาซิโดเนียเหนือ)',
            'ml_IN' => 'มาลายาลัม (อินเดีย)',
            'mn_MN' => 'มองโกเลีย (มองโกเลีย)',
            'mr_IN' => 'มราฐี (อินเดีย)',
            'ms' => 'มาเลย์',
            'my_MM' => 'พม่า (เมียนมาร์ [พม่า])',
            'ne_NP' => 'เนปาล (เนปาล)',
            'nl_NL' => 'ดัตช์ (เนเธอร์แลนด์)',
            'no_NO' => 'นอร์เวย์ (นอร์เวย์)',
            'pl_PL' => 'โปแลนด์ (โปแลนด์)',
            'pt_BR' => 'โปรตุเกส (บราซิล)',
            'pt_PT' => 'โปรตุเกส (โปรตุเกส)',
            'ro' => 'โรมาเนีย',
            'ru_RU' => 'รัสเซีย (รัสเซีย)',
            'si_LK' => 'สิงหล (ศรีลังกา)',
            'sk' => 'สโลวัก',
            'sl' => 'สโลวีเนีย',
            'sr' => 'เซอร์เบีย',
            'sv_SE' => 'สวีเดน (สวีเดน)',
            'sw' => 'สวาฮีลี',
            'ta_IN' => 'ทมิฬ (อินเดีย)',
            'te_IN' => 'เตลูกู (อินเดีย)',
            'tr_TR' => 'ตุรกี (ตุรกี)',
            'uk' => 'ยูเครน',
            'vi' => 'เวียดนาม',
            'zh_CN' => 'จีน (ตัวย่อ)',
            'zh_HK' => 'จีน (ฮ่องกง)',
            'zh_TW' => 'จีน (ตัวเต็ม)',
            'zu' => 'ซูลู',
        ],
        'tr_TR' => [
            'af' => 'Afrikaanca',
            'am' => 'Amharca',
            'ar' => 'Arapça',
            'az_AZ' => 'Azerbaycan dili (Azerbaycan)',
            'be' => 'Belarusça',
            'bg' => 'Bulgarca',
            'bn_BD' => 'Bengalce (Bangladeş)',
            'ca' => 'Katalanca',
            'cs_CZ' => 'Çekçe (Çekya)',
            'da_DK' => 'Danca (Danimarka)',
            'de_DE' => 'Almanca (Almanya)',
            'el_GR' => 'Yunanca (Yunanistan)',
            'en_AU' => 'İngilizce (Avustralya)',
            'en_CA' => 'İngilizce (Kanada)',
            'en_GB' => 'İngilizce (Birleşik Krallık)',
            'en_IN' => 'İngilizce (Hindistan)',
            'en_SG' => 'İngilizce (Singapur)',
            'en_US' => 'İngilizce (Amerika Birleşik Devletleri)',
            'en_ZA' => 'İngilizce (Güney Afrika)',
            'es_419' => 'İspanyolca (Latin Amerika)',
            'es_ES' => 'İspanyolca (İspanya)',
            'es_US' => 'İspanyolca (Amerika Birleşik Devletleri)',
            'et' => 'Estonca',
            'eu_ES' => 'Baskça (İspanya)',
            'fa' => 'Farsça',
            'fi_FI' => 'Fince (Finlandiya)',
            'fil' => 'Filipince',
            'fr_CA' => 'Fransızca (Kanada)',
            'fr_FR' => 'Fransızca (Fransa)',
            'gl_ES' => 'Galiçyaca (İspanya)',
            'hi_IN' => 'Hintçe (Hindistan)',
            'hr' => 'Hırvatça',
            'hu_HU' => 'Macarca (Macaristan)',
            'hy' => 'Ermenice (Ermenistan)',
            'id' => 'Endonezce',
            'is_IS' => 'İzlandaca (İzlanda)',
            'it_IT' => 'İtalyanca (İtalya)',
            'iw_IL' => 'İbranice (İsrail)',
            'ja_JP' => 'Japonca (Japonya)',
            'ka_GE' => 'Gürcüce (Gürcistan)',
            'kk' => 'Kazakça',
            'km_KH' => 'Khmer dili (Kamboçya)',
            'kn_IN' => 'Kannada dili (Hindistan)',
            'ko' => 'Korece (Güney Kore)',
            'ky_KG' => 'Kırgızca (Kırgızistan)',
            'lo_LA' => 'Lao dili (Laos)',
            'lt' => 'Litvanca',
            'lv' => 'Letonca',
            'mk_MK' => 'Makedonca (Kuzey Makedonya)',
            'ml_IN' => 'Malayalam dili (Hindistan)',
            'mn_MN' => 'Moğolca (Moğolistan)',
            'mr_IN' => 'Marathi dili (Hindistan)',
            'ms' => 'Malayca',
            'my_MM' => 'Birman dili (Myanmar [Burma])',
            'ne_NP' => 'Nepalce (Nepal)',
            'nl_NL' => 'Felemenkçe (Hollanda)',
            'no_NO' => 'Norveççe (Norveç)',
            'pl_PL' => 'Lehçe (Polonya)',
            'pt_BR' => 'Portekizce (Brezilya)',
            'pt_PT' => 'Portekizce (Portekiz)',
            'ro' => 'Rumence',
            'ru_RU' => 'Rusça (Rusya)',
            'si_LK' => 'Sinhali dili (Sri Lanka)',
            'sk' => 'Slovakça',
            'sl' => 'Slovence',
            'sr' => 'Sırpça',
            'sv_SE' => 'İsveççe (İsveç)',
            'sw' => 'Svahili dili',
            'ta_IN' => 'Tamilce (Hindistan)',
            'te_IN' => 'Telugu dili (Hindistan)',
            'th' => 'Tayca',
            'uk' => 'Ukraynaca',
            'vi' => 'Vietnamca',
            'zh_CN' => 'Çince (Basitleştirilmiş)',
            'zh_HK' => 'Çince (Hong Kong)',
            'zh_TW' => 'Çince (Geleneksel)',
            'zu' => 'Zuluca',
        ],
        'uk' => [
            'af' => 'Африкаанс',
            'am' => 'Амхарська',
            'ar' => 'Арабська',
            'az_AZ' => 'Азербайджанська (Азербайджан)',
            'be' => 'Білоруська',
            'bg' => 'Болгарська',
            'bn_BD' => 'Банґла (Бангладеш)',
            'ca' => 'Каталонська',
            'cs_CZ' => 'Чеська (Чехія)',
            'da_DK' => 'Данська (Данія)',
            'de_DE' => 'Німецька (Німеччина)',
            'el_GR' => 'Грецька (Греція)',
            'en_AU' => 'Англійська (Австралія)',
            'en_CA' => 'Англійська (Канада)',
            'en_GB' => 'Англійська (Велика Британія)',
            'en_IN' => 'Англійська (Індія)',
            'en_SG' => 'Англійська (Сінгапур)',
            'en_US' => 'Англійська (Сполучені Штати)',
            'en_ZA' => 'Англійська (Південно-Африканська Республіка)',
            'es_419' => 'Іспанська (Латинська Америка)',
            'es_ES' => 'Іспанська (Іспанія)',
            'es_US' => 'Іспанська (Сполучені Штати)',
            'et' => 'Естонська',
            'eu_ES' => 'Баскська (Іспанія)',
            'fa' => 'Перська',
            'fi_FI' => 'Фінська (Фінляндія)',
            'fil' => 'Філіппінська',
            'fr_CA' => 'Французька (Канада)',
            'fr_FR' => 'Французька (Франція)',
            'gl_ES' => 'Галісійська (Іспанія)',
            'hi_IN' => 'Гінді (Індія)',
            'hr' => 'Хорватська',
            'hu_HU' => 'Угорська (Угорщина)',
            'hy' => 'Вірменська (Вірменія)',
            'id' => 'Індонезійська',
            'is_IS' => 'Ісландська (Ісландія)',
            'it_IT' => 'Італійська (Італія)',
            'iw_IL' => 'Іврит (Ізраїль)',
            'ja_JP' => 'Японська (Японія)',
            'ka_GE' => 'Грузинська (Грузія)',
            'kk' => 'Казахська',
            'km_KH' => 'Кхмерська (Камбоджа)',
            'kn_IN' => 'Каннада (Індія)',
            'ko' => 'Корейська (Південна Корея)',
            'ky_KG' => 'Киргизька (Киргизстан)',
            'lo_LA' => 'Лаоська (Лаос)',
            'lt' => 'Литовська',
            'lv' => 'Латвійська',
            'mk_MK' => 'Македонська (Північна Македонія)',
            'ml_IN' => 'Малаялам (Індія)',
            'mn_MN' => 'Монгольська (Монголія)',
            'mr_IN' => 'Маратхі (Індія)',
            'ms' => 'Малайська',
            'my_MM' => 'Бірманська (Мʼянма [Бірма])',
            'ne_NP' => 'Непальська (Непал)',
            'nl_NL' => 'Нідерландська (Нідерланди)',
            'no_NO' => 'Норвезька (Норвеґія)',
            'pl_PL' => 'Польська (Польща)',
            'pt_BR' => 'Портуґальська (Бразілія)',
            'pt_PT' => 'Портуґальська (Портуґалія)',
            'ro' => 'Румунська',
            'ru_RU' => 'Російська (Росія)',
            'si_LK' => 'Сингальська (Шрі-Ланка)',
            'sk' => 'Словацька',
            'sl' => 'Словенська',
            'sr' => 'Сербська',
            'sv_SE' => 'Шведська (Швеція)',
            'sw' => 'Суахілі',
            'ta_IN' => 'Тамільська (Індія)',
            'te_IN' => 'Телугу (Індія)',
            'th' => 'Тайська',
            'tr_TR' => 'Турецька (Туреччина)',
            'vi' => 'Вʼєтнамська',
            'zh_CN' => 'Китайська (спрощена)',
            'zh_HK' => 'Китайська (Гонконг)',
            'zh_TW' => 'Китайська (традиційна)',
            'zu' => 'Зулуська',
        ],
        'vi' => [
            'af' => 'Tiếng Afrikaans',
            'am' => 'Tiếng Amharic',
            'ar' => 'Tiếng Ả Rập',
            'az_AZ' => 'Tiếng Azerbaijan (Azerbaijan)',
            'be' => 'Tiếng Belarus',
            'bg' => 'Tiếng Bulgaria',
            'bn_BD' => 'Tiếng Bangla (Bangladesh)',
            'ca' => 'Tiếng Catalan',
            'cs_CZ' => 'Tiếng Séc (Séc)',
            'da_DK' => 'Tiếng Đan Mạch (Đan Mạch)',
            'de_DE' => 'Tiếng Đức (Đức)',
            'el_GR' => 'Tiếng Hy Lạp (Hy Lạp)',
            'en_AU' => 'Tiếng Anh (Australia)',
            'en_CA' => 'Tiếng Anh (Canada)',
            'en_GB' => 'Tiếng Anh (Vương quốc Anh)',
            'en_IN' => 'Tiếng Anh (Ấn Độ)',
            'en_SG' => 'Tiếng Anh (Singapore)',
            'en_US' => 'Tiếng Anh (Hoa Kỳ)',
            'en_ZA' => 'Tiếng Anh (Nam Phi)',
            'es_419' => 'Tiếng Tây Ban Nha (Châu Mỹ La-tinh)',
            'es_ES' => 'Tiếng Tây Ban Nha (Tây Ban Nha)',
            'es_US' => 'Tiếng Tây Ban Nha (Hoa Kỳ)',
            'et' => 'Tiếng Estonia',
            'eu_ES' => 'Tiếng Basque (Tây Ban Nha)',
            'fa' => 'Tiếng Ba Tư',
            'fi_FI' => 'Tiếng Phần Lan (Phần Lan)',
            'fil' => 'Tiếng Philippines',
            'fr_CA' => 'Tiếng Pháp (Canada)',
            'fr_FR' => 'Tiếng Pháp (Pháp)',
            'gl_ES' => 'Tiếng Galician (Tây Ban Nha)',
            'hi_IN' => 'Tiếng Hindi (Ấn Độ)',
            'hr' => 'Tiếng Croatia',
            'hu_HU' => 'Tiếng Hungary (Hungary)',
            'hy' => 'Tiếng Armenia (Armenia)',
            'id' => 'Tiếng Indonesia',
            'is_IS' => 'Tiếng Iceland (Iceland)',
            'it_IT' => 'Tiếng Italy (Italy)',
            'iw_IL' => 'Tiếng Do Thái (Israel)',
            'ja_JP' => 'Tiếng Nhật (Nhật Bản)',
            'ka_GE' => 'Tiếng Georgia (Georgia)',
            'kk' => 'Tiếng Kazakh',
            'km_KH' => 'Tiếng Khmer (Campuchia)',
            'kn_IN' => 'Tiếng Kannada (Ấn Độ)',
            'ko' => 'Tiếng Hàn (Hàn Quốc)',
            'ky_KG' => 'Tiếng Kyrgyz (Kyrgyzstan)',
            'lo_LA' => 'Tiếng Lào (Lào)',
            'lt' => 'Tiếng Litva',
            'lv' => 'Tiếng Latvia',
            'mk_MK' => 'Tiếng Macedonia (Bắc Macedonia)',
            'ml_IN' => 'Tiếng Malayalam (Ấn Độ)',
            'mn_MN' => 'Tiếng Mông Cổ (Mông Cổ)',
            'mr_IN' => 'Tiếng Marathi (Ấn Độ)',
            'ms' => 'Tiếng Mã Lai',
            'my_MM' => 'Tiếng Miến Điện (Myanmar [Miến Điện])',
            'ne_NP' => 'Tiếng Nepal (Nepal)',
            'nl_NL' => 'Tiếng Hà Lan (Hà Lan)',
            'no_NO' => 'Tiếng Na Uy (Na Uy)',
            'pl_PL' => 'Tiếng Ba Lan (Ba Lan)',
            'pt_BR' => 'Tiếng Bồ Đào Nha (Brazil)',
            'pt_PT' => 'Tiếng Bồ Đào Nha (Bồ Đào Nha)',
            'ro' => 'Tiếng Romania',
            'ru_RU' => 'Tiếng Nga (Nga)',
            'si_LK' => 'Tiếng Sinhala (Sri Lanka)',
            'sk' => 'Tiếng Slovak',
            'sl' => 'Tiếng Slovenia',
            'sr' => 'Tiếng Serbia',
            'sv_SE' => 'Tiếng Thụy Điển (Thụy Điển)',
            'sw' => 'Tiếng Swahili',
            'ta_IN' => 'Tiếng Tamil (Ấn Độ)',
            'te_IN' => 'Tiếng Telugu (Ấn Độ)',
            'th' => 'Tiếng Thái',
            'tr_TR' => 'Tiếng Thổ Nhĩ Kỳ (Thổ Nhĩ Kỳ)',
            'uk' => 'Tiếng Ukraina',
            'zh_CN' => 'Tiếng Trung (Giản thể)',
            'zh_HK' => 'Tiếng Trung (Hồng Kông)',
            'zh_TW' => 'Tiếng Trung (Phồn thể)',
            'zu' => 'Tiếng Zulu',
        ],
        'zh_CN' => [
            'af' => '南非荷兰语',
            'am' => '阿姆哈拉语',
            'ar' => '阿拉伯语',
            'az_AZ' => '阿塞拜疆语（阿塞拜疆）',
            'be' => '白俄罗斯语',
            'bg' => '保加利亚语',
            'bn_BD' => '孟加拉语（孟加拉国）',
            'ca' => '加泰罗尼亚语',
            'cs_CZ' => '捷克语（捷克）',
            'da_DK' => '丹麦语（丹麦）',
            'de_DE' => '德语（德国）',
            'el_GR' => '希腊语（希腊）',
            'en_AU' => '英语（澳大利亚）',
            'en_CA' => '英语（加拿大）',
            'en_GB' => '英语（英国）',
            'en_IN' => '英语（印度）',
            'en_SG' => '英语（新加坡）',
            'en_US' => '英语（美国）',
            'en_ZA' => '英语（南非）',
            'es_419' => '西班牙语（拉丁美洲）',
            'es_ES' => '西班牙语（西班牙）',
            'es_US' => '西班牙语（美国）',
            'et' => '爱沙尼亚语',
            'eu_ES' => '巴斯克语（西班牙）',
            'fa' => '波斯语',
            'fi_FI' => '芬兰语（芬兰）',
            'fil' => '菲律宾语',
            'fr_CA' => '法语（加拿大）',
            'fr_FR' => '法语（法国）',
            'gl_ES' => '加利西亚语（西班牙）',
            'hi_IN' => '印地语（印度）',
            'hr' => '克罗地亚语',
            'hu_HU' => '匈牙利语（匈牙利）',
            'hy' => '亚美尼亚语（亚美尼亚）',
            'id' => '印度尼西亚语',
            'is_IS' => '冰岛语（冰岛）',
            'it_IT' => '意大利语（意大利）',
            'iw_IL' => '希伯来语（以色列）',
            'ja_JP' => '日语（日本）',
            'ka_GE' => '格鲁吉亚语（格鲁吉亚）',
            'kk' => '哈萨克语',
            'km_KH' => '高棉语（柬埔寨）',
            'kn_IN' => '卡纳达语（印度）',
            'ko' => '韩语（韩国）',
            'ky_KG' => '柯尔克孜语（吉尔吉斯斯坦）',
            'lo_LA' => '老挝语（老挝）',
            'lt' => '立陶宛语',
            'lv' => '拉脱维亚语',
            'mk_MK' => '马其顿语（北马其顿）',
            'ml_IN' => '马拉雅拉姆语（印度）',
            'mn_MN' => '蒙古语（蒙古）',
            'mr_IN' => '马拉地语（印度）',
            'ms' => '马来语',
            'my_MM' => '缅甸语（缅甸）',
            'ne_NP' => '尼泊尔语（尼泊尔）',
            'nl_NL' => '荷兰语（荷兰）',
            'no_NO' => '挪威语（挪威）',
            'pl_PL' => '波兰语（波兰）',
            'pt_BR' => '葡萄牙语（巴西）',
            'pt_PT' => '葡萄牙语（葡萄牙）',
            'ro' => '罗马尼亚语',
            'ru_RU' => '俄语（俄罗斯）',
            'si_LK' => '僧伽罗语（斯里兰卡）',
            'sk' => '斯洛伐克语',
            'sl' => '斯洛文尼亚语',
            'sr' => '塞尔维亚语',
            'sv_SE' => '瑞典语（瑞典）',
            'sw' => '斯瓦希里语',
            'ta_IN' => '泰米尔语（印度）',
            'te_IN' => '泰卢固语（印度）',
            'th' => '泰语',
            'tr_TR' => '土耳其语（土耳其）',
            'uk' => '乌克兰语',
            'vi' => '越南语',
            'zu' => '祖鲁语',
        ],
        'zh_HK' => [
            'af' => '南非荷蘭文',
            'am' => '阿姆哈拉文',
            'ar' => '阿拉伯文',
            'az_AZ' => '阿塞拜疆文（亞塞拜疆）',
            'be' => '白俄羅斯文',
            'bg' => '保加利亞文',
            'bn_BD' => '孟加拉文（孟加拉）',
            'ca' => '加泰隆尼亞文',
            'cs_CZ' => '捷克文（捷克）',
            'da_DK' => '丹麥文（丹麥）',
            'de_DE' => '德文（德國）',
            'el_GR' => '希臘文（希臘）',
            'en_AU' => '英文（澳洲）',
            'en_CA' => '英文（加拿大）',
            'en_GB' => '英文（英國）',
            'en_IN' => '英文（印度）',
            'en_SG' => '英文（新加坡）',
            'en_US' => '英文（美國）',
            'en_ZA' => '英文（南非）',
            'es_419' => '西班牙文（拉丁美洲）',
            'es_ES' => '西班牙文（西班牙）',
            'es_US' => '西班牙文（美國）',
            'et' => '愛沙尼亞文',
            'eu_ES' => '巴斯克文（西班牙）',
            'fa' => '波斯文',
            'fi_FI' => '芬蘭文（芬蘭）',
            'fil' => '菲律賓文',
            'fr_CA' => '法文（加拿大）',
            'fr_FR' => '法文（法國）',
            'gl_ES' => '加里西亞文（西班牙）',
            'hi_IN' => '印地文（印度）',
            'hr' => '克羅地亞文',
            'hu_HU' => '匈牙利文（匈牙利）',
            'hy' => '亞美尼亞文（亞美尼亞）',
            'id' => '印尼文',
            'is_IS' => '冰島文（冰島）',
            'it_IT' => '意大利文（意大利）',
            'iw_IL' => '希伯來文（以色列）',
            'ja_JP' => '日文（日本）',
            'ka_GE' => '格魯吉亞文（格魯吉亞）',
            'kk' => '哈薩克文',
            'km_KH' => '高棉文（柬埔寨）',
            'kn_IN' => '坎納達文（印度）',
            'ko' => '韓文（南韓）',
            'ky_KG' => '吉爾吉斯文（吉爾吉斯）',
            'lo_LA' => '老撾文（老撾）',
            'lt' => '立陶宛文',
            'lv' => '拉脫維亞文',
            'mk_MK' => '馬其頓文（北馬其頓）',
            'ml_IN' => '馬拉雅拉姆文（印度）',
            'mn_MN' => '蒙古文（蒙古）',
            'mr_IN' => '馬拉地文（印度）',
            'ms' => '馬來文',
            'my_MM' => '緬甸文（緬甸）',
            'ne_NP' => '尼泊爾文（尼泊爾）',
            'nl_NL' => '荷蘭文（荷蘭）',
            'no_NO' => '挪威文（挪威）',
            'pl_PL' => '波蘭文（波蘭）',
            'pt_BR' => '葡萄牙文（巴西）',
            'pt_PT' => '葡萄牙文（葡萄牙）',
            'ro' => '羅馬尼亞文',
            'ru_RU' => '俄文（俄羅斯）',
            'si_LK' => '僧伽羅文（斯里蘭卡）',
            'sk' => '斯洛伐克文',
            'sl' => '斯洛文尼亞文',
            'sr' => '塞爾維亞文',
            'sv_SE' => '瑞典文（瑞典）',
            'sw' => '史瓦希里文',
            'ta_IN' => '泰米爾文（印度）',
            'te_IN' => '泰盧固文（印度）',
            'th' => '泰文',
            'tr_TR' => '土耳其文（土耳其）',
            'uk' => '烏克蘭文',
            'vi' => '越南文',
            'zu' => '祖魯文',
        ],
        'zh_TW' => [
            'af' => '南非荷蘭文',
            'am' => '阿姆哈拉文',
            'ar' => '阿拉伯文',
            'az_AZ' => '亞塞拜然文（亞塞拜然）',
            'be' => '白俄羅斯文',
            'bg' => '保加利亞文',
            'bn_BD' => '孟加拉文（孟加拉）',
            'ca' => '加泰蘭文',
            'cs_CZ' => '捷克文（捷克）',
            'da_DK' => '丹麥文（丹麥）',
            'de_DE' => '德文（德國）',
            'el_GR' => '希臘文（希臘）',
            'en_AU' => '英文（澳洲）',
            'en_CA' => '英文（加拿大）',
            'en_GB' => '英文（英國）',
            'en_IN' => '英文（印度）',
            'en_SG' => '英文（新加坡）',
            'en_US' => '英文（美國）',
            'en_ZA' => '英文（南非）',
            'es_419' => '西班牙文（拉丁美洲）',
            'es_ES' => '西班牙文（西班牙）',
            'es_US' => '西班牙文（美國）',
            'et' => '愛沙尼亞文',
            'eu_ES' => '巴斯克文（西班牙）',
            'fa' => '波斯文',
            'fi_FI' => '芬蘭文（芬蘭）',
            'fil' => '菲律賓文',
            'fr_CA' => '法文（加拿大）',
            'fr_FR' => '法文（法國）',
            'gl_ES' => '加利西亞文（西班牙）',
            'hi_IN' => '印地文（印度）',
            'hr' => '克羅埃西亞文',
            'hu_HU' => '匈牙利文（匈牙利）',
            'hy' => '亞美尼亞文（亞美尼亞）',
            'id' => '印尼文',
            'is_IS' => '冰島文（冰島）',
            'it_IT' => '義大利文（義大利）',
            'iw_IL' => '希伯來文（以色列）',
            'ja_JP' => '日文（日本）',
            'ka_GE' => '喬治亞文（喬治亞）',
            'kk' => '哈薩克文',
            'km_KH' => '高棉文（柬埔寨）',
            'kn_IN' => '坎那達文（印度）',
            'ko' => '韓文（南韓）',
            'ky_KG' => '吉爾吉斯文（吉爾吉斯）',
            'lo_LA' => '寮文（寮國）',
            'lt' => '立陶宛文',
            'lv' => '拉脫維亞文',
            'mk_MK' => '馬其頓文（北馬其頓）',
            'ml_IN' => '馬來亞拉姆文（印度）',
            'mn_MN' => '蒙古文（蒙古）',
            'mr_IN' => '馬拉地文（印度）',
            'ms' => '馬來文',
            'my_MM' => '緬甸文（緬甸）',
            'ne_NP' => '尼泊爾文（尼泊爾）',
            'nl_NL' => '荷蘭文（荷蘭）',
            'no_NO' => '挪威文（挪威）',
            'pl_PL' => '波蘭文（波蘭）',
            'pt_BR' => '葡萄牙文（巴西）',
            'pt_PT' => '葡萄牙文（葡萄牙）',
            'ro' => '羅馬尼亞文',
            'ru_RU' => '俄文（俄羅斯）',
            'si_LK' => '僧伽羅文（斯里蘭卡）',
            'sk' => '斯洛伐克文',
            'sl' => '斯洛維尼亞文',
            'sr' => '塞爾維亞文',
            'sv_SE' => '瑞典文（瑞典）',
            'sw' => '史瓦希里文',
            'ta_IN' => '坦米爾文（印度）',
            'te_IN' => '泰盧固文（印度）',
            'th' => '泰文',
            'tr_TR' => '土耳其文（土耳其）',
            'uk' => '烏克蘭文',
            'vi' => '越南文',
            'zu' => '祖魯文',
        ],
        'zu' => [
            'af' => 'i-Afrikaans',
            'am' => 'isi-Amharic',
            'ar' => 'isi-Arabic',
            'az_AZ' => 'isi-Azerbaijani (i-Azerbaijan)',
            'be' => 'isi-Belarusian',
            'bg' => 'isi-Bulgari',
            'bn_BD' => 'isi-Bengali (i-Bangladesh)',
            'ca' => 'isi-Catalan',
            'cs_CZ' => 'isi-Czech (i-Czechia)',
            'da_DK' => 'isi-Danish (i-Denmark)',
            'de_DE' => 'isi-German (i-Germany)',
            'el_GR' => 'isi-Greek (i-Greece)',
            'en_AU' => 'i-English (i-Australia)',
            'en_CA' => 'i-English (i-Canada)',
            'en_GB' => 'i-English (i-United Kingdom)',
            'en_IN' => 'i-English (i-India)',
            'en_SG' => 'i-English (i-Singapore)',
            'en_US' => 'i-English (i-United States)',
            'en_ZA' => 'i-English (iNingizimu Afrika)',
            'es_419' => 'isi-Spanish (i-Latin America)',
            'es_ES' => 'isi-Spanish (i-Spain)',
            'es_US' => 'isi-Spanish (i-United States)',
            'et' => 'isi-Estonia',
            'eu_ES' => 'isi-Basque (i-Spain)',
            'fa' => 'isi-Persian',
            'fi_FI' => 'isi-Finnish (i-Finland)',
            'fil' => 'isi-Filipino',
            'fr_CA' => 'isi-French (i-Canada)',
            'fr_FR' => 'isi-French (i-France)',
            'gl_ES' => 'isi-Galicia (i-Spain)',
            'hi_IN' => 'isi-Hindi (i-India)',
            'hr' => 'isi-Croatian',
            'hu_HU' => 'isi-Hungarian (i-Hungary)',
            'hy' => 'isi-Armenia (i-Armenia)',
            'id' => 'isi-Indonesian',
            'is_IS' => 'isi-Icelandic (i-Iceland)',
            'it_IT' => 'isi-Italian (i-Italy)',
            'iw_IL' => 'isi-Hebrew (kwa-Israel)',
            'ja_JP' => 'isi-Japanese (i-Japan)',
            'ka_GE' => 'isi-Georgian (i-Georgia)',
            'kk' => 'isi-Kazakh',
            'km_KH' => 'isi-Khmer (i-Cambodia)',
            'kn_IN' => 'isi-Kannada (i-India)',
            'ko' => 'isi-Korean (i-South Korea)',
            'ky_KG' => 'isi-Kyrgyz (i-Kyrgyzstan)',
            'lo_LA' => 'isi-Lao (i-Laos)',
            'lt' => 'isi-Lithuanian',
            'lv' => 'isi-Latvian',
            'mk_MK' => 'isi-Macedonian (i-North Macedonia)',
            'ml_IN' => 'isi-Malayalam (i-India)',
            'mn_MN' => 'isi-Mongolian (i-Mongolia)',
            'mr_IN' => 'isi-Marathi (i-India)',
            'ms' => 'isi-Malay',
            'my_MM' => 'isi-Burmese (i-Myanmar [Burma])',
            'ne_NP' => 'isi-Nepali (i-Nepal)',
            'nl_NL' => 'isi-Dutch (i-Netherlands)',
            'no_NO' => 'isi-Norwegian (i-Norway)',
            'pl_PL' => 'isi-Polish (i-Poland)',
            'pt_BR' => 'isi-Portuguese (i-Brazil)',
            'pt_PT' => 'isi-Portuguese (i-Portugal)',
            'ro' => 'isi-Romanian',
            'ru_RU' => 'isi-Russian (i-Russia)',
            'si_LK' => 'isi-Sinhala (i-Sri Lanka)',
            'sk' => 'isi-Slovak',
            'sl' => 'isi-Slovenian',
            'sr' => 'isi-Serbian',
            'sv_SE' => 'isi-Swedish (i-Sweden)',
            'sw' => 'isiSwahili',
            'ta_IN' => 'isi-Tamil (i-India)',
            'te_IN' => 'isi-Telugu (i-India)',
            'th' => 'isi-Thai',
            'tr_TR' => 'isi-Turkish (i-Turkey)',
            'uk' => 'isi-Ukrainian',
            'vi' => 'isi-Vietnamese',
            'zh_CN' => 'isi-Chinese (enziwe lula)',
            'zh_HK' => 'isi-Chinese (i-Hong Kong)',
            'zh_TW' => 'isi-Chinese (okosiko)',
        ],
    ];

    private const DEPEND_ON_DEVICE_MESSAGES = [
        'af' => 'Wissel volgens toestel',
        'am' => 'እንደ መሣሪያው ይለያያል',
        'ar' => 'يتباين بحسب الجهاز',
        'az_AZ' => 'Varies with device',
        'be' => 'Залежыць ад прылады',
        'bg' => 'Варира според устройството',
        'bn_BD' => 'ডিভাইস অনুযায়ী আলাদা হয়',
        'ca' => 'Varia segons el dispositiu',
        'cs_CZ' => 'Liší se podle zařízení',
        'da_DK' => 'Varierer fra enhed til enhed',
        'de_DE' => 'Variiert je nach Gerät',
        'el_GR' => 'Διαφέρει ανάλογα με τη συσκευή',
        'en_AU' => 'Varies with device',
        'en_CA' => 'Varies with device',
        'en_GB' => 'Varies with device',
        'en_IN' => 'Varies with device',
        'en_SG' => 'Varies with device',
        'en_US' => 'Varies with device',
        'en_ZA' => 'Varies with device',
        'es_419' => 'Varía con el dispositivo.',
        'es_ES' => 'Varía según el dispositivo.',
        'es_US' => 'Varía con el dispositivo.',
        'et' => 'Oleneb seadmest',
        'eu_ES' => 'Gailuaren arabera aldatzen da',
        'fa' => 'بسته به دستگاه‌ متفاوت است',
        'fi_FI' => 'Vaihtelee laitteen mukaan',
        'fil' => 'Nag-iiba-iba sa device',
        'fr_CA' => 'Varie selon les appareils.',
        'fr_FR' => 'Varie selon les appareils.',
        'gl_ES' => 'Varía segundo o dispositivo',
        'hi_IN' => 'डिवाइस के अनुसार अलग हो सकता है',
        'hr' => 'Razlikuje se ovisno o uređaju',
        'hu_HU' => 'Eszköztől függ',
        'hy_AM' => 'Varies with device',
        'id' => 'Bervariasi berdasarkan perangkat',
        'is_IS' => 'Fer eftir tækjum',
        'it_IT' => 'Varia in base al dispositivo',
        'iw_IL' => 'משתנה בהתאם למכשיר',
        'ja_JP' => 'デバイスにより異なります',
        'ka_GE' => 'Varies with device',
        'kk' => 'Құрылғыға байланысты әртүрлі болады',
        'km_KH' => 'Varies with device',
        'kn_IN' => 'ಸಾಧನ ಜೊತೆಗೆ ಬದಲಾಗುತ್ತದೆ',
        'ko_KR' => '기기에 따라 다릅니다.',
        'ky_KG' => 'Түзмөккө жараша айырмаланат',
        'lo_LA' => 'Varies with device',
        'lt' => 'Skiriasi pagal įrenginį',
        'lv' => 'Atšķiras atkarībā no ierīces',
        'mk_MK' => 'Варира со уред',
        'ml_IN' => 'ഉപകരണങ്ങൾ അനുസരിച്ച് വ്യത്യാസപ്പെടാം',
        'mn_MN' => 'Varies with device',
        'mr_IN' => 'डिव्हाइससह बदलते',
        'ms' => 'Berbeza-beza mengikut peranti',
        'my_MM' => 'စက်ပေါ်မူတည်၍ ကွဲပြားသည်',
        'ne_NP' => 'Varies with device',
        'nl_NL' => 'Varieert per apparaat',
        'no_NO' => 'Varierer med enheten',
        'pl_PL' => 'Zależy od urządzenia',
        'pt_BR' => 'Varia de acordo com o dispositivo',
        'pt_PT' => 'Varia consoante o aparelho',
        'ro' => 'Variază în funcție de dispozitiv',
        'ru_RU' => 'Зависит от устройства',
        'si_LK' => 'Varies with device',
        'sk' => 'Líši sa v závislosti od zariadenia',
        'sl' => 'Odvisno od naprave',
        'sr' => 'Разликује се у зависности од уређаја',
        'sv_SE' => 'Beror på enheten',
        'sw' => 'Hutofautiana kulingana na kifaa',
        'ta_IN' => 'சாதனத்தைப் பொறுத்து மாறுபடும்',
        'te_IN' => 'పరికరాన్ని బట్టి మారుతుంటుంది',
        'th' => 'ต่างกันไปตามอุปกรณ์',
        'tr_TR' => 'Cihaza göre değişir',
        'uk' => 'Залежить від пристрою',
        'vi' => 'Khác nhau tùy theo điện thoại',
        'zh_CN' => '因设备而异',
        'zh_HK' => '因裝置而異',
        'zh_TW' => '因裝置而異',
        'zu' => 'Iyahluka kuya ngedivayisi',
    ];

    /**
     * Normalizes the locale.
     *
     * @param string $locale
     *
     * @return string
     */
    public static function getNormalizeLocale(string $locale): string
    {
        if ($locale === '') {
            return self::DEFAULT_GOOGLE_PLAY_LOCALE;
        }
        $locale = str_replace('-', '_', strtolower($locale));

        if (isset(self::SUPPORTED_LOCALES[$locale])) {
            return self::SUPPORTED_LOCALES[$locale];
        }

        if (isset(self::ALIASES_LOCALE[$locale])) {
            return self::ALIASES_LOCALE[$locale];
        }

        if (($pos = strpos($locale, '_')) !== false) {
            $locale = substr($locale, 0, $pos);

            if (isset(self::SUPPORTED_LOCALES[$locale])) {
                return self::SUPPORTED_LOCALES[$locale];
            }

            if (isset(self::ALIASES_LOCALE[$locale])) {
                return self::ALIASES_LOCALE[$locale];
            }
        }

        return self::DEFAULT_GOOGLE_PLAY_LOCALE;
    }

    /**
     * Normalizes the locales.
     *
     * @param array $locales
     *
     * @return array
     */
    public static function getNormalizeLocales(array $locales): array
    {
        $locales = !empty($locales) ? $locales : self::SUPPORTED_LOCALES;
        $locales = array_map([self::class, 'getNormalizeLocale'], $locales);

        return array_values(array_unique($locales));
    }

    /**
     * Finds preferred language.
     *
     * @param string $sourceLocale
     * @param string $destLanguageName
     *
     * @return string|null
     *
     * @internal
     */
    public static function findPreferredLanguage(string $sourceLocale, string $destLanguageName): ?string
    {
        $sourceLocale = self::getNormalizeLocale($sourceLocale);

        if (isset(self::GOOGLE_PLAY_TRANSLATE_LANGUAGES[$sourceLocale])) {
            foreach (self::GOOGLE_PLAY_TRANSLATE_LANGUAGES[$sourceLocale] as $destLocale => $languageName) {
                if (strcmp($languageName, $destLanguageName) === 0) {
                    return $destLocale;
                }
            }
        }

        return null;
    }

    /**
     * Detects that the passed value is "Varies with device".
     *
     * @param string $locale
     * @param string $message
     *
     * @return bool
     *
     * @internal
     */
    public static function isDependOnDevice(string $locale, string $message): bool
    {
        $locale = self::getNormalizeLocale($locale);

        return isset(self::DEPEND_ON_DEVICE_MESSAGES[$locale])
            && strcmp(self::DEPEND_ON_DEVICE_MESSAGES[$locale], $message) === 0;
    }
}
